/********************************************************************************
  * @file    PT32x076_aes.h
  * @author  ӦÿŶ
  * @version V1.0.0
  * @date    2023/7/15
  * @brief   This file contains all the functions prototypes for the AES firmware
  *          library
  * @attention
  *
  * ǰĹָ̼, ĿͻṩйƷıϢ,Խʡǵʱ䡣
  * ̼/ͻʹаıϢκ, * Pai-IC κֱӣӻ̷𺦸
  *
  * (C) Ȩ Pai-IC Microelectronics
  *******************************************************************************/

#ifndef __PT32x076_AES_H
#define __PT32x076_AES_H

#ifdef __cplusplus
 extern "C" {
#endif
	 

/* Includes ------------------------------------------------------------------*/
#include "PT32x076.h"
	
typedef struct
{
	u32 AES_OperatingMode;				    /*!< Specifies the operating mode selection.
																					This parameter can be a value of @ref AES_OperatingMode */

	u32 AES_EncryptionMethod;					/*!< Specifies the encryption method.
																					This parameter can be a value of @ref AES_EncryptionMethod */

	u32 AES_KeySize;						    	/*!< Specifies the Key size selection.
																					This parameter can be a value of @ref AES_KeySize */

}AES_InitTypeDef;


/** @defgroup AES_ALL_PERIPH
* @{
*/
#define IS_AES_ALL_PERIPH(AESx)               ((AESx) == AES)

/** @defgroup AES_OperatingMode
* @{
*/
#define AES_Mode_Decrypt			                (AES_CR_MODE&0x00000000)
#define AES_Mode_Encryption	                  (AES_CR_MODE&0x00000002)
#define IS_AES_OperatingMode(Mode)            (((Mode) == AES_Mode_Decrypt)||\
															                ((Mode) == AES_Mode_Encryption))

/** @defgroup AES_EncryptionMethod
* @{
*/
#define AES_EncryptionMethodECB			          (AES_CR_EM&0x00000000)
#define AES_EncryptionMethodCBC	              (AES_CR_EM&0x00000004)
#define IS_AES_EncryptionMethod(Method)       (((Method) == AES_EncryptionMethodECB)||\
															                ((Method) == AES_EncryptionMethodCBC))

/** @defgroup AES_KeySize
* @{
*/
#define AES_KeySize128			                  (AES_CR_KSIZE&0x00000000)
#define AES_KeySize192	                      (AES_CR_KSIZE&0x00000008)
#define AES_KeySize256	                      (AES_CR_KSIZE&0x00000010)
#define IS_AES_KeySize(KeySize)               (((KeySize) == AES_KeySize128)||\
															                ((KeySize) == AES_KeySize192)||\
																							((KeySize) == AES_KeySize256))
/** @defgroup AES_FLAG
* @{
*/
#define AES_FLAG_CCF                          (AES_SR_CCF&0x00000001)
#define IS_AES_FLAG(AES_FLAG)                 ((AES_FLAG) == AES_FLAG_CCF)

/** @defgroup AES_Interrupt
* @{
*/
#define AES_IT_CCIE                           (AES_CR_CCIE&0x00000100) 
#define IS_AES_IT(AES_IT)                     ((AES_IT) == AES_IT_CCIE)



void AES_Init(AES_TypeDef *AESx, AES_InitTypeDef *AES_InitStruct);
void AES_StructInit(AES_InitTypeDef *AES_InitStruct);
void AES_StartComputation(AES_TypeDef *AESx);
void AES_OperatingMode(AES_TypeDef *AESx, u32 SEL);
void AES_EncryptionMethodConfig(AES_TypeDef *AESx, u32 SEL);
void AES_KeySizeConfig(AES_TypeDef *AESx, u32 KeySize);
void AES_KeyExpansion(AES_TypeDef *AESx);
void AES_ITConfig(AES_TypeDef *AESx, u32 AES_IT, FunctionalState NewState);
/* Description    : These functions  write key value to key register with different key length*/
void AES_SetKey(AES_TypeDef *AESx,u32 *Keys,u32 KeySize);
void AES_GetKey(AES_TypeDef *AESx,u32 *Keys,u32 KeySize);
/* This function write the din register       */
void AES_DataInput(AES_TypeDef *AESx,u32 Din[4]);
/* This function set Initial vector register */
void AES_InitializationVectorInput(AES_TypeDef *AESx,u32 IV[4]);
/* This function read out the result from Dout register*/
void AES_GetDataOutput(AES_TypeDef *AESx,u32 *data);
FlagStatus AES_GetFlagStatus(AES_TypeDef *AESx, u32 AES_FLAG);
#ifdef __cplusplus
}

#endif // _AES_H_


#endif /* __PT32x076_AES_H */


/**
  * @}
  */

/**
  * @}
  */

/************************(C) COPYRIGHT PENGPAI Microelectronics*****END OF FILE****/
