/********************************************************************************
  * @file    PT32Sx076_wwdg.h
  * @author  ӦÿŶ
  * @version V1.0.0
  * @date    2023/7/15
  * @brief   This file contains all the functions prototypes for the WWDG firmware
  *          library
  * @attention
  *
  * ǰĹָ̼, ĿͻṩйƷıϢ,Խʡǵʱ䡣
  * ̼/ͻʹаıϢκ, * Pai-IC κֱӣӻ̷𺦸
  *
  * (C) Ȩ Pai-IC Microelectronics
  *******************************************************************************/

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef PT32x076_WWDG_H
#define PT32x076_WWDG_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x076.h"


/** @defgroup WDG_ALL_PERIPH
* @{
*/ 
#define IS_WWDG_ALL_PERIPH(PERIPH)     ((PERIPH) == WWDG)

/** @defgroup WWDG_LockKey
* @{
*/
#define WWDG_CR2_KEYVALUE                ((u32)0xACBD0000)

/** @defgroup WWDG_IT
* @{
*/
#define WWDG_IT_EWIE      WWDG_CFGR_EWIE
#define IS_WWDG_IT(SEL)	   ((SEL) == WWDG_IT_EWIE)

/** @defgroup WWDG_FLAG
* @{
*/
typedef enum
{
WWDG_FLAG_EWIF   = 0x00,
}WWDG_FLAG;
#define IS_WWDG_FLAG(SEL)			 ((SEL) == WWDG_FLAG_EWIF)

/** @defgroup WWDG_Prescaler
* @{
*/
#define WWDG_Prescaler_1    (WWDG_CFGR_PSC&0x0000)
#define WWDG_Prescaler_2    (WWDG_CFGR_PSC&0x1000)
#define WWDG_Prescaler_4    (WWDG_CFGR_PSC&0x2000)
#define WWDG_Prescaler_8    (WWDG_CFGR_PSC&0x3000)
#define WWDG_Prescaler_16   (WWDG_CFGR_PSC&0x4000)
#define WWDG_Prescaler_32   (WWDG_CFGR_PSC&0x5000)
#define WWDG_Prescaler_64   (WWDG_CFGR_PSC&0x6000)
#define WWDG_Prescaler_128  (WWDG_CFGR_PSC&0x7000)
#define IS_WWDG_Prescaler(SEL) 		((((SEL)&~WWDG_CFGR_PSC)==0) && ((SEL) <=WWDG_Prescaler_128))

/** @defgroup WWDG_WINDOW_VALUE
* @{
*/                                     
#define IS_WWDG_WINDOW_VALUE(VALUE)     (((VALUE) >= 0x40) && ((VALUE) <= 0x7F))

/** @defgroup WWDG_COUNTER
* @{
*/
#define IS_WWDG_COUNTER(COUNTER)        (((COUNTER) >= 0x40) && ((COUNTER) <= 0x7F))

/** @defgroup WWDG_Exported_Functions
  * @{
  */ 
void WWDG_Cmd(WWDG_TypeDef* WDGx, FunctionalState NewState);  
void WWDG_ResetEnable(WWDG_TypeDef* WDGx);
void WWDG_SetPrescaler(u32 WWDG_Prescaler);
void WWDG_DBGPendingCmd(WWDG_TypeDef* WDGx, FunctionalState NewState);
void WWDG_SetWindowValue(u32 WindowValue);
void WWDG_ITConfigEnable(WWDG_TypeDef* WDGx,u16 WWDG_IT);
void WWDG_SetCounter(u32 Counter);
FlagStatus WWDG_GetFlagStatus(WWDG_TypeDef* WDGx, WWDG_FLAG Flag);
void WWDG_ClearFlag(WWDG_TypeDef* WDGx, u8 WWDG_FLAG);

#ifdef __cplusplus
}
#endif

#endif /* __PT32S032_WWDG_H */

/**
  * @}
  */ 

/**
  * @}
  */ 

/**
  * @}
  */ 

/******************* (C) COPYRIGHT 2011 STMicroelectronics *****END OF FILE****/
