/********************************************************************************
  * @file    PT32x076_adc.h
  * @author  ӦÿŶ
  * @version V1.0.0
  * @date    2023/7/15
  * @brief   This file contains all the functions prototypes for the ADC firmware
  *          library
  * @attention
  *
  * ǰĹָ̼, ĿͻṩйƷıϢ,Խʡǵʱ䡣
  * ̼/ͻʹаıϢκ, * Pai-IC κֱӣӻ̷𺦸
  *
  * (C) Ȩ Pai-IC Microelectronics
  *******************************************************************************/

#ifndef PT32x076_ADC_H
#define PT32x076_ADC_H

#ifdef __cplusplus
extern "C" {
#endif

#include "PT32x076.h"

/** @defgroup ADC_InitTypeDef
* @{
*/
typedef struct
{
	u32 ADC_Prescaler;									/*!< Specifies the ADC prescaler,
																						 This parameter can be a value of @ref ADC_Prescaler */

	u32 ADC_Mode;												/*!< Specifies the ADC mode,
																						 This parameter can be a value of @ref ADC_Mode */

	u32 ADC_TriggerSource;							/*!< Specifies the ADC trigger source selection,
																						 This parameter can be a value of @ref ADC_TriggerSource */

	u32 ADC_TimerTriggerSource;					/*!< Specifies the ADC timing trigger source selection,
																						 This parameter can be a value of @ref ADC_TimerTriggerSource */

	u32 ADC_ExternalTriggerSource;		/*!< Specifies the ADC timing trigger source selection,
																						 This parameter can be a value of @ref ADC_ExternalPinTriggerSource */

	u32 ADC_Align;											/*!< Specifies the ADC ALIGN,
																						 This parameter can be a value of @ref ADC_Align */

	u32 ADC_Channel;										/*!< Specifies the ADC channel selection,
																						 This parameter can be a value of @ref ADC_Channel */

	u32 ADC_BGVoltage;									/*!< Specifies the ADC bg voltage selection,
																						 This parameter can be a value of @ref ADC_BGVoltage	*/

	u32 ADC_ReferencePositive;		/*!< Specifies the ADC voltage reference positive selection,
																						 This parameter can be a value of @ref ADC_VoltageReferencePositive */

} ADC_InitTypeDef;


/** @defgroup ADC_ALL_PERIPH
* @{
*/
#define IS_ADC_ALL_PERIPH(SEL)       ((SEL) == ADC)

/** @defgroup ADC_Prescaler
* @{
*/
#define IS_ADC_Prescaler(SEL)       ((SEL)<=255)

/** @defgroup ADC_Mode
* @{
*/
#define ADC_Mode_Single			                  (ADC_CR1_MODE&0x00000000)
#define ADC_Mode_Continuous	                  (ADC_CR1_MODE&0x00000002)
#define IS_ADC_Mode(SEL)                      (((SEL) == ADC_Mode_Single)||\
															                ((SEL) == ADC_Mode_Continuous))


/** @defgroup ADC_TriggerSource
* @{
*/
#define ADC_TriggerSource_Software            (ADC_CR1_TRIGS&0x00000000)
#define ADC_TriggerSource_Timer               (ADC_CR1_TRIGS&0x00000004)
#define ADC_TriggerSource_ExternalPin         (ADC_CR1_TRIGS&0x00000008)
#define IS_ADC_TriggerSource(SEL)             (((SEL) == ADC_TriggerSource_Software)||\
																							((SEL) == ADC_TriggerSource_Timer)   ||\
																							((SEL) == ADC_TriggerSource_ExternalPin))

/** @defgroup ADC_TimerTriggerSource
* @{
*/
#define ADC_TimerTriggerSource_TIM1ADC                         (ADC_CR1_TIMS&0x00000010)
#define ADC_TimerTriggerSource_TIM2ADC                         (ADC_CR1_TIMS&0x00000020)
#define ADC_TimerTriggerSource_TIM3ADC                         (ADC_CR1_TIMS&0x00000030)
#define ADC_TimerTriggerSource_TIM5ADC                         (ADC_CR1_TIMS&0x00000050)
#define ADC_TimerTriggerSource_TIM6ADC                         (ADC_CR1_TIMS&0x00000060)
#define ADC_TimerTriggerSource_TIM7ADC                         (ADC_CR1_TIMS&0x00000070)
#define ADC_TimerTriggerSource_TIM8ADC                         (ADC_CR1_TIMS&0x00000080)
#define ADC_TimerTriggerSource_LPTIMADC                        (ADC_CR1_TIMS&0x00000090)
#define IS_ADC_TimerTriggerSource(SEL)   (((SEL) & ~ADC_CR1_TIMS) == 0 && SEL <= ADC_TimerTriggerSource_LPTIMADC)

/** @defgroup ADC_Align
* @{
*/
#define ADC_Align_Right     (ADC_CR1_ALIGN&0x00000000)
#define ADC_Align_Left      (ADC_CR1_ALIGN&0x00000800)
#define IS_ADC_Align(SEL)       (((SEL) == ADC_Align_Right) || \
																 ((SEL) == ADC_Align_Left))

/** @defgroup IS_ADC_ADVRPS_SEL **/
#define ADC_VoltageReferencePositive_VDDA              0x00000000
#define ADC_VoltageReferencePositive_BG2v0     (ADC_CR1_ADVRPS&0x100)
#define ADC_VoltageReferencePositive_VREF      (ADC_CR1_ADVRPS&0x200)
#define IS_ADC_ReferencePositive(SEL)  (((SEL) == ADC_VoltageReferencePositive_VDDA) || \
																			 ((SEL) == ADC_VoltageReferencePositive_BG2v0) ||((SEL) == ADC_VoltageReferencePositive_VREF))
										


/** @defgroup IS_ADC_InputNegative_SEL **/
#define ADC_InputNegative_VSS              0x00000000
#define ADC_InputNegative_INN            (ADC_CR1_INNS&0x2000)
#define IS_ADC_InputNegative(SEL)	       (((SEL) == ADC_InputNegative_INN)   || \
																					((SEL) == ADC_InputNegative_VSS))


/** @defgroup ADC_Channel
* @{
*/
#define ADC_Channel_0                             (ADC_CR1_CHS&0x00000000)
#define ADC_Channel_1                             (ADC_CR1_CHS&0x00010000)
#define ADC_Channel_2                             (ADC_CR1_CHS&0x00020000)
#define ADC_Channel_3                             (ADC_CR1_CHS&0x00030000)
#define ADC_Channel_4                             (ADC_CR1_CHS&0x00040000)
#define ADC_Channel_5                             (ADC_CR1_CHS&0x00050000)
#define ADC_Channel_6                             (ADC_CR1_CHS&0x00060000)
#define ADC_Channel_7                             (ADC_CR1_CHS&0x00070000)
#define ADC_Channel_8                             (ADC_CR1_CHS&0x00080000)
#define ADC_Channel_9                             (ADC_CR1_CHS&0x00090000)
#define ADC_Channel_10                            (ADC_CR1_CHS&0x000A0000)
#define ADC_Channel_11                            (ADC_CR1_CHS&0x000B0000)
#define ADC_Channel_12                            (ADC_CR1_CHS&0x000C0000)
#define ADC_Channel_13                            (ADC_CR1_CHS&0x000D0000)
#define ADC_Channel_14                            (ADC_CR1_CHS&0x000E0000)
#define ADC_Channel_15                            (ADC_CR1_CHS&0x000F0000)
#define ADC_Channel_16                            (ADC_CR1_CHS&0x00100000)
#define ADC_Channel_17                            (ADC_CR1_CHS&0x00110000)
#define ADC_Channel_18                            (ADC_CR1_CHS&0x00120000)
#define ADC_Channel_19                            (ADC_CR1_CHS&0x00130000)
#define ADC_Channel_20                            (ADC_CR1_CHS&0x00140000)
#define ADC_Channel_21                            (ADC_CR1_CHS&0x00150000)
#define ADC_Channel_22                            (ADC_CR1_CHS&0x00160000)
#define ADC_Channel_23                            (ADC_CR1_CHS&0x00170000)
#define ADC_Channel_24                            (ADC_CR1_CHS&0x00180000)
#define ADC_Channel_25                            (ADC_CR1_CHS&0x00190000)
#define ADC_Channel_26                            (ADC_CR1_CHS&0x001A0000)
#define ADC_Channel_27                            (ADC_CR1_CHS&0x001B0000)
#define IS_ADC_Channel(SEL)    ((SEL) & ~ADC_CR1_CHS) == 0 && (SEL <= ADC_Channel_27)

/** @defgroup ADC_BGVoltage
* @{
*/
#define ADC_BGVoltage_BG1v2     (ADC_CR1_BGS&0x00000000)
#define ADC_BGVoltage_BG1v0     (ADC_CR1_BGS&0x00200000)
#define IS_ADC_BGVoltage(SEL)       (((SEL)==ADC_BGVoltage_BG1v2)||\
																		 ((SEL)==ADC_BGVoltage_BG1v0))

/** @defgroup ADC_IT
* @{
*/
#define ADC_IT_EOC      ADC_CR1_EOCIE
#define ADC_IT_EOS      ADC_CR1_EOSIE
#define ADC_IT_ALL      0x8400
#define IS_ADC_IT(SEL)    (((SEL) & 0xFFFF7BFF) == 0 && ((SEL) != 0))

/** @defgroup ADC_FLAG
* @{
*/
#define ADC_FLAG_RDY        ADC_SR_RDY
#define ADC_FLAG_EOC        ADC_SR_EOC
#define ADC_FLAG_EOS        ADC_SR_EOS
#define IS_ADC_FLAG(SEL)   (((SEL) & 0xFFFFFFF8) == 0 && ((SEL) != 0))


/** @defgroup ADC_ExternalTriggerSource
* @{
*/
#define ADC_ExternalTriggerSource_ADCETR         (ADC_CR1_EXTS&0x00000000)
#define ADC_ExternalTriggerSource_TIM1CH4        (ADC_CR1_EXTS&0x20000000)
#define IS_ADC_ExternalTriggerSource(SEL)  			(((SEL)==ADC_ExternalTriggerSource_ADCETR)||\
													                       ((SEL)==ADC_ExternalTriggerSource_TIM1CH4))

/** @defgroup ADC_AverageTimes
* @{
*/
#define ADC_AverageTimes_1     (ADC_CR2_AVGT&0x00000000)
#define ADC_AverageTimes_2     (ADC_CR2_AVGT&0x01000000)
#define ADC_AverageTimes_4     (ADC_CR2_AVGT&0x02000000)
#define ADC_AverageTimes_8     (ADC_CR2_AVGT&0x03000000)
#define ADC_AverageTimes_16    (ADC_CR2_AVGT&0x04000000)
#define ADC_AverageTimes_32    (ADC_CR2_AVGT&0x05000000)
#define ADC_AverageTimes_64    (ADC_CR2_AVGT&0x06000000)
#define ADC_AverageTimes_128   (ADC_CR2_AVGT&0x07000000)
#define IS_ADC_AverageTimes(SEL)    (((SEL) & ~ADC_CR2_AVGT) == 0 && SEL <= ADC_AverageTimes_128)


/** @defgroup ADC_ReadyTime
* @{
*/
#define IS_ADC_ReadyTime(SEL)    ((SEL)<=0xFF)

/** @defgroup ADC_SampleTime
* @{
*/
#define IS_ADC_SampleTime(SEL)      (((SEL)<=0xFF) && ((SEL)>=3))




/** @defgroup Trim Value
* @{
*/
#define IS_ADC_BG2v0TrimValue(Value)  ((Value)<=0x3F)

/** @defgroup ADC_ScanChannel
* @{
*/
#define IS_ADC_ScanChannel(SEL)     ((SEL)<=19)

/** @defgroup ADC_ScanChannelNumber
* @{
*/
#define IS_ADC_ScanChannelNumber(SEL)       (((SEL)>=2)&&((SEL)<=20))


/** @defgroup BG2v0TrimKey
* @{
*/
#define ADC_TrimKey 0xAC000000
#define IS_ADC_BG2v0TrimKey(SEL)      ((SEL)==ADC_TrimKey)

/*! function declaration and definition*/
void ADC_Init(ADC_TypeDef *ADCx, ADC_InitTypeDef *ADC_InitStruct);
void ADC_StructInit(ADC_InitTypeDef *ADC_InitStruct);
void ADC_Cmd(ADC_TypeDef *ADCx, FunctionalState NewState);
void ADC_ChannelConfig(ADC_TypeDef *ADCx, u32 ADC_Channel);
void ADC_StartOfConversion(ADC_TypeDef *ADCx);
u16 ADC_GetConversionValue(ADC_TypeDef *ADCx);
void ADC_ITConfig(ADC_TypeDef *ADCx, u32 ADC_IT, FunctionalState NewState);
FlagStatus ADC_GetFlagStatus(ADC_TypeDef *ADCx, u32 ADC_FLAG);
void ADC_AverageCmd(ADC_TypeDef *ADCx, FunctionalState NewState);
void ADC_AverageTimesConfig(ADC_TypeDef *ADCx, u32 Times);
void ADC_ReadyTimeConfig(ADC_TypeDef *ADCx, u32 ReadyTime);
void ADC_SampleTimeConfig(ADC_TypeDef *ADCx, u32 SampleTime);
void ADC_ScanCmd(ADC_TypeDef *ADCx, FunctionalState NewState);
void ADC_ScanChannelConfig(ADC_TypeDef *ADCx, u32 ScanChannel,u32 ADC_Channel );
void ADC_ScanChannelNumberConfig(ADC_TypeDef *ADCx, u32 ScanNumber);
void ADC_DMACmd(ADC_TypeDef *ADCx, FunctionalState NewState);
void ADC_TriggerSource(ADC_TypeDef *ADCx, u32 SEL);
void ADC_TimerTriggerSource(ADC_TypeDef *ADCx, u32 SEL);
void ADC_ReferencePositive(ADC_TypeDef *ADCx, u32 SEL);
void ADC_Prescaler(ADC_TypeDef *ADCx, u32 Division);
void ADC_Mode(ADC_TypeDef *ADCx, u32 SEL);
void ADC_ExternalTriggerSource(ADC_TypeDef *ADCx, u32 SEL);
void ADC_BG2v0Config(ADC_TypeDef *ADCx, FunctionalState NewState);
void ADC_BG2v0OutputConfig(ADC_TypeDef *ADCx, FunctionalState NewState);
void ADC_TrimValueConfig(ADC_TypeDef *ADCx, u32 Value);
void ADC_InputNegative(ADC_TypeDef *ADCx, u32 SEL);

#ifdef __cplusplus
}
#endif

#endif /*__PT32x076_ADC_H */
