/********************************************************************************
  * @file    PT32x076_beep.h
  * @author  ӦÿŶ
  * @version V1.0.0
  * @date    2023/7/15
  * @brief   This file contains all the functions prototypes for the BEEP firmware
  *          library
  * @attention
  *
  * ǰĹָ̼, ĿͻṩйƷıϢ,Խʡǵʱ䡣
  * ̼/ͻʹаıϢκ, * Pai-IC κֱӣӻ̷𺦸
  *
  * (C) Ȩ Pai-IC Microelectronics
  *******************************************************************************/

#ifndef PT32x076_BEEP_H
#define PT32x076_BEEP_H

#ifdef __cplusplus
extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x076.h"

/** @addtogroup BEEP
  * @{
  */

/* Exported types ------------------------------------------------------------*/

/**
  * @brief  BEEP Initstructure definition
  */

typedef struct
{
	u32 BEEP_PrescalerValue;    /*!< Specifies the beep prescaler value.
								                   This parameter can be a number between 1 and 256 */

	u32 BEEP_ClockSelection;      /*!< Specifies the beep clock source selection.
								                   This parameter can be a value of @ref BEEP_clock_selection */

} Beep_InitTypeDef;

/* Exported constants --------------------------------------------------------*/

/** @defgroup IS_BEEP_ALL_PERIPH
  * @{
  */
#define IS_BEEP_ALL_PERIPH(SEL)    	((SEL) == BEEP)
/**
  * @}
  */
#define BEEP_CLOCK_LSI          (BEEP_CR_CLKS&0x0)
#define BEEP_CLOCK_LSE          (BEEP_CR_CLKS&0x2)

#define IS_BEEP_ClockSelection(SEL)  (((SEL) == BEEP_CLOCK_LSI)  ||  ((SEL) == BEEP_CLOCK_LSE))

/**
  * @}
  */

/** @defgroup IS_BEEP_PSC
  * @{
  */
#define IS_BEEP_Prescaler(SEL) 		 ((SEL)>0 && (SEL) <= 256)
/**
  * @}
  */

/* Exported macro ------------------------------------------------------------*/
/* Exported functions ---------------------------------------------------------*/
void Beep_Init(Beep_InitTypeDef *Beep_InitStruct);
void Beep_Cmd(FunctionalState NewState);
void Beep_HighSinkConfig(BEEP_TypeDef *BEEPx, FunctionalState NewState);

/**
  * @}
  */

#ifdef __cplusplus
}
#endif

#endif /*__PT32x076_BEEP_H */
