/********************************************************************************
  * @file    PT32x076_dma.h
  * @author  Application development team
  * @version V1.0.0
  * @date    2023/06/26
  * @brief   This file contains all the functions prototypes for the DMA firmware
  *          library
  * @attention
  *
  * ǰĹָ̼, ĿͻṩйƷıϢ,Խʡǵʱ䡣
  * ̼/ͻʹаıϢκ, * Pai-IC κֱӣӻ̷𺦸
  *
  * (C) Ȩ Pai-IC Microelectronics
  *******************************************************************************/

#ifndef PT32x076_DMA_H
#define PT32x076_DMA_H

#ifdef __cplusplus
extern "C" {
#endif

#include "PT32x076.h"

/** @defgroup DMA_InitTypeDef
* @{
*/
typedef struct
{
	u32 DMA_SourceBaseAddress;          	/*!< Specifies the Source Address,
																						 This parameter can be a value of @ref DMA_SourceBaseAddress */

	u32 DMA_DestinationBaseAddress;     	/*!< Specifies the Destination Address,
																						 This parameter can be a value of @ref DMA_DestinationBaseAddress */

	u32 DMA_NumberOfData;          				/*!< Specifies the Number of Blocks for a DMA transfer,
																						 This parameter can be a value of @ref DMA_NumberOfData */

	u32 DMA_SourceDataSize;        				/*!< Specifies the DMA Source Data Size,
																						 This parameter can be a value of @ref DMA_SourceDataSize */

	u32 DMA_DestinationDataSize;     			/*!< Specifies the DMA Destination Data Size,
																						 This parameter can be a value of @ref DMA_DestinationDataSize */

	u32 DMA_SourceAddressIncrement;       /*!< Specifies the DMA Source Address Increment,
																						 This parameter can be a value of @ref DMA_SourceAddressIncrement */

	u32 DMA_DestinationAddressIncrement;  /*!< Specifies the DMA Destination Address Increment,
																						 This parameter can be a value of @ref DMA_DestinationAddressIncrement */

	u32 DMA_Direction;										/*!< Specifies the DMA Direction,
																						 This parameter can be a value of @ref DMA_Direction */

	u32 DMA_CircularMode;									/*!< Specifies the DMA Circular mode,
																						 This parameter can be a value of @ref DMA_CircularMode */

	u32 DMA_Burst;                        /*!<Transmission data burst length
	                                           This parameter can be a value of @ref DMA_BURST */

} DMA_InitTypeDef;


/** @defgroup DMA_ALL_PERIPH
* @{
*/
#define IS_DMA_ALL_PERIPH(SEL)      ((SEL) == DMA)

#define IS_DMA_Channel(SEL)         (((SEL) == DMA_Channel0) || \
									 ((SEL) == DMA_Channel1) || \
									 ((SEL) == DMA_Channel2) || \
									 ((SEL) == DMA_Channel3) || \
									 ((SEL) == DMA_Channel4) || \
									 ((SEL) == DMA_Channel5))

typedef enum
{
	DMA_CHNUM_0 = 0,
	DMA_CHNUM_1,
	DMA_CHNUM_2,
	DMA_CHNUM_3,
	DMA_CHNUM_4,
	DMA_CHNUM_5,
} DMA_ChannelNum;
#define DMA_CHAPCR_CH_SEL                 ((u32)0x0000003F)
#define IS_DMA_ChannelNum(SEL)        (((SEL) == DMA_CHNUM_0) || ((SEL) == DMA_CHNUM_1) || ((SEL) == DMA_CHNUM_2) || \
																			 ((SEL) == DMA_CHNUM_3) || ((SEL) == DMA_CHNUM_4) || ((SEL) == DMA_CHNUM_5))


/** @defgroup DMA_NumberOfData
* @{
*/
#define IS_DMA_NumberOfData(SEL)      ((SEL > 0) && (SEL < 65536))  //!<Number of data to transfer

/** @defgroup DMA_SourceDataSize
* @{
*/
#define DMA_SourceDataSize_Byte      (DMA_CCR_SSIZE&0x00000000)
#define DMA_SourceDataSize_Half      (DMA_CCR_SSIZE&0x00000008)
#define DMA_SourceDataSize_Word      (DMA_CCR_SSIZE&0x00000010)
#define IS_DMA_SourceDataSize(SEL)     (((SEL) == DMA_SourceDataSize_Byte) || \
										((SEL) == DMA_SourceDataSize_Half) || \
										((SEL) == DMA_SourceDataSize_Word))   //!<Source data size

/** @defgroup DMA_DestinationDataSize
* @{
*/
#define DMA_DestinationDataSize_Byte      (DMA_CCR_DSIZE&0x00000000)
#define DMA_DestinationDataSize_Half      (DMA_CCR_DSIZE&0x00000080)
#define DMA_DestinationDataSize_Word      (DMA_CCR_DSIZE&0x00000100)
#define IS_DMA_DestinationDataSize(SEL)    (((SEL) == DMA_DestinationDataSize_Byte) || \
											((SEL) == DMA_DestinationDataSize_Half) || \
											((SEL) == DMA_DestinationDataSize_Word))   //!<Destination data size

/** @defgroup DMA_SourceAddressIncrement
* @{
*/
#define DMA_SourceAddressIncrement_Disable    (DMA_CCR_SINC&0x00000000)
#define DMA_SourceAddressIncrement_Enable     (DMA_CCR_SINC&0x00000002)
#define IS_DMA_SourceAddressIncrement(SEL)       (((SEL) == DMA_SourceAddressIncrement_Disable) || \
												  ((SEL) == DMA_SourceAddressIncrement_Enable))

/** @defgroup DMA_DestinationAddressIncrement
* @{
*/
#define DMA_DestinationAddressIncrement_Disable    (DMA_CCR_DINC&0x00000000)
#define DMA_DestinationAddressIncrement_Enable     (DMA_CCR_DINC&0x00000004)
#define IS_DMA_DestinationAddressIncrement(SEL)       (((SEL) == DMA_DestinationAddressIncrement_Disable) || \
													   ((SEL) == DMA_DestinationAddressIncrement_Enable))

/** @defgroup DMA_Direction
* @{
*/
#define DMA_Direction_PeripheralToMemory      (DMA_CCR_DIR&0x00000000)
#define DMA_Direction_MemoryToMemory          (DMA_CCR_DIR&0x00000800)
#define DMA_Direction_MemoryToPeripheral      (DMA_CCR_DIR&0x00002000)
#define IS_DMA_Direction(SEL)       					 (((SEL) == DMA_Direction_PeripheralToMemory) || \
														  ((SEL) == DMA_Direction_MemoryToMemory) || \
														  ((SEL) == DMA_Direction_MemoryToPeripheral))

/** @defgroup DMA_CircularMode
* @{
*/
#define DMA_CircularMode_Disable    (DMA_CCR_CIRC&0x00000000)
#define DMA_CircularMode_Enable     (DMA_CCR_CIRC&0x00004000)
#define IS_DMA_CircularMode(SEL)       (((SEL) == DMA_CircularMode_Disable) || \
										((SEL) == DMA_CircularMode_Enable))


/** @defgroup DMA_BURST
  * @{
  */
#define DMA_Burst_1Unit               (DMA_CCR_BURST&0x0000)
#define DMA_Burst_4Unit               (DMA_CCR_BURST&0x0001)
#define DMA_Burst_8Unit               (DMA_CCR_BURST&0x0002)
#define DMA_Burst_16Unit              (DMA_CCR_BURST&0x0003)
#define IS_DMA_BURST(SEL)             ((SEL) <= DMA_Burst_16Unit)


/** @defgroup DMA_IT
* @{
*/
#define DMA_IT_TC0E               DMA_IER_TC0E
#define DMA_IT_TC1E               DMA_IER_TC1E
#define DMA_IT_TC2E               DMA_IER_TC2E
#define DMA_IT_TC3E               DMA_IER_TC3E
#define DMA_IT_TC4E               DMA_IER_TC4E
#define DMA_IT_TC5E               DMA_IER_TC5E
#define DMA_IT_TE0E               DMA_IER_TE0E
#define DMA_IT_TE1E               DMA_IER_TE1E
#define DMA_IT_TE2E               DMA_IER_TE2E
#define DMA_IT_TE3E               DMA_IER_TE3E
#define DMA_IT_TE4E               DMA_IER_TE4E
#define DMA_IT_TE5E               DMA_IER_TE5E
#define DMA_IT_TH0E               DMA_IER_TH0E
#define DMA_IT_TH1E               DMA_IER_TH1E
#define DMA_IT_TH2E               DMA_IER_TH2E
#define DMA_IT_TH3E               DMA_IER_TH3E
#define DMA_IT_TH4E               DMA_IER_TH4E
#define DMA_IT_TH5E               DMA_IER_TH5E
#define DMA_IT_ALL                ((u32)(0x003F3F3F))
#define IS_DMA_IT(SEL)            ((((SEL) &(~DMA_IT_ALL)) == 0x0) && ((SEL) !=0x0000))

/** @defgroup DMA_FLAG
* @{
*/
#define DMA_FLAG_TC0F           DMA_SR_TC0F
#define DMA_FLAG_TC1F           DMA_SR_TC1F
#define DMA_FLAG_TC2F           DMA_SR_TC2F
#define DMA_FLAG_TC3F           DMA_SR_TC3F
#define DMA_FLAG_TC4F           DMA_SR_TC4F
#define DMA_FLAG_TC5F           DMA_SR_TC5F
#define DMA_FLAG_TE0F           DMA_SR_TE0F
#define DMA_FLAG_TE1F           DMA_SR_TE1F
#define DMA_FLAG_TE2F           DMA_SR_TE2F
#define DMA_FLAG_TE3F           DMA_SR_TE3F
#define DMA_FLAG_TE4F           DMA_SR_TE4F
#define DMA_FLAG_TE5F           DMA_SR_TE5F
#define DMA_FLAG_C0THF          DMA_SR_C0THF
#define DMA_FLAG_C1THF          DMA_SR_C1THF
#define DMA_FLAG_C2THF          DMA_SR_C2THF
#define DMA_FLAG_C3THF          DMA_SR_C3THF
#define DMA_FLAG_C4THF          DMA_SR_C4THF
#define DMA_FLAG_C5THF          DMA_SR_C5THF
#define DMA_FLAG_CEF            DMA_SR_CEF
#define DMA_FLAG_ALL            ((u32)(0x803F3F3F))

#define IS_DMA_FLAG(SEL)    ((((SEL) &(~DMA_FLAG_ALL)) == 0x0) && ((SEL) !=0x0000))


/** @defgroup DMA_ChannelxPERIPH
* @{
*/

#define DMA_ChannelPERIPH_SPI0TX                 (DMA_CHAPCR1_CH0SEL&0x00000000)
#define DMA_ChannelPERIPH_SPI0RX                 (DMA_CHAPCR1_CH0SEL&0x00000001)
#define DMA_ChannelPERIPH_SPI1TX                 (DMA_CHAPCR1_CH0SEL&0x00000002)
#define DMA_ChannelPERIPH_SPI1RX                 (DMA_CHAPCR1_CH0SEL&0x00000003)
#define DMA_ChannelPERIPH_UART0TX                (DMA_CHAPCR1_CH0SEL&0x0000000D)
#define DMA_ChannelPERIPH_UART0RX                (DMA_CHAPCR1_CH0SEL&0x0000000E)
#define DMA_ChannelPERIPH_UART1TX                (DMA_CHAPCR1_CH0SEL&0x0000000F)
#define DMA_ChannelPERIPH_UART1RX                (DMA_CHAPCR1_CH0SEL&0x00000010)
#define DMA_ChannelPERIPH_LPUART0TX              (DMA_CHAPCR1_CH0SEL&0x00000011)
#define DMA_ChannelPERIPH_LPUART0RX              (DMA_CHAPCR1_CH0SEL&0x00000012)
#define DMA_ChannelPERIPH_LPUART1TX              (DMA_CHAPCR1_CH0SEL&0x00000013)
#define DMA_ChannelPERIPH_LPUART1RX              (DMA_CHAPCR1_CH0SEL&0x00000014)
#define DMA_ChannelPERIPH_UART2TX                (DMA_CHAPCR1_CH0SEL&0x00000015)
#define DMA_ChannelPERIPH_UART2RX                (DMA_CHAPCR1_CH0SEL&0x00000016)
#define DMA_ChannelPERIPH_UART3TX                (DMA_CHAPCR1_CH0SEL&0x00000017)
#define DMA_ChannelPERIPH_UART3RX                (DMA_CHAPCR1_CH0SEL&0x00000018)
#define DMA_ChannelPERIPH_ADC                    (DMA_CHAPCR1_CH0SEL&0x00000019)

#define DMA_ChannelPERIPH_TIM1_AREV_OR_UEV       (DMA_CHAPCR1_CH0SEL&0x00000020)
#define DMA_ChannelPERIPH_TIM1_TEV               (DMA_CHAPCR1_CH0SEL&0x00000021)
#define DMA_ChannelPERIPH_TIM1_OC1_OR_IC1        (DMA_CHAPCR1_CH0SEL&0x00000022)
#define DMA_ChannelPERIPH_TIM1_OC2_OR_IC2        (DMA_CHAPCR1_CH0SEL&0x00000023)
#define DMA_ChannelPERIPH_TIM1_OC3_OR_IC3        (DMA_CHAPCR1_CH0SEL&0x00000024)
#define DMA_ChannelPERIPH_TIM1_OC4_OR_IC4        (DMA_CHAPCR1_CH0SEL&0x00000025)

#define DMA_ChannelPERIPH_TIM5_AREV_OR_UEV       (DMA_CHAPCR1_CH0SEL&0x00000026)
#define DMA_ChannelPERIPH_TIM5_TEV               (DMA_CHAPCR1_CH0SEL&0x00000027)
#define DMA_ChannelPERIPH_TIM5_OC1_OR_IC1        (DMA_CHAPCR1_CH0SEL&0x00000028)

#define DMA_ChannelPERIPH_TIM6_AREV_OR_UEV       (DMA_CHAPCR1_CH0SEL&0x00000029)
#define DMA_ChannelPERIPH_TIM6_TEV               (DMA_CHAPCR1_CH0SEL&0x0000002A)
#define DMA_ChannelPERIPH_TIM6_OC1_OR_IC1        (DMA_CHAPCR1_CH0SEL&0x0000002B)

#define DMA_ChannelPERIPH_TIM7_AREV_OR_UEV       (DMA_CHAPCR1_CH0SEL&0x0000002C)
#define DMA_ChannelPERIPH_TIM7_TEV               (DMA_CHAPCR1_CH0SEL&0x0000002D)
#define DMA_ChannelPERIPH_TIM7_OC1_OR_IC1        (DMA_CHAPCR1_CH0SEL&0x0000002E)

#define DMA_ChannelPERIPH_TIM8_AREV_OR_UEV       (DMA_CHAPCR1_CH0SEL&0x0000002F)
#define DMA_ChannelPERIPH_TIM8_TEV               (DMA_CHAPCR1_CH0SEL&0x00000030)
#define DMA_ChannelPERIPH_TIM8_OC1_OR_IC1        (DMA_CHAPCR1_CH0SEL&0x00000031)
#define DMA_ChannelPERIPH_TIM8_OC2_OR_IC2        (DMA_CHAPCR1_CH0SEL&0x00000032)
#define DMA_ChannelPERIPH_TIM8_OC3_OR_IC3        (DMA_CHAPCR1_CH0SEL&0x00000033)
#define DMA_ChannelPERIPH_TIM8_OC4_OR_IC4        (DMA_CHAPCR1_CH0SEL&0x00000034)

#define DMA_ChannelPERIPH_LPTIM_AREV_OR_UEV      (DMA_CHAPCR1_CH0SEL&0x00000035)
#define DMA_ChannelPERIPH_LPTIM_TEV              (DMA_CHAPCR1_CH0SEL&0x00000036)
#define DMA_ChannelPERIPH_LPTIM_OC1_OR_IC1       (DMA_CHAPCR1_CH0SEL&0x00000037)
#define DMA_ChannelPERIPH_LPTIM_IC2              (DMA_CHAPCR1_CH0SEL&0x00000038)

#define IS_DMA_ChannelxPERIPH(SEL)               ((((SEL) &(~DMA_CHAPCR1_CH0SEL)) == 0x0) && (( (  (SEL) >= DMA_ChannelPERIPH_UART0TX)&& ( (SEL) <= DMA_ChannelPERIPH_LPTIM_IC2) )  ||  ((SEL)<=DMA_ChannelPERIPH_SPI1TX)    ))


/*! function declaration and definition*/
void DMA_Init(DMA_Channel_TypeDef *DMA_Channelx, DMA_InitTypeDef *DMA_InitStruct);
void DMA_StructInit(DMA_InitTypeDef *DMA_InitStruct);
void DMA_Cmd(DMA_Channel_TypeDef *DMA_Channelx, FunctionalState NewState);
u32 DMA_GetCurrentSourceAddress(DMA_Channel_TypeDef *DMA_Channelx);
u32 DMA_GetCurrentDestinationAddress(DMA_Channel_TypeDef *DMA_Channelx);
u16 DMA_GetNumberOfData(DMA_Channel_TypeDef *DMA_Channelx);
void DMA_ITConfig(DMA_TypeDef *DMAx, u32 DMA_IT, FunctionalState NewState);
void DMA_ClearITFlag(DMA_TypeDef *DMAx, u32 DMA_FLAG);
FlagStatus DMA_GetFlagStatus(DMA_TypeDef *DMAx, u32 DMA_FLAG);
void DMA_PeripheralConfig(DMA_TypeDef *DMAx, DMA_ChannelNum ch, u32 Peripheral);


#ifdef __cplusplus
}
#endif

#endif /*__PT32x076_DMA_H */
