/********************************************************************************
  * @file    PT32x076_iwdg.h
  * @author  ӦÿŶ
  * @version V1.0.0
  * @date    2023/7/15
  * @brief   This file contains all the functions prototypes for the IWDG firmware
  *          library
  * @attention
  *
  * ǰĹָ̼, ĿͻṩйƷıϢ,Խʡǵʱ䡣
  * ̼/ͻʹаıϢκ, * Pai-IC κֱӣӻ̷𺦸
  *
  * (C) Ȩ Pai-IC Microelectronics
  *******************************************************************************/
#ifndef PT32x076_IWDG_H
#define PT32x076_IWDG_H

#ifdef __cplusplus
extern "C" {
#endif

#include "PT32x076.h"

#define KR_KEY_DISABLE   		((u32)0xFFFFFFFF)

/** @defgroup WDG_ALL_PERIPH
* @{
*/
#define IS_WDG_ALL_PERIPH(SEL)     ((SEL) == IWDG)

/** @defgroup WDG_LockKey
* @{
*/
#define WDG_LockKey_Unlock        ((u32)0x1ACCE551)
#define WDG_LockKey_Lock          ((u32)0x00000000)
#define IS_WDG_LockKey(SEL)				 (((SEL) == WDG_LockKey_Unlock) || \
										  ((SEL) == WDG_LockKey_Lock))

/** @defgroup WDG_FLAG
* @{
*/
typedef enum
{
	WDG_FLAG_HungryDog   = 0x00,
	WDG_FLAG_LockStatus,
} WDG_FLAG;
#define IS_WDG_FLAG(SEL)			 (((SEL) == WDG_FLAG_HungryDog) || \
									  ((SEL) == WDG_FLAG_LockStatus))

#define WDG_StatusBit       ((u32)0x00000001)


/** @defgroup WDG_ReloadValue
* @{
*/
#define IS_WDG_ReloadValue(SEL) ((SEL) <= 0xFFFFFFFF)

/** @defgroup WDG_clock soure_selection
  * @{
  */
#define WDG_ClockSource_LSI            (IWDG_CR_CLKS&0x00)
#define WDG_ClockSource_LSE            (IWDG_CR_CLKS&0x08)
#define IS_WDG_ClockSource(SEL)        (((SEL) == WDG_ClockSource_LSI) || \
										((SEL) == WDG_ClockSource_LSE))




/*! function declaration and definition*/
void IWDG_LockCmd(IWDG_TypeDef *WDGx, u32 WDG_WriteAccess);
void IWDG_SetReload(IWDG_TypeDef *WDGx, u32 Reload);
void IWDG_ReloadCounter(IWDG_TypeDef *WDGx);
void IWDG_Cmd(IWDG_TypeDef *WDGx, FunctionalState NewState);
FlagStatus IWDG_GetFlagStatus(IWDG_TypeDef *WDGx, WDG_FLAG Flag);
void IWDG_ResetCmd(IWDG_TypeDef *WDGx, FunctionalState NewState);
void IWDG_DBGPendingCmd(IWDG_TypeDef *WDGx, FunctionalState NewState);
void IWDG_ClockSourceConfig(IWDG_TypeDef *WDGx, u8 ClockSource);
#ifdef __cplusplus
}
#endif

#endif /*__PT32x076_WDG_H */
