/********************************************************************************
  * @file    PT32x076_lcd.h
  * @author  ӦÿŶ
  * @version V1.0.0
  * @date    2023/7/15
  * @brief   This file contains all the functions prototypes for the LCD firmware
  *          library
  * @attention
  *
  * ǰĹָ̼, ĿͻṩйƷıϢ,Խʡǵʱ䡣
  * ̼/ͻʹаıϢκ, * Pai-IC κֱӣӻ̷𺦸
  *
  * (C) Ȩ Pai-IC Microelectronics
  *******************************************************************************/

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef PT32x076_LCD_H
#define PT32x076_LCD_H

#ifdef __cplusplus
extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x076.h"

/* Exported types ------------------------------------------------------------*/
/** @defgroup LCD_InitTypeDef
* @{ 
*/
typedef struct
{
	u32 LCD_DriveVoltageType;		/*!< Specifies the type of drive voltage.
																		This parameter can be value of @ref LCD_DriveVoltageType */
	
	u32 LCD_Duty;								/*!< Specifies the duty.
																		This parameter can be value of @ref LCD_Duty */
	
	u32 LCD_Wave;								/*!< Specifies the wave control.
																		This parameter can be value of @ref LCD_WaveControl */
	
	u32 LCD_ClkSource;					/*!< Specifies the clock source.
																		This parameter can be value of @ref LCD_ClkSource */
	
  u32 LCD_PageDisplayMode;		/*!< Specifies the page display mode.
																		This parameter can be value of @ref LCD_Screen_Control_Mode */
	
	u32 LCD_TotalResistance;		/*!< Specifies the total resistance.
																		This parameter can be value of @ref LCD_TotalResistance */
	
} LCD_InitTypeDef;

/* Exported constants --------------------------------------------------------*/

/** @defgroup LCD_DriveVoltageType
* @{ 
*/
#define LCD_DriveVoltageType_R	          0x10000
#define LCD_DriveVoltageType_C	          0x00000
#define LCD_DriveVoltageType_REXT	      0x20000
#define IS_LCD_CRTYPE_SEL(SEL)	         (((SEL)& ~LCD_CR_TYPE) == 0 && (SEL) <= LCD_DriveVoltageType_REXT)


/** @defgroup LCD_Duty
* @{ 
*/
#define LCD_Duty_2	                      0x00
#define LCD_Duty_4	                      0x04
#define LCD_Duty_6	                      0x08
#define LCD_Duty_8	                      0x0C
#define IS_LCD_DUTY_SEL(SEL)	         (((SEL) & ~LCD_CR_DUTY) == 0  &&  (SEL) <= LCD_Duty_8)

/** @defgroup LCD_Wave
* @{ 
*/
#define LCD_Wave_A		                  0x00
#define LCD_Wave_B		                  0x10
#define IS_LCD_WAVE_SEL(SEL)	          (((SEL) & ~LCD_CR_WAVE) == 0 && (SEL) <= LCD_Wave_B)

/** @defgroup LCD_ClkSource
* @{ 
*/
#define LCD_ClkSource_LSI		           0x00
#define LCD_ClkSource_LSE		           0x40
#define IS_LCD_CLK_SEL(SEL)	            (((SEL) & ~LCD_CR_CLKS) ==0  && (SEL) <= LCD_ClkSource_LSE)


#define LCD_ScreenControlMode_None	        0x000
#define LCD_ScreenControlMode_Blink	        0x200
#define LCD_ScreenControlMode_ON	          0x400
#define LCD_ScreenControlMode_OFF	          0x600
#define IS_LCD_SCM_SEL(SEL)           (((SEL) & ~ LCD_CR_SCM) == 0  && (SEL) <= LCD_ScreenControlMode_OFF)


/** @defgroup LCD_PageDisplayMode
* @{ 
*/
#define LCD_PageDisplayMode_Fixed		   	 0x0000
#define LCD_PageDisplayMode_Round		   	 0x1000
#define LCD_PageDisplayMode_RoundOFF	   0x2000
#define LCD_PageDisplayMode_Continue	   0x3000
#define IS_LCD_PDM_SEL(SEL)	         (((SEL) & ~LCD_CR_PDM) == 0 && (SEL) <= LCD_PageDisplayMode_Continue)

/** @defgroup LCD_TotalResistance
* @{ 
*/
#define LCD_TotalResistance_45k	        (LCD_CR_RSEL&0x00000000)
#define LCD_TotalResistance_360k	      (LCD_CR_RSEL&0x00008000)
#define IS_LCD_RSEL_SEL(SEL)	            (((SEL) & ~LCD_CR_RSEL) == 0 && (SEL) <= LCD_TotalResistance_360k)

/** @defgroup LCD_PAGEs/REGs
* @{ 
*/
#define LCD_MAX_PAGES                      16
#define LCD_PAGE_REGS                      11   // 44/4

/** @defgroup LCD_Page_SEL
* @{ 
*/
#define LCD_Page_0	0
#define LCD_Page_1	1
#define LCD_Page_2	2
#define LCD_Page_3	3
#define LCD_Page_4	4
#define LCD_Page_5	5
#define LCD_Page_6	6
#define LCD_Page_7	7
#define LCD_Page_8	8
#define LCD_Page_9	9
#define LCD_Page_10	10
#define LCD_Page_11	11
#define LCD_Page_12	12
#define LCD_Page_13	13
#define LCD_Page_14	14
#define LCD_Page_15	15
#define IS_LCD_Page_SEL(SEL)	       ((SEL) <= LCD_Page_15)

/** @defgroup LCD_PinSource_SEL
* @{ 
*/
#define LCD_PinSource0			0
#define LCD_PinSource1			1
#define LCD_PinSource2			2
#define LCD_PinSource3			3
#define LCD_PinSource4			4
#define LCD_PinSource5			5
#define LCD_PinSource6			6
#define LCD_PinSource7			7
#define LCD_PinSource8			8
#define LCD_PinSource9			9
#define LCD_PinSource10			10
#define LCD_PinSource11			11
#define LCD_PinSource12			12
#define LCD_PinSource13			13
#define LCD_PinSource14			14
#define LCD_PinSource15			15
#define LCD_PinSource16			16
#define LCD_PinSource17			17
#define LCD_PinSource18			18
#define LCD_PinSource19			19
#define LCD_PinSource20			20
#define LCD_PinSource21			21
#define LCD_PinSource22			22
#define LCD_PinSource23			23
#define LCD_PinSource24			24
#define LCD_PinSource25			25
#define LCD_PinSource26			26
#define LCD_PinSource27			27
#define LCD_PinSource28			28
#define LCD_PinSource29			29
#define LCD_PinSource30			30
#define LCD_PinSource31			31
#define LCD_PinSource32			32
#define LCD_PinSource33			33
#define LCD_PinSource34			34
#define LCD_PinSource35			35
#define LCD_PinSource36			36
#define LCD_PinSource37			37
#define LCD_PinSource38			38
#define LCD_PinSource39			39
#define LCD_PinSource40			40
#define LCD_PinSource41			41
#define LCD_PinSource42			42
#define LCD_PinSource43			43
#define IS_LCD_PinSource_SEL(SEL)	             ((SEL) <= LCD_PinSource43)

/** @defgroup LCD_PIN_SEL
* @{ 
*/
#define LCD_PIN_0	              	((u64)0x00000000001)
#define LCD_PIN_1	              	((u64)0x00000000002)
#define LCD_PIN_2	              	((u64)0x00000000004)
#define LCD_PIN_3	              	((u64)0x00000000008)
#define LCD_PIN_4	             	 	((u64)0x00000000010)
#define LCD_PIN_5	              	((u64)0x00000000020)
#define LCD_PIN_6	              	((u64)0x00000000040)
#define LCD_PIN_7	              	((u64)0x00000000080)
#define LCD_PIN_8	              	((u64)0x00000000100)
#define LCD_PIN_9	              	((u64)0x00000000200)
#define LCD_PIN_10	              ((u64)0x00000000400)
#define LCD_PIN_11	              ((u64)0x00000000800)
#define LCD_PIN_12	              ((u64)0x00000001000)
#define LCD_PIN_13	              ((u64)0x00000002000)
#define LCD_PIN_14	              ((u64)0x00000004000)
#define LCD_PIN_15	              ((u64)0x00000008000)
#define LCD_PIN_16	              ((u64)0x00000010000)
#define LCD_PIN_17	              ((u64)0x00000020000)
#define LCD_PIN_18	              ((u64)0x00000040000)
#define LCD_PIN_19	              ((u64)0x00000080000)
#define LCD_PIN_20	              ((u64)0x00000100000)
#define LCD_PIN_21	              ((u64)0x00000200000)
#define LCD_PIN_22	              ((u64)0x00000400000)
#define LCD_PIN_23	              ((u64)0x00000800000)
#define LCD_PIN_24	              ((u64)0x00001000000)
#define LCD_PIN_25	              ((u64)0x00002000000)
#define LCD_PIN_26	              ((u64)0x00004000000)
#define LCD_PIN_27	              ((u64)0x00008000000)
#define LCD_PIN_28	              ((u64)0x00010000000)
#define LCD_PIN_29	              ((u64)0x00020000000)
#define LCD_PIN_30	              ((u64)0x00040000000)
#define LCD_PIN_31	              ((u64)0x00080000000)
#define LCD_PIN_32	              ((u64)0x00100000000)
#define LCD_PIN_33	              ((u64)0x00200000000)
#define LCD_PIN_34	              ((u64)0x00400000000)
#define LCD_PIN_35	              ((u64)0x00800000000)
#define LCD_PIN_36	              ((u64)0x01000000000)
#define LCD_PIN_37	              ((u64)0x02000000000)
#define LCD_PIN_38	              ((u64)0x04000000000)
#define LCD_PIN_39	              ((u64)0x08000000000)
#define LCD_PIN_40	              ((u64)0x10000000000)
#define LCD_PIN_41	              ((u64)0x20000000000)
#define LCD_PIN_42	              ((u64)0x40000000000)
#define LCD_PIN_43	              ((u64)0x80000000000)
#define LCD_PIN_MASK	          ((u64)0xFFFFFFFFFFF)
#define IS_LCD_PIN_SEL(SEL)	             (((SEL) & LCD_PIN_MASK) != 0)

/** @defgroup LCD_COM_SEL
* @{ 
*/
#define LCD_COM_0	0x01
#define LCD_COM_1	0x02
#define LCD_COM_2	0x04
#define LCD_COM_3	0x08
#define LCD_COM_4	0x10
#define LCD_COM_5	0x20
#define LCD_COM_6	0x40
#define LCD_COM_7	0x80
#define IS_LCD_COM_SEL(SEL)	             ((SEL) <= LCD_COM_7)

/** @defgroup LCD_GDR_SEL
* @{ 
*/
#define LCD_Grayscale100	         0x0E
#define LCD_Grayscale92		         0x0C
#define LCD_Grayscale85		         0x0A
#define LCD_Grayscale80		         0x08
#define LCD_Grayscale75		         0x06
#define LCD_Grayscale70		         0x04
#define LCD_Grayscale66	         	 0x02
#define LCD_Grayscale63	         	 0x00
#define IS_LCD_GDR(SEL)	         (((SEL) & ~LCD_GCR_GDR)==0 && (SEL) <= LCD_Grayscale100)

/** @defgroup LCD_PSC_SEL
* @{ 
*/
#define IS_LCD_PSC_SEL(SEL)	             ((SEL) < 32)

/** @defgroup LCD_BTCR_SEL
* @{ 
*/
#define IS_LCD_BTCR_SEL(SEL)	         ((SEL) < 256)

/** @defgroup LCD_BON_SEL
* @{ 
*/
#define IS_LCD_BON_SEL(SEL)	             ((SEL) < 256)

/** @defgroup LCD_DRIVER_SEL
* @{ 
*/
#define LCD_DRIVER_SEG                    0
#define LCD_DRIVER_COM                    1
#define IS_LCD_DRIVER_SEL(SEL)	          ((SEL) == LCD_DRIVER_SEG || (SEL) == LCD_DRIVER_COM)

/** @defgroup LCD_PDTR_SEL
* @{ 
*/
#define IS_LCD_PDTR_SEL(SEL)	          ((SEL) < 256)

/** @defgroup LCD_SDP_SEL
* @{ 
*/
#define IS_LCD_SDPR_SEL(SEL)	             ((SEL) < 16)

/** @defgroup LCD_PNR_SEL
* @{ 
*/
#define IS_LCD_PNR_SEL(SEL)	             ((SEL) < 16)

/* Exported macro ------------------------------------------------------------*/
/* Exported functions ---------------------------------------------------------*/
void LCD_Init(LCD_InitTypeDef *LCD_InitStruct);
void LCD_StructInit(LCD_InitTypeDef *LCD_InitStruct);
void LCD_ScreenControlModeConfig(u32 mode);
void LCD_ClearAllPages(void);
void LCD_ClearPage(u32 Page_Data);
void LCD_SetDisplayCOM(u32 LCD_PIN, u32 LCD_COM, FunctionalState NEWState);
void LCD_Cmd(FunctionalState NewState);
void LCD_UpdataCmd(FunctionalState NewState);
void LCD_GrayscaleCmd(FunctionalState NewState);
void LCD_Grayscale(uint16_t Gray_Rate);
void LCD_Prescaler(u32 PSC);
void LCD_BlinkTime(u32 BT);
void LCD_BlinkingLightingTime(u32 ON);
void LCD_PinConfig(u64 LCD_Pin, FunctionalState NewState);
void LCD_PinDriverConfig(u64 LCD_Pin, u8 driver);
void LCD_PageDisplayTime(u16 Display_Time);
void LCD_ScrollDisplayPage(u8 Max_Page);
void LCD_PageNumberConfig(u8 Page_Number);
FlagStatus LCD_GetBusyStatus(void);

/**
  * @}
  */


#ifdef __cplusplus
}
#endif

#endif


