/********************************************************************************
  * @file    PT32x076_rcc.h
  * @author  ӦÿŶ
  * @version V1.0.0
  * @date    2023/7/15
  * @brief   This file contains all the functions prototypes for the RCC firmware
  *          library
  * @attention
  *
  * ǰĹָ̼, ĿͻṩйƷıϢ,Խʡǵʱ䡣
  * ̼/ͻʹаıϢκ, * Pai-IC κֱӣӻ̷𺦸
  *
  * (C) Ȩ Pai-IC Microelectronics
  *******************************************************************************/

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef PT32x076_RCC_H
#define PT32x076_RCC_H

#ifdef __cplusplus
extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x076.h"

/** @addtogroup RCC
  * @{
  */

/* Exported types ------------------------------------------------------------*/


/* Exported constants --------------------------------------------------------*/
/** @defgroup RCC_Clock_Frequency_Selection
  * @{
  */

	
#define RCC_SYSCLK									 ((u8)0x01)
#define RCC_HCLK										 ((u8)0x02)
#define RCC_PCLK										 ((u8)0x03)
#define RCC_HSI  										 ((u8)0x04)
#define RCC_LSI  										 ((u8)0x05)
#define RCC_LSE  										 ((u8)0x06)
#define IS_RCC_Clock(SEL)   				 ((SEL)<=0x6)
/**
  * @}
  */

/** @defgroup RCC_clock_output_source
  * @{
  */
#define RCC_ClockOutput_HSI			    (RCC_MCOR_COSRC&0x00)
#define RCC_ClockOutput_HSE			    (RCC_MCOR_COSRC&0x10)
#define RCC_ClockOutput_PLL			    (RCC_MCOR_COSRC&0x20)
#define RCC_ClockOutput_LSI			    (RCC_MCOR_COSRC&0x30)
#define RCC_ClockOutput_SYSCLK			(RCC_MCOR_COSRC&0x40)
#define RCC_ClockOutput_LSE			    (RCC_MCOR_COSRC&0x50)
#define RCC_ClockOutput_None		    (RCC_MCOR_COSRC&0x70)
#define IS_RCC_ClockOutputSource(SEL)   	((((SEL)&~RCC_MCOR_COSRC)==0) && ((SEL) <=RCC_ClockOutput_None))
/**
  * @}
  */

/** @defgroup RCC_PLL_clock_source
  * @{
  */
#define RCC_PLLClockSource_HSI	(RCC_PLLCFGR1_SRC&0x0)
#define RCC_PLLClockSource_HSE	(RCC_PLLCFGR1_SRC&0x2)
#define IS_RCC_PLLClockSource(SEL)   	(((SEL) == RCC_PLLClockSource_HSI)   || \
										 ((SEL) == RCC_PLLClockSource_HSE))
/**
  * @}
  */

/** @defgroup RCC_system_clock_switch_source
  * @{
  */
#define RCC_SystemClock_HSI					(RCC_CFGR_SCW&0x00) 	//Internal Hight CLK Source
#define RCC_SystemClock_HSE					(RCC_CFGR_SCW&0x01) 	//Extern Hight CLK Source
#define RCC_SystemClock_PLL					(RCC_CFGR_SCW&0x02)		//Extern Low CLK Source
#define IS_RCC_SystemClock(SEL) 			(((SEL) == RCC_SystemClock_HSI)   || \
											 ((SEL) == RCC_SystemClock_HSE) 	|| \
											 ((SEL) == RCC_SystemClock_PLL))

#define RCC_ClockSource_HSI											(0x00) 	//Internal Hight CLK Source
#define RCC_ClockSource_HSE 										(0x01) 	//Extern Hight CLK  Source
#define RCC_ClockSource_HSEExternal							(0x02) 	//Extern Hight CLK Source
#define RCC_ClockSource_PLL											(0x03)	//Extern Low CLK Source
#define RCC_ClockSource_LSI											(0x04) 	//Internal Low CLK Source
#define RCC_ClockSource_LSE											(0x05) 	//Extern Low CLK Source
#define RCC_ClockSource_LSEExternal							(0x06) 	//Extern Low CLK Source

#define IS_RCC_ClockSource(SEL) 			((SEL) <=RCC_ClockSource_LSEExternal)
/**
  * @}
  */

/** @defgroup RCC_Reset_State_Flag
  * @{
  */
#define RCC_FLAG_SFR       		 			 RCC_RSR_SFR
#define RCC_FLAG_IWDG       				 RCC_RSR_IWDG
#define RCC_FLAG_HSE      					 RCC_RSR_HSE
#define RCC_FLAG_PLL       		  		 RCC_RSR_PLL
#define RCC_FLAG_POR       			 		 RCC_RSR_POR
#define RCC_FLAG_PIN      		 			 RCC_RSR_PIN
#define RCC_FLAG_PVD     			  		 RCC_RSR_PVD
#define RCC_FLAG_CWR       			 		 RCC_RSR_CWR
#define RCC_FLAG_CPU      		 			 RCC_RSR_CPU
#define RCC_FLAG_RTC     					   RCC_RSR_RTC
#define RCC_FLAG_WWDG     					 RCC_RSR_WWDG
#define RCC_FLAG_ALL     						 (u32)(0x6D7B) 
#define IS_RCC_ResetStatusFlag(SEL)       ((((SEL) & ~RCC_FLAG_ALL) == 0) && ((SEL) !=0x0000))
/**
  * @}
  */

/** @defgroup RCC_Reset_selection
  * @{
  */
#define RCC_ResetEnable_PVDLowVoltage       	  RCC_RCR_PDRE
#define IS_RCC_ResetEnable(SEL)   		         ((SEL)==RCC_ResetEnable_PVDLowVoltage)
/**
  * @}
  */

/** @defgroup RCC_Key_selection
  * @{
  */

#define RCC_AdvancedSoftwareReset_CWR 	(u8)(0x00)
#define RCC_AdvancedSoftwareReset_CPU	  (u8)(0x01)
#define RCC_AdvancedSoftwareReset_RTC	  (u8)(0x02)
#define RCC_KEY_CWR    									(u16)0xCD23
#define RCC_KEY_CPU    									(u16)0xC57A
#define RCC_KEY_RTC    									(u16)0x695A

#define IS_RCC_AdvancedSoftwareReset(SEL)   ((SEL == RCC_AdvancedSoftwareReset_CWR)  || \
											 (SEL == RCC_AdvancedSoftwareReset_CPU)  || \
											 (SEL == RCC_AdvancedSoftwareReset_RTC))
/** @defgroup RCC_HCLK_prescaler_value
  * @{
  */
#define IS_RCC_HCLKPrescaler(SEL)   	 ((SEL) <= 31)
/**
  * @}
  */

/** @defgroup RCC_PCLK_prescaler_value
  * @{
  */
#define IS_RCC_PCLKPrescaler(SEL)   	 ((SEL) <= 31)
/**
  * @}
  */

/** @defgroup RCC_clock_output_Prescale_value
  * @{
  */
#define RCC_ClockOutputPrescale_None      	(RCC_MCOR_COPRE&0x00)
#define RCC_ClockOutputPrescale_2      		  (RCC_MCOR_COPRE&0x01)
#define RCC_ClockOutputPrescale_4      		  (RCC_MCOR_COPRE&0x02)
#define RCC_ClockOutputPrescale_8      		  (RCC_MCOR_COPRE&0x03)
#define RCC_ClockOutputPrescale_16      		(RCC_MCOR_COPRE&0x04)
#define IS_RCC_ClockOutputPrescale(SEL)   	((SEL) <=RCC_ClockOutputPrescale_16)
/**
  * @}
  */

/** @defgroup RCC_system_clock_after_wakeup_selection
  * @{
  */
#define RCC_SystemClockAfterWakeUp_HSI						(RCC_CFGR_SCWK&0x000000)
#define RCC_SystemClockAfterWakeUp_PreviousClock	(RCC_CFGR_SCWK&0x100000)
#define IS_RCC_SystemClockAfterWakeUp(SEL)   	    (((SEL) == RCC_SystemClockAfterWakeUp_HSI) ||\
													 ((SEL) == RCC_SystemClockAfterWakeUp_PreviousClock))
													 
#define RCC_FlashWakeUp_Normal            (RCC_CFGR_FWUS&0x00000000)
#define RCC_FlashWakeUp_Fast               RCC_CFGR_FWUS
#define IS_RCC_FlashWakeUp_Mode(SEL)           (((SEL) == RCC_FlashWakeUp_Normal) || ((SEL) == RCC_FlashWakeUp_Fast))													 
/**
  * @}
  */

/* Exported macro ------------------------------------------------------------*/
/* Exported functions ---------------------------------------------------------*/
u32 RCC_GetClockFreq(u8 RCC_Clock);
FlagStatus RCC_GetResetFlagStatus(u32 RCC_FLAG);
void RCC_ClearResetFlag(u32 RCC_FLAG);
void RCC_ResetConfig(u32 ResetSource, FunctionalState NewState);
void RCC_ClockSourceConfig(u32 ClockSource, FunctionalState NewState);
void RCC_AdvancedSoftwareReset(u8 RCC_AdvancedSoftwareResetSource);
void RCC_SetSystemClock(u32 SystemClockSwitch);
void RCC_SetSystemClockAfterWakeUp(u32 Clock);
void RCC_PLLClockSourceConfig(u32 PLLClockSource);
void RCC_HCLKSetPrescaler(u32 Prescaler);
void RCC_PCLKSetPrescaler(u32 Prescaler);
u8 RCC_GetSystemClockSelection(void);
void RCC_SetMCOSource(u32 ClockSource);
void RCC_MCOSetPrescaler(u32 PrescaleSelcection);
void RCC_FlashWakeUpMode(u32 FlashWakeUpMode);

void CLOCK_Cmd(void);
void CLOCK_PLLConfig(void);
void IFMC_WaitConfig(void);
void CLOCK_SystemClockConfig(void);
void CLOCK_MCOConfig(void);
u32  clk_get_sysclk(void);
void SystemInit(void);


/**
  * @}
  */

#ifdef __cplusplus
}
#endif

#endif /*__PT32x076_RCC_H */
