/********************************************************************************
  * @file    PT32x076_rtc.h
  * @author  ӦÿŶ
  * @version V1.0.0
  * @date    2023/7/15
  * @brief   This file contains all the functions prototypes for the RTC firmware
  *          library
  * @attention
  *
  * ǰĹָ̼, ĿͻṩйƷıϢ,Խʡǵʱ䡣
  * ̼/ͻʹаıϢκ, * Pai-IC κֱӣӻ̷𺦸
  *
  * (C) Ȩ Pai-IC Microelectronics
  *******************************************************************************/
	
/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef PT32x076_RTC_H
#define PT32x076_RTC_H

#ifdef __cplusplus
extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "PT32x076.h"


/** @addtogroup RTC
  * @{
  */ 
  
/* Exported types ------------------------------------------------------------*/

/** @defgroup RTC_InitTypeDef
* @{ 
*/
typedef struct
{
	u32 RTC_TF;         /*!< Specifies the RTC Time Format
												   This parameter can be a value of @ref RTC_TimeFormat_Selection */
	
	u32 RTC_ClkSource;  /*!< Specifies the RTC Clock Source
												   This parameter can be a value of @ref RTC_ClockSource */
	
	u32 RTC_BeaconOut;  /*!< Specifies the RTC Beacon Out
												   This parameter can be a value of @ref RTC_BeaconOut */
	
	u32 RTC_TrimMode;   /*!< Specifies the RTC Trim Mode
												   This parameter can be a value of @ref RTC_TrimMode */
	
} RTC_InitTypeDef;

/** @defgroup RTC_Calendar
* @{ 
*/
typedef struct
{
    u16 Year;         /*!< Specifies the RTC Calendar Year value
														This parameter can be a number between 2000 and 9999 (DEC Format)*/
	
    u8 Month;         /*!< Specifies the RTC Calendar Month value
														This parameter can be a number between 1 and 12 (DEC Format)*/
	
    u8 Day;           /*!< Specifies the RTC Calendar Day value
														This parameter can be a number between 1 and 31 (DEC Format)*/
	
    u8 Week;          /*!< Specifies the RTC Calendar Week value
														This parameter can be a number between 1 and 7 (DEC Format)*/
	
    u8 Hour;          /*!< Specifies the RTC Calendar Hour value
														This parameter can be a number between 0 and 23 (DEC Format)*/ 
	
    u8 Minute;        /*!< Specifies the RTC Calendar Minute value
														This parameter can be a number between 0 and 59 (DEC Format)*/ 
	
    u8 Second;        /*!< Specifies the RTC Calendar Second value
														This parameter can be a number between 0 and 59 (DEC Format)*/
	
	  u8 PM;						/*!< Specifies the RTC Calendar PM value
														This parameter can be a value of @ref RTC_AM_PM */
	
    u8 TimeFormat;    /*!< Specifies the RTC Calendar Time Format
														This parameter can be a value of @ref RTC_TimeFormat */  
	
} RTC_Calendar;

/** @defgroup RTC_Alarm
* @{ 
*/
typedef struct
{
    u8 Hour;           /*!< Specifies the RTC Alarm Hour value
														This parameter can be a number between 0 and 23 (DEC Format)*/
	
    u8 Minute;         /*!< Specifies the RTC Alarm Minute value
														This parameter can be a number between 0 and 59 (DEC Format)*/
	
    u8 Second;         /*!< Specifies the RTC Alarm Second value
														This parameter can be a number between 0 and 59 (DEC Format)*/
	
	  u8 Week; 					 /*!< Specifies the RTC Alarm Week value
														This parameter can be a number between 1 and 7 (DEC Format)*/
	
    u8 PM;						 /*!< Specifies the RTC Alarm PM value
														This parameter can be a value of @ref RTC_AM_PM */
	
    u8 TimeFormat;     /*!< Specifies the RTC Alarm Time Format
														This parameter can be a value of @ref RTC_TimeFormat */
	
} RTC_Alarm;

/* Exported constants --------------------------------------------------------*/

/** @defgroup RTC_TimeFormat_Selection
* @{ 
*/
#define RTC_TF_12	                    (RTC_CR_TF&0x00000002)
#define RTC_TF_24	                    (RTC_CR_TF&0x00000000)
#define  IS_RTC_TF_SET(SEL)	          (((SEL) == RTC_TimeFormat_12)  ||\
								                       ((SEL) == RTC_TimeFormat_24))

/** @defgroup RTC_ClockSource
* @{ 
*/
#define RTC_ClkSource_LSI	              (RTC_CR_CLKS&0x00000000)
#define RTC_ClkSource_LSE	              (RTC_CR_CLKS&0x00000004)
#define  IS_RTC_CLK(SEL)	         (((SEL) == RTC_ClkSource_LSE)  ||\
								                         ((SEL) == RTC_ClkSource_LSI))

/** @defgroup RTC_BeaconOut
* @{ 
*/
#define RTC_BeaconOut_ENABLE	          (RTC_CR_TBOE&0x00000008)
#define RTC_BeaconOut_DISABLE	          (RTC_CR_TBOE&0x00000000)
#define  IS_RTC_BEACON(SEL)	       (((SEL) == RTC_BeaconOut_ENABLE)  ||\
								                        ((SEL) == RTC_BeaconOut_DISABLE))

/** @defgroup RTC_TrimMode
* @{ 
*/
#define RTC_TrimMode_ENABLE	            (RTC_CR_TME&0x00000010)
#define RTC_TrimMode_DISABLE	          (RTC_CR_TME&0x00000000)
#define  IS_RTC_TME(SEL)	         (((SEL) == RTC_TrimMode_ENABLE)  ||\
								                        ((SEL) == RTC_TrimMode_DISABLE))

/** @defgroup RTC_DEC_Value
* @{ 
*/
#define IS_DEC_Week(SEL)          (((SEL)<8) && ((SEL)>0))     
#define IS_DEC_Year(SEL)          (((SEL)>=2000) && ((SEL)<=9999))
#define IS_DEC_Month(SEL)          (((SEL)<13) && ((SEL)>0)) 
#define IS_DEC_Day(SEL)           (((SEL)<32) && ((SEL)>0)) 
#define IS_DEC_Hour(SEL)           ((SEL)<24) 
#define IS_DEC_Minute(SEL)         ((SEL)<60) 
#define IS_DEC_Second(SEL)         ((SEL)<60) 

/** @defgroup RTC_AM_PM
* @{ 
*/
#define RTC_HOUR_AM                   0
#define RTC_HOUR_PM                   1
#define IS_RTC_AM_PM(SEL)             (((SEL) == RTC_HOUR_AM) || ((SEL) == RTC_HOUR_PM))

/** @defgroup RTC_TimeFormat
* @{ 
*/
#define RTC_TimeFormat_24             0
#define RTC_TimeFormat_12             1
#define IS_DEC_TimeFormat(SEL)     (((SEL) == RTC_TimeFormat_24) || ((SEL) == RTC_TimeFormat_12))

/** @defgroup RTC_IT
* @{ 
*/
#define RTC_IT_CHSECE		                  RTC_IE_CHSECE
#define RTC_IT_CSECE		                  RTC_IE_CSECE 
#define RTC_IT_CMINE	                    RTC_IE_CMINE
#define RTC_IT_CHOURE		                  RTC_IE_CHOURE
#define RTC_IT_CDAYE		                  RTC_IE_CDAYE
#define RTC_IT_CMONE		                  RTC_IE_CMONE
#define RTC_IT_ALME		                    RTC_IE_ALME
#define RTC_IT_PEDE		                    RTC_IE_PEDE
#define RTC_IT_ALL                        (RTC_IE_CHSECE|RTC_IE_CSECE|RTC_IE_CMINE|RTC_IE_CHOURE|RTC_IE_CDAYE|RTC_IE_CMONE|RTC_IE_ALME|RTC_IE_PEDE)	     
#define IS_RTC_IT(SEL)                  (((SEL) != 0) && (((SEL) & 0xFFFFFF00) == 0))


/** @defgroup RTC_FLAG
* @{ 
*/
#define RTC_FLAG_CHSEC               RTC_SR2_CHSEC
#define RTC_FLAG_CSEC                RTC_SR2_CSEC
#define RTC_FLAG_CMIN                RTC_SR2_CMIN
#define RTC_FLAG_CHOUR               RTC_SR2_CHOUR
#define RTC_FLAG_CDAY                RTC_SR2_CDAY
#define RTC_FLAG_CMON                RTC_SR2_CMON
#define RTC_FLAG_ALM                 RTC_SR2_ALM
#define RTC_FLAG_PED                 RTC_SR2_PED
#define RTC_FLAG_ALL                 ((u32)(0xFF))    
#define IS_RTC_FLAG(SEL)              (((SEL) != 0) && (((SEL) & 0xFFFFFF00) == 0))

/** @defgroup RTC_AWEEK
* @{ 
*/
#define RTC_AWEEK_Monday                              (RTC_AWEEK_WEEK&0x02)
#define RTC_AWEEK_Tuesday                             (RTC_AWEEK_WEEK&0x04)
#define RTC_AWEEK_Wednesday                           (RTC_AWEEK_WEEK&0x08)
#define RTC_AWEEK_Thursday                            (RTC_AWEEK_WEEK&0x10)
#define RTC_AWEEK_Friday                              (RTC_AWEEK_WEEK&0x20)
#define RTC_AWEEK_Saturday                            (RTC_AWEEK_WEEK&0x40)
#define RTC_AWEEK_Sunday                              (RTC_AWEEK_WEEK&0x80)
#define RTC_AWEEK_ALL                                 (RTC_AWEEK_WEEK&0xFE)
#define IS_RTC_AWEEK(SEL)                       (((SEL)&0x01) == 0 && (SEL)!=0x00)

/** @defgroup RTC_TrimValue
* @{ 
*/
#define IS_RTC_TrimValue(SEL)               ((SEL)<=0x1FF)     

/** @defgroup RTC_Period
* @{ 
*/
#define IS_RTC_Period(SEL)                  ((SEL)<=0xFFFF)

/** @defgroup RTC_TimeType_selection
* @{ 
*/
#define RTC_TIME_SEC		        0 /*!< TIME Second  */
#define RTC_TIME_MIN		        1  /*!< TIME Minutes  */
#define RTC_TIME_HOUR		        2  /*!< TIME Hour  */
#define RTC_TIME_DAY		        3  /*!< TIME DAY  */
#define RTC_TIME_WEEK		        4  /*!< TIME WEEK  */
#define RTC_TIME_MON		        5  /*!< TIME MON  */
#define RTC_TIME_YEAR		        6  /*!< TIME YEAR  */
#define RTC_TIME_ASEC	          7  /*!< TIME ALM_SEC  */
#define RTC_TIME_AMIN	          8  /*!< TIME ALM_MIN  */
#define RTC_TIME_AHOUR	        9  /*!< TIME ALM_HOUR  */
#define RTC_TIME_PM	            10  /*!< TIME ALM_HOUR  */
#define IS_RTC_TIME(SEL)        ((SEL) <= RTC_TIME_PM) 

/* Exported macro ------------------------------------------------------------*/
/* Exported functions ---------------------------------------------------------*/
void RTC_DeInit(void);
void RTC_Init(RTC_InitTypeDef* RTC_InitStruct);
void RTC_StructInit(RTC_InitTypeDef* RTC_InitStruct);
void RTC_ITConfig(u16 RTC_IT, FunctionalState NewState);
void RTC_ClearFlag(u8 RTC_FLAG);
FlagStatus RTC_GetFlagStatus(u32 RTC_FLAG);
void RTC_UnlockCmd(FunctionalState NewState);
void RTC_GetCalendarTime(RTC_Calendar* CalendarTime);
void RTC_SetCalendarTime(RTC_Calendar* CalendarTime);
void RTC_GetAlarmTime(RTC_Alarm* AlarmTime);
void RTC_SetAlarmTime(RTC_Alarm* AlarmTime);
void RTC_SetTrim(u16 Value);
void RTC_Cmd(FunctionalState NewState);
void RTC_PeriodInterval(u32 Period);
u16 RTC_GetTime(u16 RTC_Time);
void RTC_SetTime(u16 RTC_Time,u16 Time);
/**
  * @}
  */


#ifdef __cplusplus
}
#endif

#endif 


