/********************************************************************************
  * @file    PT32Sx076_tim.h
  * @author  ӦÿŶ
  * @version V1.0.0
  * @date    2023/7/15
  * @brief   This file contains all the functions prototypes for the TIM firmware
  *          library
  * @attention
  *
  * ǰĹָ̼, ĿͻṩйƷıϢ,Խʡǵʱ䡣
  * ̼/ͻʹаıϢκ, * Pai-IC κֱӣӻ̷𺦸
  *
  * (C) Ȩ Pai-IC Microelectronics
  *******************************************************************************/
	
#ifndef __PT32x076_TIM_H
#define __PT32x076_TIM_H

#ifdef __cplusplus
extern "C" {
#endif

#include "PT32x076.h"

/** @defgroup TIM_ALL_PERIPH
* @{
*/
#define IS_TIM_ALL_PERIPH(SEL) (((SEL) == TIM1) || ((SEL) == TIM2) || ((SEL) == TIM3) || ((SEL) == TIM4) || ((SEL) == TIM5)  || ((SEL) == TIM6) || ((SEL) == TIM7) ||  ((SEL) == TIM8) || ((SEL) == LPTIM) )

#define IS_TIM_LIST1_PERIPH(SEL) (((SEL) == TIM1) || ((SEL) == TIM5)  || ((SEL) == TIM6) || ((SEL) == TIM7) || ((SEL) == TIM8) || ((SEL) == LPTIM))

#define IS_TIM_LIST2_PERIPH(SEL) ((SEL) == LPTIM)

#define IS_TIM_LIST3_PERIPH(SEL) (((SEL) == TIM1) || ((SEL) == TIM5)  || ((SEL) == TIM6) || ((SEL) == TIM7))

#define IS_TIM_LIST4_PERIPH(SEL) (((SEL) == TIM1) || ((SEL) == TIM5)  || ((SEL) == TIM6) || ((SEL) == TIM7) || ((SEL) == TIM8))
/** @defgroup TIM_TimeBaseInitTypeDef
* @{
*/
typedef struct
{
	u16 TIM_AutoReloadValue;       /*!< Specifies the value to be loaded into the Auto-Reload Register at the next update event.
																		  This parameter can be a number between 0x0000 and 0xFFFF */

	u32  TIM_InternalClockSource;  /*!< Specifies internal clock source.
																		  This parameter can be value of @ref TIM_InternalClockSource */

	u16 TIM_Prescaler; 						 /*!< Specifies the prescaler value used to divide the PCLK.
																		  This parameter can be a number between 0x0000 and 0xFFFF */

	u32 TIM_Direction;						 /*!< Specifies the counter mode.
																			This parameter can be value of @ref TIM_Direction */

	u32 TIM_CenterAlignedMode;		 /*!< Specifies the center aligned mode.
																			This parameter can be value of @ref TIM_CenterAlignedMode */

} TIM_TimeBaseInitTypeDef;


/** @defgroup TIM_InternalClockSource
* @{
*/
#define TIM_LIST4_InternalClockSource_PCLK		0x00000000
#define TIM_LIST4_InternalClockSource_SYSCLK	TIM_CR1_CLKS
#define IS_TIM_LIST4_InternalClockSource(SEL)	   (((SEL) == TIM_LIST4_InternalClockSource_PCLK) || \
										                              ((SEL) == TIM_LIST4_InternalClockSource_SYSCLK))

/** @defgroup TIM_InternalClockSource
* @{
*/
#define TIM_LIST5_InternalClockSource_LSI		0x00000000
#define TIM_LIST5_InternalClockSource_LSE 	TIM_CR1_CLKS
#define IS_TIM_LIST5_InternalClockSource(SEL)	(((SEL) == TIM_LIST5_InternalClockSource_LSI) || \
										                     ((SEL) == TIM_LIST5_InternalClockSource_LSE))

/** @defgroup LPTIM_InternalClockSource
* @{
*/
#define LPTIM_InternalClockSource_PCLK       0x00000000
#define LPTIM_InternalClockSource_HSI       (LPTIM_CR1_CLKS&0x00010000)
#define LPTIM_InternalClockSource_SYS       (LPTIM_CR1_CLKS&0x00020000)
#define LPTIM_InternalClockSource_LSI       (LPTIM_CR1_CLKS&0x00030000)
#define LPTIM_InternalClockSource_LSE       (LPTIM_CR1_CLKS&0x00040000)
#define IS_LPTIM_InternalClockSource(SEL)	  (((SEL) == LPTIM_InternalClockSource_PCLK) || \
										                         ((SEL) == LPTIM_InternalClockSource_HSI)  ||\
                                             ((SEL) == LPTIM_InternalClockSource_SYS)  ||\
                                             ((SEL) == LPTIM_InternalClockSource_LSI)  ||\
																						 ((SEL) == LPTIM_InternalClockSource_LSE))

/** @defgroup TIM_Direction
* @{
*/
#define TIM_Direction_Up		(TIM_CR1_DIR&0x00000000)
#define TIM_Direction_Down	(TIM_CR1_DIR&0x00000200)
#define IS_TIM_Direction(SEL)      (((SEL) == TIM_Direction_Up) || \
									((SEL) == TIM_Direction_Down))

/** @defgroup TIM_CenterAlignedMode
* @{
*/
#define TIM_CenterAlignedMode_Disable	(TIM_CR1_CMS&0x00000000)
#define TIM_CenterAlignedMode_Enable	(TIM_CR1_CMS&0x00000400)
#define IS_TIM_CenterAlignedMode(SEL)   (((SEL) == TIM_CenterAlignedMode_Disable) || \
										 ((SEL) == TIM_CenterAlignedMode_Enable))

/** @defgroup TIM_CH_Enum
* @{
*/
typedef enum
{
	TIM_Channel_1 = 0,                /*!< TIM channel 1 */
	TIM_Channel_2,                    /*!< TIM channel 2 */
	TIM_Channel_3,                    /*!< TIM channel 3 */
	TIM_Channel_4                     /*!< TIM channel 4 */
} TIM_CH_Enum;

/** @defgroup TIM_OCInitTypeDef
* @{
*/
typedef struct
{
	TIM_CH_Enum TIM_Channel;	/*!< Specifies the advanced TIM channnel.
																	This parameter can be value of @ref TIM_CH_Enum */
	
	u32 TIM_OCMode;						/*!< Specifies the output compare mode.
																	This parameter can be value of @ref TIM_OCMode */
	
	u32 TIM_OCIdleState;			/*!< Specifies the channel output compare idele state.
																	This parameter can be value of @ref TIM_OCIdleState */
	
	u32 TIM_OCNIdleState;			/*!< Specifies the complementary channel output compare idele state.
																	This parameter can be value of @ref TIM_OCNIdleState */
	
	u32 TIM_OCOutput;					/*!< Specifies the channel output compare enable.
																	This parameter can be value of @ref TIM_OCOutput */
	
	u32 TIM_OCNOutput;				/*!< Specifies the complementary channel output compare enable.
																  This parameter can be value of @ref TIM_OCNOutput */
	
	u16 TIM_OCValue;					/*!< Specifies the output compare value.
																	This parameter can be a number between 0x0000 and 0xFFFF */
	
} TIM_OCInitTypeDef;

/** @defgroup TIM_Channel
* @{
*/
#define IS_TIM_Channel(SEL) (((SEL) == TIM_Channel_1) ||\
							 ((SEL) == TIM_Channel_2)  ||\
							 ((SEL) == TIM_Channel_3)  ||\
							 ((SEL) == TIM_Channel_4))

/** @defgroup TIM_OCMode
* @{
*/
#define TIM_OCMode_Timing					(TIM_OCMR_OC1M&0x0000)
#define TIM_OCMode_PWM1						(TIM_OCMR_OC1M&0x0001)
#define TIM_OCMode_PWM2						(TIM_OCMR_OC1M&0x0002)
#define TIM_OCMode_Toggle					(TIM_OCMR_OC1M&0x0003)
#define TIM_OCMode_Active					(TIM_OCMR_OC1M&0x0004)
#define TIM_OCMode_Inactive				(TIM_OCMR_OC1M&0x0005)
#define TIM_OCMode_CompelInactive	(TIM_OCMR_OC1M&0x0006)
#define TIM_OCMode_CompelActive		(TIM_OCMR_OC1M&0x0007)
#define IS_TIM_OCMode(SEL)         ((((SEL) &(~TIM_OCMR_OC1M))== 0x0) && ((SEL)<=TIM_OCMode_CompelActive))

/** @defgroup TIM_OCIdleState
* @{
*/
#define  TIM_OCIdleState_Low		0x00000000
#define  TIM_OCIdleState_High		TIM_OCMR_OIS1
#define IS_TIM_OCIdleState(SEL)	(((SEL) == TIM_OCIdleState_Low)    || \
								 ((SEL) == TIM_OCIdleState_High))

/** @defgroup TIM_OCNIdleState
* @{
*/
#define  TIM_OCNIdleState_Low		0x00000000
#define  TIM_OCNIdleState_High	TIM_OCMR_OIS1N
#define IS_TIM_OCNIdleState(SEL)	(((SEL) == TIM_OCNIdleState_Low)    || \
									 ((SEL) == TIM_OCNIdleState_High))

/** @defgroup TIM_OCOutput
* @{
*/
#define  TIM_OCOutput_Disable	0x00000000
#define  TIM_OCOutput_Enable	TIM_OCMR_OC1E
#define IS_TIM_OCOutput(SEL)	(((SEL) == TIM_OCOutput_Disable) || \
								 ((SEL) == TIM_OCOutput_Enable))

/** @defgroup TIM_OCNOutput
* @{
*/
#define  TIM_OCNOutput_Disable	0x00000000
#define  TIM_OCNOutput_Enable		TIM_OCMR_OC1NE
#define IS_TIM_OCNOutput(SEL)	(((SEL) == TIM_OCNOutput_Disable) || \
								 ((SEL) == TIM_OCNOutput_Enable))


/** @defgroup TIM_ICInitTypeDef
* @{
*/
typedef struct
{
	TIM_CH_Enum TIM_Channel;		/*!< Specifies the advanced TIM channnel.
																	 This parameter can be value of @ref TIM_CH_Enum */
	
	u32 TIM_ICRiseCapture;			/*!< Specifies the input capture rising capture enable.
																	 This parameter can be value of @ref TIM_ICRiseCapture */
	
	u32 TIM_ICFallCapture;			/*!< Specifies the input capture fall capture enable.
																	 This parameter can be value of @ref TIM_ICFallCapture */  
	
	u32 TIM_ICResetCounter;			/*!< Specifies the input capture reset counter enable.
																	 This parameter can be value of @ref TIM_ICResetCounter */  
	
	u32 TIM_ICSource;						/*!< Specifies the input capture source selection.
																	 This parameter can be value of @ref TIM_ICSource */  
	
	u32 TIM_ICFilter;						/*!< Specifies the input capture filter.
																	 This parameter can be value of @ref TIM_ICFilter */  
	
	u32 TIM_ICPrescaler;				 /*!< Specifies the input capture prescaler.
																	 This parameter can be value of @ref TIM_ICPrescaler */  
	
} TIM_ICInitTypeDef;

/** @defgroup TIM_ICRiseCapture
* @{
*/
#define  TIM_ICRiseCapture_Disable	0x00000000
#define  TIM_ICRiseCapture_Enable	TIM_CAPR1_IC1R
#define  IS_TIM_ICRiseCapture(SEL)	(((SEL) == TIM_ICRiseCapture_Disable)    || \
									 ((SEL) == TIM_ICRiseCapture_Enable))

/** @defgroup TIM_ICFallCapture
* @{
*/
#define  TIM_ICFallCapture_Disable	0x00000000
#define  TIM_ICFallCapture_Enable	TIM_CAPR1_IC1F
#define  IS_TIM_ICFallCapture(SEL)	(((SEL) == TIM_ICFallCapture_Disable)    || \
									 ((SEL) == TIM_ICFallCapture_Enable))

/** @defgroup TIM_ICResetCounter
* @{
*/
#define  TIM_ICResetCounter_Disable	0x00000000
#define  TIM_ICResetCounter_Enable	TIM_CAPR1_IC1RC
#define  IS_TIM_ICResetCounter(SEL)	(((SEL) == TIM_ICResetCounter_Disable)    || \
									 ((SEL) == TIM_ICResetCounter_Enable))

/** @defgroup TIM_ICSource
* @{
*/
#define TIM_ICSource_ICS1            (TIM_CAPR1_IC1S&0x00010000)
#define TIM_ICSource_ICS2            (TIM_CAPR1_IC1S&0x00020000)
#define TIM_ICSource_ICS3            (TIM_CAPR1_IC1S&0x00030000)
#define TIM_ICSource_ICS4            (TIM_CAPR1_IC1S&0x00040000)
#define TIM_ICSource_TRC             (TIM_CAPR1_IC1S&0x00050000)
#define IS_TIM_ICSource(SEL)        ((((SEL) &(~TIM_CAPR1_IC1S))== 0x0) && ((SEL) !=0x0000))

/** @defgroup TIM_ICFilter
* @{
*/
#define TIM_ICFilter_0	     0x00000000
#define TIM_ICFilter_2	     (TIM_CAPR2_IC1FR&0x00000001)
#define TIM_ICFilter_4	     (TIM_CAPR2_IC1FR&0x00000002)
#define TIM_ICFilter_8	     (TIM_CAPR2_IC1FR&0x00000003)
#define TIM_ICFilter_16	     (TIM_CAPR2_IC1FR&0x00000004)
#define TIM_ICFilter_32	     (TIM_CAPR2_IC1FR&0x00000005)
#define TIM_ICFilter_64	     (TIM_CAPR2_IC1FR&0x00000006)
#define IS_TIM_ICFilter(SEL)       ((SEL) <=TIM_ICFilter_64)

/** @defgroup TIM_ICPrescaler
* @{
*/
#define TIM_ICPrescaler_0	          0x00000000
#define TIM_ICPrescaler_2	         (TIM_CAPR2_IC1PSC&0x00000010)
#define TIM_ICPrescaler_4	         (TIM_CAPR2_IC1PSC&0x00000020)
#define TIM_ICPrescaler_8	         (TIM_CAPR2_IC1PSC&0x00000030)
#define IS_TIM_ICPrescaler(SEL)     ((((SEL) &(~TIM_CAPR2_IC1PSC))== 0x0) && ((SEL) <=TIM_ICPrescaler_8))

#define TIM_LIST4_Channel1Polarity_Enable  (TIM_CR3_CC1P)
#define TIM_LIST4_Channel2Polarity_Enable  (TIM_CR3_CC2P)
#define TIM_LIST4_Channel3Polarity_Enable  (TIM_CR3_CC3P)
#define TIM_LIST4_Channel4Polarity_Enable  (TIM_CR3_CC4P)
#define TIM_LIST4_Channel1NPolarity_Enable (TIM_CR3_C1NP)
#define TIM_LIST4_Channel2NPolarity_Enable (TIM_CR3_C2NP)
#define TIM_LIST4_Channel3NPolarity_Enable (TIM_CR3_C3NP)
#define TIM_LIST4_Channel4NPolarity_Enable (TIM_CR3_C4NP)
#define TIM_LIST4_ChannelPolarity_ALL      (0x3333)

#define TIM_LIST4_Channel1Polarity_disable  (TIM_CR3_CC1P&0x0)
#define TIM_LIST4_Channel2Polarity_disable  (TIM_CR3_CC2P&0x0)
#define TIM_LIST4_Channel3Polarity_disable  (TIM_CR3_CC3P&0x0)
#define TIM_LIST4_Channel4Polarity_disable  (TIM_CR3_CC4P&0x0)
#define TIM_LIST4_Channel1NPolarity_disable (TIM_CR3_C1NP&0x0)
#define TIM_LIST4_Channel2NPolarity_disable (TIM_CR3_C2NP&0x0)
#define TIM_LIST4_Channel3NPolarity_disable (TIM_CR3_C3NP&0x0)
#define TIM_LIST4_Channel4NPolarity_disable (TIM_CR3_C4NP&0x0)

#define TIM_LIST2_Channel1Polarity_Enable   (LPTIM_CR3_CC1P)
#define TIM_LIST2_Channel2Polarity_Enable   (LPTIM_CR3_C2P)
#define TIM_LIST2_ChannelPolarity_ALL       (0x11)

#define IS_TIM_LIST2_ChannelPolarity(SEL)  ((((SEL) & (~TIM_LIST2_ChannelPolarity_ALL)) ==0x0)  && ((SEL) <=TIM_LIST2_Channel2Polarity_Enable))

#define IS_TIM_LIST4_ChannelPolarity(SEL)  ((((SEL) & (~TIM_LIST4_ChannelPolarity_ALL)) ==0x0)  && ((SEL) <=TIM_LIST4_Channel4NPolarity_Enable))

/** @defgroup TIM_BDTRInitTypeDef
* @{
*/
typedef struct
{
	u32 TIM_DeadTime;									/*!< Specifies the dead time value.
																				 This parameter can be a number between 0x0000 and 0x1000 */
	
	u32 TIM_Break;										/*!< Specifies the break enable.
																				 This parameter can be value of @ref TIM_Break */  
	
	u32 TIM_BreakPolarity;						/*!< Specifies the break polarity.
																				 This parameter can be value of @ref TIM_BreakPolarity */  
	
	u32 TIM_BreakSoftwareControl;			/*!< Specifies the break software control.
																				 This parameter can be value of @ref TIM_BreakSoftwareControl */
	
	u32 TIM_BreakSource;							/*!< Specifies the break source selection.
																				 This parameter can be value of @ref TIM_BreakSource */
	
	u32 TIM_BreakInputControl;				/*!< Specifies the break input control.
																				 This parameter can be value of @ref TIM_BreakInputControl */
	
} TIM_BDTRInitTypeDef;

/** @defgroup TIM_DeadTime
* @{
*/
#define IS_TIM_DeadTime(SEL)	((SEL) <4096)

/** @defgroup TIM_Break
* @{
*/
#define TIM_Break_Disable			 (TIM_BDTR_BKE&0x00000)
#define TIM_Break_Enable				TIM_BDTR_BKE
#define IS_TIM_Break(SEL)	(((SEL) == TIM_Break_Disable) ||\
							 ((SEL) == TIM_Break_Enable))

/** @defgroup TIM_BreakPolarity
* @{
*/
#define TIM_BreakPolarity_Low								0x00000000
#define TIM_BreakPolarity_High							TIM_BDTR_BKP
#define IS_TIM_BreakPolarity(SEL)						 (((SEL) == TIM_BreakPolarity_Low) || \
														  ((SEL) == TIM_BreakPolarity_High))

/** @defgroup TIM_BreakSoftwareControl
* @{
*/
#define TIM_BreakSoftwareControl_Disable	0x00000000
#define TIM_BreakSoftwareControl_Enable		TIM_BDTR_BKSC
#define IS_TIM_BreakSoftwareControl(SEL)	(((SEL) == TIM_BreakSoftwareControl_Disable) || \
											 ((SEL) == TIM_BreakSoftwareControl_Enable))

/** @defgroup TIM_BreakSource
* @{
*/
#define TIM_BreakSource_TIM1BKIN	    TIM_BKICR_BKINE
#define TIM_BreakSource_PVD				    TIM_BKICR_PVDE
#define TIM_BreakSource_Software	    TIM_BKICR_SWE
#define TIM_BreakSource_CMP0			    TIM_BKICR_CMP0E
#define TIM_BreakSource_CMP1			    TIM_BKICR_CMP1E
#define TIM_BreakSource_CMP2		    	TIM_BKICR_CMP2E
#define TIM_BreakSource_CMP3			    TIM_BKICR_CMP3E
#define TIM_BreakSource_ALL			      ((u32)0x00000F31)
#define IS_TIM_BreakSource(SEL)	       ((((SEL) &(~TIM_BreakSource_ALL))== 0x0) && ((SEL) !=0x0000))

/** @defgroup TIM_BreakInputControl
* @{
*/
#define TIM_BreakInput_OutputIdle	    0x00000000
#define TIM_BreakInput_TIMOFF	        TIM_BDTR_BKIC
#define IS_TIM_BreakInputControl(SEL)	     (((SEL) == TIM_BreakInput_OutputIdle) || \
											  ((SEL) == TIM_BreakInput_TIMOFF))

/** @defgroup TIM_SAMC
* @{
*/
#define TIM_SAMC_DIV1	     (TIM_CR1_SAMPSC&0x00)
#define TIM_SAMC_DIV2	     (TIM_CR1_SAMPSC&0x10)
#define TIM_SAMC_DIV4	     (TIM_CR1_SAMPSC&0x20)
#define TIM_SAMC_DIV8	     (TIM_CR1_SAMPSC&0x30)
#define TIM_SAMC_DIV16	   (TIM_CR1_SAMPSC&0x40)
#define TIM_SAMC_DIV32	   (TIM_CR1_SAMPSC&0x50)
#define IS_TIM_SAMCDiv(SEL)       ((((SEL) &(~TIM_CR1_SAMPSC))== 0x0) && ((SEL)<=TIM_SAMC_DIV32))

/** @defgroup TIM_EventSource
* @{
*/
#define TIM_EventSource_Update	(TIM_CR1_UG&0x0002)
#define TIM_EventSource_Break	(TIM_BDTR_BKSC&0X80000)
#define IS_TIM_EventSource(SEL) (((SEL) == TIM_EventSource_Update) || \
								 ((SEL) == TIM_EventSource_Break))

/** @defgroup TIM_RepeatTimes
* @{
*/
#define IS_TIM_RepeatTimes(SEL)             ((SEL) <= 0xF)

/** @defgroup TIM_IT
* @{
*/
#define TIM_OCIT_ARI                   TIM_CR2_ARI
#define TIM_OCIT_OC1I                  TIM_CR2_OC1I
#define TIM_OCIT_OC2I                  TIM_CR2_OC2I
#define TIM_OCIT_OC3I                  TIM_CR2_OC3I
#define TIM_OCIT_OC4I                  TIM_CR2_OC4I
#define TIM_OCIT_UIE                   TIM_CR2_UIE
#define LPTIM_OCIT_ARRUIE              LPTIM_CR2_ARRUIE
#define LPTIM_OCIT_OCR1UIE             LPTIM_CR2_OCR1UIE
#define LPTIM_OCIT_DOWNIE              LPTIM_CR2_DOWNIE
#define LPTIM_OCIT_UPIE                LPTIM_CR2_UPIE
#define TIM_IT_ALL                   ((u32)0x0000005F)
#define IS_TIM_OCIT(SEL)            ((((SEL) &0xFFF0FFA0)== 0x0) && ((SEL) !=0x0000))
#define IS_TIM_OCIT1(SEL)           ((SEL) == TIM_OCIT_ARI)

#define TIM_ICIT_IC1I                  TIM_CAPR1_IC1I
#define TIM_ICIT_IC2I                  TIM_CAPR1_IC2I
#define TIM_ICIT_IC3I                  TIM_CAPR1_IC3I
#define TIM_ICIT_IC4I                  TIM_CAPR1_IC4I
#define TIM_ICIT_ALL                   ((u32)0x00008888)
#define IS_TIM_ICIT(SEL)            ((((SEL) &0xFFFF7777)== 0x0) &&((SEL) != 0x0000))

#define TIM_BKIT_BKI                   TIM_BDTR_BKI
#define IS_TIM_BKIT(SEL)            ((SEL) == TIM_BKIT_BKI)

#define TIM_TIIT_TIE                   TIM_MSCR_TIE
#define IS_TIM_TIIT(SEL)            ((SEL) == TIM_TIIT_TIE)

/** @defgroup TIM_FLAG
* @{
*/
#define TIM_FLAG_ARF                    TIM_SR_ARF
#define TIM_FLAG_OC1F                   TIM_SR_OC1F
#define TIM_FLAG_OC2F                   TIM_SR_OC2F
#define TIM_FLAG_OC3F                   TIM_SR_OC3F
#define TIM_FLAG_OC4F                   TIM_SR_OC4F
#define TIM_FLAG_IC1R                		TIM_SR_IC1R
#define TIM_FLAG_IC1F               	  TIM_SR_IC1F
#define TIM_FLAG_IC2R               	  TIM_SR_IC2R
#define TIM_FLAG_IC2F               		TIM_SR_IC2F
#define TIM_FLAG_IC3R               		TIM_SR_IC3R
#define TIM_FLAG_IC3F               		TIM_SR_IC3F
#define TIM_FLAG_IC4R                		TIM_SR_IC4R
#define TIM_FLAG_IC4F               	  TIM_SR_IC4F
#define TIM_FLAG_BIF                    TIM_SR_BIF
#define TIM_FLAG_TIF                    TIM_SR_TIF
#define TIM_FLAG_UF                     TIM_SR_UF
#define TIM_FLAG_ALL                    ((u32)0xFFFF)
#define LPTIM_FLAG_ARRUF                LPTIM_SR_ARRUF    
#define LPTIM_FLAG_OCR1UF               LPTIM_SR_OCR1UF 
#define LPTIM_FLAG_DOWN                 LPTIM_SR_DOWN
#define LPTIM_FLAG_UP                   LPTIM_SR_UP
#define LPTIM_FLAG_ALL                  ((u32)0xFC1E3)
#define IS_TIM_FLAG0(SEL)               ((((SEL) &(~TIM_FLAG_ALL))==0) && ( ((SEL) !=0x0000)))
#define IS_TIM_FLAG1(SEL)               ((((SEL) &(~LPTIM_FLAG_ALL))==0) && ((SEL) !=0x0000))

/** @defgroup TIM_ADCTrigger
* @{
*/
#define TIM_ADCTrigger_OC1UE                  TIM_TACR_OC1UE
#define TIM_ADCTrigger_OC1DE                  TIM_TACR_OC1DE
#define TIM_ADCTrigger_OC2UE                  TIM_TACR_OC2UE
#define TIM_ADCTrigger_OC2DE                  TIM_TACR_OC2DE
#define TIM_ADCTrigger_OC3UE                  TIM_TACR_OC3UE
#define TIM_ADCTrigger_OC3DE                  TIM_TACR_OC3DE
#define TIM_ADCTrigger_OC4UE                  TIM_TACR_OC4UE
#define TIM_ADCTrigger_OC4DE                  TIM_TACR_OC4DE
#define TIM_ADCTrigger_UOAE                   TIM_TACR_UOAE
#define TIM_ADCTrigger_DOAE                   TIM_TACR_DOAE
#define TIM_ADCTrigger_TAE                    TIM_TACR_TAE
#define TIM_ADCTrigger_IC1RAE                 TIM_TACR_IC1RAE
#define TIM_ADCTrigger_IC1FAE                 TIM_TACR_IC1FAE
#define TIM_ADCTrigger_IC2RAE                 TIM_TACR_IC2RAE
#define TIM_ADCTrigger_IC2FAE                 TIM_TACR_IC2FAE
#define TIM_ADCTrigger_IC3RAE                 TIM_TACR_IC3RAE
#define TIM_ADCTrigger_IC3FAE                 TIM_TACR_IC3FAE
#define TIM_ADCTrigger_IC4RAE                 TIM_TACR_IC4RAE
#define TIM_ADCTrigger_IC4FAE                 TIM_TACR_IC4FAE
#define TIM_ADCTrigger_ALL                    ((u32)0xFF07FF)
#define IS_TIM_ADCTrigger(SEL)                ((((SEL) &(~TIM_ADCTrigger_ALL))== 0x0) && ((SEL) !=0x0000))

/** @defgroup TIM_DMARequest
* @{
*/
#define TIM_DMARequest_ARDE                   TIM_TDCR_ARDE
#define TIM_DMARequest_OC1DE                  TIM_TDCR_OC1DE
#define TIM_DMARequest_OC2DE                  TIM_TDCR_OC2DE
#define TIM_DMARequest_OC3DE                  TIM_TDCR_OC3DE
#define TIM_DMARequest_OC4DE                  TIM_TDCR_OC4DE
#define TIM_DMARequest_IC1RDE                 TIM_TDCR_IC1RDE
#define TIM_DMARequest_IC1FDE                 TIM_TDCR_IC1FDE
#define TIM_DMARequest_IC2RDE                 TIM_TDCR_IC2RDE
#define TIM_DMARequest_IC2FDE                 TIM_TDCR_IC2FDE
#define TIM_DMARequest_IC3RDE                 TIM_TDCR_IC3RDE
#define TIM_DMARequest_IC3FDE                 TIM_TDCR_IC3FDE
#define TIM_DMARequest_IC4RDE                 TIM_TDCR_IC4RDE
#define TIM_DMARequest_IC4FDE                 TIM_TDCR_IC4FDE
#define TIM_DMARequest_TDE                    TIM_TDCR_TDE
#define TIM_DMARequest_UDE                    TIM_TDCR_UDE
#define TIM_DMARequest_ALL                    ((u32)0xDFFF)
#define IS_TIM_DMARequest(SEL)               ((((SEL) &(~TIM_DMARequest_ALL))== 0x0) && ((SEL) !=0x0000))


/** @defgroup TIM_SlaveModeInitTypeDef
* @{
*/
typedef struct
{
	u32 TIM_TriggerInput;					/*!< Specifies the trigger input.
																			This parameter can be value of @ref TIM_TriggerInput */  
	
	u32 TIM_SlaveMode;						/*!< Specifies the slave mode.
																			This parameter can be value of @ref TIM_SlaveMode */  
	
	u32 TIM_TriggerFilter;				/*!< Specifies the trigger filter.
																			This parameter can be value of @ref TIM_TriggerPrecaler */  
	
	u32 TIM_TriggerPrecaler;			/*!< Specifies the trigger precaler.
																			This parameter can be value of @ref TIM_TriggerPrecaler */  
	
	u32 TIM_ExternalClock;				/*!< Specifies the external clock.
																			This parameter can be value of @ref TIM_ExternalClock */  
	
	u32 TIM_TriggerPolarity;			/*!< Specifies the trigger polarity.
																			This parameter can be value of @ref PWM_TriggerPolarity */  
	
} TIM_SlaveModeInitTypeDef;

/** @defgroup TIM_TriggerInput
* @{ 
*/
#define TIM_TriggerInput_ITR0          (TIM_MSCR_TIS&0x0)
#define TIM_TriggerInput_ITR1          (TIM_MSCR_TIS&0x1)
#define TIM_TriggerInput_ITR2          (TIM_MSCR_TIS&0x2)
#define TIM_TriggerInput_ITR3          (TIM_MSCR_TIS&0x3)
#define TIM_TriggerInput_TI1FPED       (TIM_MSCR_TIS&0x4)
#define TIM_TriggerInput_TI2FPED       (TIM_MSCR_TIS&0x5)
#define TIM_TriggerInput_TI3FPED       (TIM_MSCR_TIS&0x6)
#define TIM_TriggerInput_TI4FPED       (TIM_MSCR_TIS&0x7)
#define TIM_TriggerInput_TI1FP         (TIM_MSCR_TIS&0x8)
#define TIM_TriggerInput_TI2FP         (TIM_MSCR_TIS&0x9)
#define TIM_TriggerInput_TI3FP         (TIM_MSCR_TIS&0xA)
#define TIM_TriggerInput_TI4FP         (TIM_MSCR_TIS&0xB)
#define TIM_TriggerInput_ITR4          (TIM_MSCR_TIS&0xC)
#define TIM_TriggerInput_ETRFP         (TIM_MSCR_TIS&0xD)
#define TIM_TriggerInput_SOFT          (TIM_MSCR_TIS&0xF)
#define IS_TIM_TriggerInput0(SEL)     ((((SEL) &(~TIM_MSCR_TIS))== 0x0) &&(( (SEL) <=TIM_TriggerInput_ETRFP) )) 
#define IS_TIM_TriggerInput1(SEL)     ((((SEL) &(~TIM_MSCR_TIS))== 0x0) &&(( ((SEL) <=TIM_TriggerInput_TI1FPED) ||  ( (SEL) ==TIM_TriggerInput_TI1FP)))) 
#define IS_TIM_TriggerInput2(SEL)     ((((SEL) &(~TIM_MSCR_TIS))== 0x0) &&(( (SEL) <=TIM_TriggerInput_TI2FPED)  ||  ( ((SEL) >=TIM_TriggerInput_TI1FP) && ((SEL) <=TIM_TriggerInput_TI2FP) ) || ( ((SEL) >=TIM_TriggerInput_ITR4) && ((SEL) <=TIM_TriggerInput_ETRFP) ) || ((SEL) ==TIM_TriggerInput_SOFT)))

/** @defgroup TIM_SlaveMode
* @{ 
*/
#define	TIM_SlaveMode_Disable         (TIM_MSCR_SMS&0x0)
#define	TIM_SlaveMode_Encode1        	(TIM_MSCR_SMS&0x10)
#define	TIM_SlaveMode_Encode2        	(TIM_MSCR_SMS&0x20)
#define	TIM_SlaveMode_Encode3        	(TIM_MSCR_SMS&0x30)
#define	TIM_SlaveMode_Reset         	(TIM_MSCR_SMS&0x40)
#define	TIM_SlaveMode_Gated         	(TIM_MSCR_SMS&0x50)
#define	TIM_SlaveMode_Trigger         (TIM_MSCR_SMS&0x60)
#define	TIM_SlaveMode_Clock           (TIM_MSCR_SMS&0x70)
#define IS_TIM_SlaveMode0(SEL)       ((((SEL) &(~TIM_MSCR_SMS))== 0x0))
#define IS_TIM_SlaveMode1(SEL)       ((((SEL) &(~TIM_MSCR_SMS))== 0x0) && (( ((SEL) >=0x40) && ((SEL) <=0x70)) ||  ( (SEL) ==0x0))) 
#define IS_TIM_SlaveMode2(SEL)       ((((SEL) &(~TIM_MSCR_SMS))== 0x0) && (  ((SEL) <=0x60) )) 

/** @defgroup TIM_TriggerFilter
* @{ 
*/
#define TIM_TriggerFilter_1          (TIM_MSCR_ETF&0x0)
#define TIM_TriggerFilter_2          (TIM_MSCR_ETF&0x100)
#define TIM_TriggerFilter_4          (TIM_MSCR_ETF&0x200)
#define TIM_TriggerFilter_8          (TIM_MSCR_ETF&0x300)
#define TIM_TriggerFilter_16         (TIM_MSCR_ETF&0x400)
#define TIM_TriggerFilter_32         (TIM_MSCR_ETF&0x500)
#define TIM_TriggerFilter_64         (TIM_MSCR_ETF&0x600)
#define IS_TIM_TriggerFilter(SEL)   ((((SEL) &(~TIM_MSCR_ETF))== 0x0) && ((SEL) <=TIM_TriggerFilter_64))

/** @defgroup TIM_TriggerPrecaler
* @{ 
*/
#define TIM_TriggerPrecaler_1       (TIM_MSCR_ETPSC&0x0)
#define TIM_TriggerPrecaler_2       (TIM_MSCR_ETPSC&0x10)
#define TIM_TriggerPrecaler_4       (TIM_MSCR_ETPSC&0x20)
#define TIM_TriggerPrecaler_8       (TIM_MSCR_ETPSC&0x30)
#define IS_TIM_TriggerPrecaler(SEL)   ((((SEL) &(~TIM_MSCR_ETPSC))== 0x0) && ((SEL) <=TIM_TriggerPrecaler_8))

/** @defgroup TIM_ExternalClock
* @{ 
*/
#define TIM_ExternalClock_Disable   (TIM_MSCR_ECE&0x0)
#define TIM_ExternalClock_Enable    (TIM_MSCR_ECE&0x400)
#define IS_TIM_ExternalClock(SEL)   (((SEL) == TIM_ExternalClock_Disable)   ||  ((SEL) == TIM_ExternalClock_Enable))

/** @defgroup TIM_TriggerPolarity
* @{ 
*/
#define TIM_TriggerPolarity_Disable (TIM_MSCR_ETP&0x0)
#define TIM_TriggerPolarity_Enable  (TIM_MSCR_ETP&0x8000)
#define IS_TIM_TriggerPolarity(SEL)   (((SEL) == TIM_TriggerPolarity_Disable)   ||  ((SEL) == TIM_TriggerPolarity_Enable))

/** @defgroup TIM_MasterModeInitTypeDef
* @{
*/
typedef struct
{
	u32 TIM_Synchronization;			/*!< Specifies the synchronization.
																		 This parameter can be value of @ref TIM_Synchronization */  
	
	u32 TIM_MasterMode;						/*!< Specifies the master mode.
																		 This parameter can be value of @ref TIM_MasterMode */
	
} TIM_MasterModeInitTypeDef;

/** @defgroup TIM_Synchronization
* @{ 
*/
#define TIM_Synchronization_Disable  (TIM_MSCR_SYNC&0x0)
#define TIM_Synchronization_Enable   (TIM_MSCR_SYNC&0x00100000)
#define IS_TIM_Synchronization(SEL)  (((SEL) == TIM_Synchronization_Disable)   ||  ((SEL) == TIM_Synchronization_Enable))

/** @defgroup TIM_MasterMode
* @{ 
*/
#define TIM_MasterMode_0             (TIM_MSCR_TOS&0x0)
#define TIM_MasterMode_1             (TIM_MSCR_TOS&0x00010000)
#define TIM_MasterMode_2             (TIM_MSCR_TOS&0x00020000)
#define TIM_MasterMode_3             (TIM_MSCR_TOS&0x00040000)
#define TIM_MasterMode_4             (TIM_MSCR_TOS&0x00050000)
#define TIM_MasterMode_5             (TIM_MSCR_TOS&0x00060000)
#define TIM_MasterMode_6             (TIM_MSCR_TOS&0x00070000)
#define TIM_MasterMode_7             (TIM_MSCR_TOS&0x00080000)
#define TIM_MasterMode_8             (TIM_MSCR_TOS&0x00090000)
#define TIM_MasterMode_9             (TIM_MSCR_TOS&0x000A0000)
#define TIM_MasterMode_10            (TIM_MSCR_TOS&0x000B0000)
#define TIM_MasterMode_disable       (TIM_MSCR_TOS&0x00030000)
#define IS_TIM_MasterMode(SEL)       ((((SEL) &(~TIM_MSCR_TOS))== 0x0) && ((SEL) <=TIM_MasterMode_10))

/** @defgroup LPTIM_Trigger_selection
* @{ 
*/
#define LPTIM_Trigger_Disable        (LPTIM_MSCR_TPS&0x0)
#define LPTIM_Trigger_Rise           (LPTIM_MSCR_TPS&0x4000000)
#define LPTIM_Trigger_Fall           (LPTIM_MSCR_TPS&0x8000000)
#define LPTIM_Trigger_Edge           (LPTIM_MSCR_TPS&0xC000000)
#define IS_LPTIM_TriggerPolarity(SEL)       (((SEL) == LPTIM_Trigger_Disable)   ||  ((SEL) == LPTIM_Trigger_Rise)   ||  ((SEL) == LPTIM_Trigger_Fall)   ||  ((SEL) == LPTIM_Trigger_Edge))

/*! function declaration and definition*/
void TIM_TimeBaseInit(TIM_TypeDef *TIMx, TIM_TimeBaseInitTypeDef *TimeBaseInit);
void TIM_TimeBaseStructInit(TIM_TimeBaseInitTypeDef *TimeBaseInit);
void TIM_OCInit(TIM_TypeDef *TIMx, TIM_OCInitTypeDef *OutInit);
void TIM_OCStructInit(TIM_OCInitTypeDef *OutInit);
void TIM_ICInit(TIM_TypeDef *TIMx, TIM_ICInitTypeDef *CapInit);
void TIM_ICStructInit(TIM_ICInitTypeDef *CapInit);
void TIM_ChannelPolarity_Config(TIM_TypeDef *TIMx,u32 ChannelPolarity);
void TIM_BDTRInit(TIM_TypeDef *TIMx, TIM_BDTRInitTypeDef *BDTRInit);
void TIM_BDTRStructInit(TIM_BDTRInitTypeDef *BDTRInit);
void TIM_SoftwareBreak_CMD(TIM_TypeDef *TIMx, FunctionalState NewState);
void TIM_SetInterruptAutoreload(TIM_TypeDef *TIMx, u8 value);
void TIM_SetAutoreload(TIM_TypeDef *TIMx, u16 value);
void TIM_SetPrescaler(TIM_TypeDef *TIMx, u16 value);
void TIM_SetCounter(TIM_TypeDef *TIMx, u16 value);
void TIM_SetOCxValue(TIM_TypeDef *TIMx, u8 TIM_Channel, u16 value);
void TIM_SetICxValue(TIM_TypeDef *TIMx, u8 TIM_Channel, u16 value);
void TIM_SetSAMCClockDivision(TIM_TypeDef *TIMx, u16 TIM_SAMC);
u16 TIM_GetICxValue(TIM_TypeDef *TIMx, u8 TIM_Channel);
u16 TIM_GetCounter(TIM_TypeDef *TIMx);
u16 TIM_GetAutoreload(TIM_TypeDef *TIMx);
u16 TIM_GetPrescaler(TIM_TypeDef *TIMx);
void TIM_GenerateEvent(TIM_TypeDef *TIMx, u32 TIM_EventSource);
void TIM_Cmd(TIM_TypeDef *TIMx, FunctionalState NewState);
void TIM_OCITConfig(TIM_TypeDef *TIMx, u32 TIM_OCIT, FunctionalState NewState);
void TIM_ICITConfig(TIM_TypeDef *TIMx, u32 TIM_ICIT, FunctionalState NewState);
void TIM_BKITConfig(TIM_TypeDef *TIMx, u32 TIM_BKIT, FunctionalState NewState);
void TIM_TIITConfig(TIM_TypeDef *TIMx, u32 TIM_TIIT, FunctionalState NewState);
void TIM_ClearFlag(TIM_TypeDef *TIMx, u32 TIM_FLAG);
FlagStatus TIM_GetFlagStatus(TIM_TypeDef *TIMx, u32 TIM_FLAG);
void TIM_ADCTrigger(TIM_TypeDef *TIMx, u32 CountMode);
void TIM_DMAConfig(TIM_TypeDef *TIMx, u32 DMA_Event , FunctionalState NewState);
void TIM_SlaveModeInit(TIM_TypeDef *TIMx, TIM_SlaveModeInitTypeDef *TIM_SlaveModeInit);
void TIM_SlaveModeStructInit(TIM_SlaveModeInitTypeDef *TIM_SlaveModeInit);
void TIM_MasterModeInit(TIM_TypeDef *TIMx, TIM_MasterModeInitTypeDef *TIM_MasterModeInit);
void TIM_MasterModeStructInit(TIM_MasterModeInitTypeDef *TIM_MasterModeInit);
void LPTIM_SoftTriggerCMD(TIM_TypeDef *TIMx, FunctionalState NewState);
void LPTIM_SingletriggerCMD(TIM_TypeDef *TIMx, FunctionalState NewState);
void LPTIM_TimeoutCMD(TIM_TypeDef *TIMx, FunctionalState NewState);
void LPTIM_TriggerPolarityConfig(TIM_TypeDef *TIMx, u32 TriggerPolarity);
#ifdef __cplusplus
}
#endif

#endif /*__PT32x076_TIM_H */
