/********************************************************************************
  * @file    PT32Sx076_uart.h
  * @author  ӦÿŶ
  * @version V1.0.0
  * @date    2023/7/15
  * @brief   This file contains all the functions prototypes for the UART firmware
  *          library
  * @attention
  *
  * ǰĹָ̼, ĿͻṩйƷıϢ,Խʡǵʱ䡣
  * ̼/ͻʹаıϢκ, * Pai-IC κֱӣӻ̷𺦸
  *
  * (C) Ȩ Pai-IC Microelectronics
  *******************************************************************************/

#ifndef PT32x076_UART_H
#define PT32x076_UART_H

#ifdef __cplusplus
extern "C" {
#endif

#include "PT32x076.h"

/** @defgroup UART_InitTypeDef
* @{
*/
typedef struct
{
	u32 UART_BaudRate; 							/*!< This member configures the USART communication baud rate.
																			 @note UART_BaudRate shouldn't over 3Mbps. */

	u16 UART_DataLength;						/*!< Specifies the lenth of data.
                                       This parameter can be a value of @ref UART_DataLength */

	u16 UART_StopBitLength;					/*!< Specifies the number of stop bits transmitted.
                                       This parameter can be a value of @ref UART_StopBitLength */

	u16 UART_ParityMode;						/*!< Specifies the parity mode.
                                       This parameter can be a value of @ref UART_ParityMode */
    
	u16 UART_Receiver;							/*!< Specifies the receive enable.
                                       This parameter can be a value of @ref UART_Receiver */

} UART_InitTypeDef;


/** @defgroup UART_FIFO
* @{
*/
#define FIFO_RX          0
#define FIFO_TX          1
#define IS_UART_FIFO(SEL)           (((SEL) == FIFO_RX) || \
									 ((SEL) == FIFO_TX))

/** @defgroup UART_ALL_PERIPH
* @{
*/
#define IS_UART_ALL_PERIPH(SEL)   (((SEL) == UART0) || ((SEL) == UART1) ||\
								   ((SEL) == UART2) || ((SEL) == UART3) ||\
								   ((SEL) == LPUART0) || ((SEL) == LPUART1))


#define IS_UART_IRDA_PERIPH(SEL)   ((SEL) == UART0)

/** @defgroup USART_PERIPH
* @{
*/

/** @defgroup UART_BaudRate
* @{
*/
#define IS_UART_BaudRate(SEL)	     ((SEL) <= 3000000)

/** @defgroup UART_WordLengthAndParity
* @{
*/
#define UART_WordLengthAndParity_8D     (UART_CR_WP&0x00000001)
#define UART_WordLengthAndParity_7DP    (UART_CR_WP&0x00000003)
#define UART_WordLengthAndParity_9D     (UART_CR_WP&0x00000004)
#define UART_WordLengthAndParity_8DW    (UART_CR_WP&0x00000005)
#define UART_WordLengthAndParity_8DP    (UART_CR_WP&0x00000007)  
#define IS_UART_WordLengthAndParity(SEL)	(((SEL) == UART_WordLengthAndParity_8D)  || \
											 ((SEL) == UART_WordLengthAndParity_7DP) || \
											 ((SEL) == UART_WordLengthAndParity_9D)  || \
                                             ((SEL) == UART_WordLengthAndParity_8DW) || \
											 ((SEL) == UART_WordLengthAndParity_8DP))

/** @defgroup UART_DataLength
* @{
*/
#define UART_DataLength_7          7
#define UART_DataLength_8          8
#define UART_DataLength_9          9
#define UART_DataLength(SEL)       (((SEL) == UART_DataLength_7) || ((SEL) == UART_DataLength_8) || ((SEL) == UART_DataLength_9))


#define IS_UART_ErrorDataLengthAndParity(len,parity)        (((len) == UART_DataLength_7 && (parity) == UART_Parity_None) ||\
															 ((len) == UART_DataLength_9 && (parity) != UART_Parity_None))


/** @defgroup UART_StopBitLength
* @{
*/
#define  UART_StopBitLength_0P5		                 (UART_CR_STOP&0x00000000)
#define  UART_StopBitLength_1		                   (UART_CR_STOP&0x00000008)
#define  UART_StopBitLength_1P5		                 (UART_CR_STOP&0x00000010)
#define  UART_StopBitLength_2		                   (UART_CR_STOP&0x00000018)
#define IS_UART_StopBitLength(SEL)	 (((SEL) == UART_StopBitLength_0P5) || \
									  ((SEL) == UART_StopBitLength_1) || \
									  ((SEL) == UART_StopBitLength_1P5) || \
									  ((SEL) == UART_StopBitLength_2))
                                      
																			
/** @defgroup UART_ParityMode
* @{
*/
#define UART_Parity_None		    0
#define UART_Parity_Odd		      1
#define UART_Parity_Even		    2
#define IS_UART_ParityMode(SEL)		       (((SEL) == UART_Parity_None) || ((SEL) == UART_Parity_Odd) || ((SEL) == UART_Parity_Even))	

/** @defgroup UART_ParityMode_selection
* @{ 
*/
#define UART_ParityMode_Odd												 (UART_CR_PS&0x00000020)
#define UART_ParityMode_Even											 (UART_CR_PS&0x00000000)

/** @defgroup UART_Receiver
* @{
*/
#define  UART_Receiver_Enable	      (UART_CR_RE&0x00000100)
#define  UART_Receiver_Disable	    (UART_CR_RE&0x00000000)
#define IS_UART_Receiver(SEL)		 (((SEL) == UART_Receiver_Enable) || \
									  ((SEL) == UART_Receiver_Disable))


/** @defgroup UART_Data
* @{
*/
#define IS_UART_Data(SEL)             ((SEL) <= 0x1FF)

/** @defgroup UART_DutyCycle
* @{
*/
#define IS_UART_InfraredDutyCycle(SEL)   ((SEL) <= 0xFFF)

/** @defgroup UART_SingleLineDirection
* @{
*/
#define UART_SingleLineDirection_Tx		  (UART_CR_SLDS&0x00200000)
#define UART_SingleLineDirection_Rx		  (UART_CR_SLDS&0x00000000)
#define IS_UART_SingleLineDirection(SEL)	(((SEL) == UART_SingleLineDirection_Tx) || \
											 ((SEL) == UART_SingleLineDirection_Rx))

/** @defgroup UART_TimeOut
* @{
*/
#define IS_UART_TimeOut(SEL)    ((SEL) <= 0xFF)

/** @defgroup UART_InfraredBaudRate
* @{
*/
#define UART_InfraredBaudRate_600bps		(UART_IMCR_IRBD&0x00000000)
#define UART_InfraredBaudRate_1200bps		(UART_IMCR_IRBD&0x00000010)
#define UART_InfraredBaudRate_2400bps		(UART_IMCR_IRBD&0x00000020)
#define IS_UART_InfraredBaudRate(SEL)	 (((SEL) == UART_InfraredBaudRate_600bps) || \
										  ((SEL) == UART_InfraredBaudRate_1200bps) || \
										  ((SEL) == UART_InfraredBaudRate_2400bps))

/** @defgroup UART_FLAG
* @{
*/
#define UART_FLAG_RXNE          UART_SR_RXNE
#define UART_FLAG_RXHF          UART_SR_RXHF
#define UART_FLAG_RXF	    	UART_SR_RXF
#define UART_FLAG_RXCOT	        UART_SR_RXCOT
#define UART_FLAG_IDLE	        UART_SR_IDLE
#define UART_FLAG_PE	   	    UART_SR_PE
#define UART_FLAG_FE	    	UART_SR_FE
#define UART_FLAG_OVR	    	UART_SR_OVR
#define UART_FLAG_TXE	    	UART_SR_TXE
#define UART_FLAG_TXHE	        UART_SR_TXHE
#define UART_FLAG_TXF	    	UART_SR_TXF
#define UART_FLAG_TXO	    	UART_SR_TXO
#define UART_FLAG_MMF	    	UART_SR_MMF
#define UART_FLAG_LPWU	    	UART_SR_LPWU
#define UART_FLAG_ALL         ((u32)(0x3FFF))
#define IS_UART_FLAG(SEL)		(((SEL)&(~UART_FLAG_ALL)) == 0 && (SEL)!=0x00)

/** @defgroup UART_IT
* @{
*/
#define UART_IT_RXNE        UART_IE_RXNEI
#define UART_IT_RXHF        UART_IE_RXHFI
#define UART_IT_RXF	        UART_IE_RXFI
#define UART_IT_RXCOT	    UART_IE_RXCOTI
#define UART_IT_IDLE	    UART_IE_IDLEI
#define UART_IT_PE	        UART_IE_PEI
#define UART_IT_FE	        UART_IE_FEI
#define UART_IT_OVR	        UART_IE_OVRI
#define UART_IT_TXE	        UART_IE_TXEI
#define UART_IT_TXHE	    UART_IE_TXHEI
#define UART_IT_TXF	        UART_IE_TXFI
#define UART_IT_TXO	        UART_IE_TXOI
#define UART_IT_LPWUI	    UART_IE_LPWUI
#define UART_IT_ALL         ((u32)(0x2FFF))
#define IS_UART_IT(SEL)		(((SEL)&(~UART_IT_ALL)) == 0 && (SEL)!=0x00)

/** @defgroup UART_Address
* @{
*/
#define IS_UART_Address(SEL)    ((SEL) <= 0xFF)


/** @defgroup UART_DMATC
* @{
*/
#define UART_DMA_TriggerControl_1		  (UART_CR_DMATC&0x00000000)
#define UART_DMA_TriggerControl_4		  (UART_CR_DMATC&0x00002000)
#define UART_DMA_TriggerControl_8		  (UART_CR_DMATC&0x00004000)
#define IS_UART_DMATriggerControl(SEL)	    (((SEL) == UART_DMA_TriggerControl_1) || \
                                             ((SEL) == UART_DMA_TriggerControl_4) || \
                                             ((SEL) == UART_DMA_TriggerControl_8))
                                             
/** @defgroup UART_MuteModeWakeup
* @{
*/
#define UART_MuteModeWakeup_LineIdle		          (UART_CR_MMWU&0x00000000)
#define UART_MuteModeWakeup_AddressMatch		      (UART_CR_MMWU&0x01000000)
#define IS_UART_MuteModeWakeup(SEL)	         (((SEL) == UART_MuteModeWakeup_LineIdle) || \
                                             ((SEL) == UART_MuteModeWakeup_AddressMatch)) 

/** @defgroup UART_Wakeup
* @{
*/
#define UART_WakeupMethod_RXNE		          (UART_CR_LPWU&0x00000000)
#define UART_WakeupMethod_StartBit		      (UART_CR_LPWU&0x04000000)
#define IS_UART_WakeupMode(SEL)	         (((SEL) == UART_WakeupMethod_RXNE) || \
                                             ((SEL) == UART_WakeupMethod_StartBit)) 


/** @defgroup UART_Clocksource
* @{
*/
#define LPUART_Clocksource_PCLK		          (LPUART_CR_CLKS&0x00000000)
#define LPUART_Clocksource_HSI		          (LPUART_CR_CLKS&0x00000200)
#define LPUART_Clocksource_HCLK		          (LPUART_CR_CLKS&0x00000400)
#define LPUART_Clocksource_LSI		          (LPUART_CR_CLKS&0x00000600)
#define LPUART_Clocksource_LSE		          (LPUART_CR_CLKS&0x00000800)
#define IS_LPUART_Clocksource(SEL)	         (((SEL) == LPUART_Clocksource_PCLK) || \
                                             ((SEL) == LPUART_Clocksource_HSI)   || \
                                            ((SEL) == LPUART_Clocksource_HCLK)   || \
                                            ((SEL) == LPUART_Clocksource_LSI)   || \
                                             ((SEL) == LPUART_Clocksource_LSE))                                              


/*! function declaration and definition*/
void UART_Init(UART_TypeDef *UARTx, UART_InitTypeDef *UART_InitStruct);
void UART_StructInit(UART_InitTypeDef *UART_InitStruct);
void UART_Cmd(UART_TypeDef *UARTx, FunctionalState NewState);
void UART_SetTimeOut(UART_TypeDef *UARTx, u32 TimeOut);
void UART_SendData(UART_TypeDef *UARTx, u16 Data);
u16 UART_ReceiveData(UART_TypeDef *UARTx);
void UART_FifoReset(UART_TypeDef *UARTx,  u8 UART_FIFO);
void UART_IrDACmd(UART_TypeDef *UARTx, FunctionalState NewState);
void UART_IrDAPolarityConfig(UART_TypeDef *UARTx, FunctionalState NewState);
void UART_IrDABaudRateConfig(UART_TypeDef *UARTx, u8 IrDABaudRate);
void UART_IrDADutyCycleConfig(UART_TypeDef *UARTx, u16 IrDADutyCycle);
void UART_HalfDuplexCmd(UART_TypeDef *UARTx, FunctionalState NewState);
void UART_HalfDuplexDirectionConfig(UART_TypeDef *UARTx, u32 Direction);
void UART_ITConfig(UART_TypeDef *UARTx, u32 UART_IT, FunctionalState NewState);
FlagStatus UART_GetFlagStatus(UART_TypeDef *UARTx, u32 UART_FLAG);
void UART_ClearFlag(UART_TypeDef *UARTx, u32 UART_CLEAR_FLAG);
ITStatus UART_GetITStatus(UART_TypeDef *UARTx, u32 UART_IT);
void UART_SetAddress(UART_TypeDef *UARTx, u32 Address);
void UART_DMACmd(UART_TypeDef *UARTx,FunctionalState NewState);
void UART_SetDMATC(UART_TypeDef *UARTx,u32 DMA_TriggerControl);
void UART_MuteModeWakeupConfig(UART_TypeDef *UARTx,u32 Mode);
void UART_MuteModeEnable(UART_TypeDef *UARTx);
void UART_LowPowerConfig(UART_TypeDef *UARTx,u32 Method);
void UART_LoopBackModeCmd(UART_TypeDef *UARTx,FunctionalState NewState);
void LPUART_ClockSel(UART_TypeDef *UARTx,u32 clk);
void UART_BaudRateConfig(UART_TypeDef *UARTx,u32 BaudRate);

#ifdef __cplusplus
}
#endif

#endif /*__PT32x076_UART_H */
