/********************************************************************************
  * @file    PT32x076_beep.c
  * @author  ӦÿŶ
  * @version V1.0.0
  * @date    2023/7/15
  * @brief   This file contains all the functions prototypes for the BEEP firmware
  *          library
  * @attention
  *
  * ǰĹָ̼, ĿͻṩйƷıϢ,Խʡǵʱ䡣
  * ̼/ͻʹаıϢκ, * Pai-IC κֱӣӻ̷𺦸
  *
  * (C) Ȩ Pai-IC Microelectronics
  *******************************************************************************/

/* Includes ------------------------------------------------------------------*/
#include "PT32x076_beep.h"

/** @defgroup BEEP
  * @brief BEEP driver modules
  * @{
  */

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
#define Init_BEEP_CR_MASK 	  ((u32)0xFFFF00FC)
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/

/**
  * @brief  Initializes the BEEP peripheral according to the specified
  *         parameters in the Beep_InitStruct.
  * @param  Beep_InitStruct: pointer to a Beep_InitTypeDef structure that contains
  *         the configuration information for the specified BEEP peripheral.
  * @retval None
  */
void Beep_Init(Beep_InitTypeDef *Beep_InitStruct)
{
	u32 tmpreg = 0;
	/* Check the parameters */
	assert_param(IS_BEEP_ClockSelection(Beep_InitStruct->BEEP_ClockSelection));
	assert_param(IS_BEEP_Prescaler(Beep_InitStruct->BEEP_PrescalerValue));
	/*  */
	tmpreg = BEEP->CR;
	/*  */
	tmpreg &= Init_BEEP_CR_MASK;
	/*  */
	tmpreg  |= ((u32)(Beep_InitStruct->BEEP_ClockSelection));
	tmpreg  |= ((u32)((Beep_InitStruct->BEEP_PrescalerValue - 1) << 0x08));
	BEEP->CR = tmpreg;
}

/**
  * @brief  Enables or disables the specified BEEP peripheral.
  * @param  NewState: new state of the BEEP peripheral.
  *          This parameter can be: ENABLE or DISABLE.
  * @retval None
  */
void Beep_Cmd(FunctionalState NewState)
{
	/* Check the parameters */
	assert_param(IS_FUNCTIONAL_STATE(NewState));

	if(NewState != DISABLE)
	{
		/**/
		BEEP->CR |= BEEP_CR_EN;
	}
	else
	{
		/* */
		BEEP->CR &= ~((u32)BEEP_CR_EN);
	}
}

/**
  * @brief  Enables or disables the  BEEP High Sink .
	* @param  BEEPx: select the BEEPx peripheral.
  * @param  NewState: new state of the BEEP peripheral.
  *          This parameter can be: ENABLE or DISABLE.
  * @retval None
  */
void Beep_HighSinkConfig(BEEP_TypeDef *BEEPx, FunctionalState NewState)
{
	/* Check the parameters */
	assert_param(IS_BEEP_ALL_PERIPH(BEEPx));
	assert_param(IS_FUNCTIONAL_STATE(NewState));

	if(NewState != DISABLE)
	{
		/**/
		BEEPx->HCR |= BEEP_HCR_BEEPE;
	}
	else
	{
		/* */
		BEEPx->HCR &= ~((u32)BEEP_HCR_BEEPE);
	}
}

/**
  * @}
  */
