/********************************************************************************
  * @file    PT32Sx076_ldac.c
  * @author  ӦÿŶ
  * @version V1.0.0
  * @date    2023/7/15
  * @brief   This file contains all the functions prototypes for the LDaC firmware
  *          library
  * @attention
  *
  * ǰĹָ̼, ĿͻṩйƷıϢ,Խʡǵʱ䡣
  * ̼/ͻʹаıϢκ, * Pai-IC κֱӣӻ̷𺦸
  *
  * (C) Ȩ Pai-IC Microelectronics
  *******************************************************************************/
	
/* Includes ------------------------------------------------------------------*/
#include "PT32x076_ldac.h"

/** @defgroup LDAC
  * @brief LDAC driver modules
  * @{
  */

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/

/**
  * @brief  Set the LDAC Value.
  * @param  LDACx: select the LDACx peripheral.
  * @param  LDAC_Data: LDAC_DAC Value can be a number between 0x00 and 0x7F.
  * @retval None.
  */
void LDAC_SetData(LDAC_TypeDef *LDACx, u8 LDAC_Data)
{
	u16 tmpreg;
	/* Check the parameters */
	assert_param(IS_LDAC_ALL_PERIPH(LDACx));
	assert_param(IS_LDAC_Value(LDAC_Data));

	tmpreg = LDACx->CR & (~LDAC_CR_DATA);
	/* Write LDACx value */
	LDACx->CR = LDAC_Data | tmpreg;
}

/**
  * @brief  Enables or disables the specified LDAC peripheral.
  * @param  LDACx: select the LDAC peripheral.
  * @param  NewState: new state of the LDACx peripheral.
  *          This parameter can be: ENABLE or DISABLE.
  * @retval None
  */
void LDAC_Cmd(LDAC_TypeDef *LDACx, FunctionalState NewState)
{
	/* Check the parameters */
	assert_param(IS_LDAC_ALL_PERIPH(LDACx));
	assert_param(IS_FUNCTIONAL_STATE(NewState));

	if(NewState != DISABLE)
	{
		/* Enable the selected LDACx peripheral */
		LDACx->CR |= LDAC_CR_EN;
	}
	else
	{
		/* Disable the selected LDACx peripheral */
		LDACx->CR &= (uint32_t)~LDAC_CR_EN;
	}
}

/**
  * @brief  Enables or disables the specified LDAC output config.
  * @param  LDACx: select the LDAC peripheral.
  * @param  NewState: new state of the LDACx peripheral.
  *          This parameter can be: ENABLE or DISABLE.
  * @retval None
  */
void LDAC_OutputConfig(LDAC_TypeDef *LDACx, FunctionalState NewState)
{
	/* Check the parameters */
	assert_param(IS_LDAC_ALL_PERIPH(LDACx));
	assert_param(IS_FUNCTIONAL_STATE(NewState));

	if(NewState != DISABLE)
	{
		/* Enable the selected LDACx peripheral */
		LDACx->CR |= LDAC_CR_OE;
	}
	else
	{
		/* Disable the selected LDACx peripheral */
		LDACx->CR &= (uint32_t)~LDAC_CR_OE;
	}
}
/**
  * @}
  */
