/********************************************************************************
  * @file    PT32Sx076_opa.c
  * @author  ӦÿŶ
  * @version V1.0.0
  * @date    2023/7/15
  * @brief   This file contains all the functions prototypes for the OPA firmware
  *          library
  * @attention
  *
  * ǰĹָ̼, ĿͻṩйƷıϢ,Խʡǵʱ䡣
  * ̼/ͻʹаıϢκ, * Pai-IC κֱӣӻ̷𺦸
  *
  * (C) Ȩ Pai-IC Microelectronics
  *******************************************************************************/

/* Includes ------------------------------------------------------------------*/
#include "PT32x076_opa.h"

/** @defgroup OPA
  * @brief OPA driver modules
  * @{
  */

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
#define OPA_CR2_OPAxE   			0x1
#define OPA_CR2_TMxE   		  	0x100
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/

/**
  * @brief Enables or disables the specified OPA peripheral.
  * @param OPAx:OPA peripheral
	* @param  NewState: new state of the OPAx peripheral.
  *          This parameter can be: ENABLE or DISABLE.
  * @retval None
  */
void OPA_Cmd(u32 OPAx, FunctionalState NewState)
{
	/* Check the parameters */
	assert_param(IS_OPA_Number(OPAx));
	assert_param(IS_FUNCTIONAL_STATE(NewState));

	if(NewState != DISABLE)
	{
		OPA->CR2 |= OPA_CR2_OPAxE<<OPAx;
	}
	else
	{
		OPA->CR2 &= ~(OPA_CR2_OPAxE<<OPAx);
	}
}

/**
  * @brief Configures trim value for the specified OPA peripheral.
  * @param OPAx:OPA peripheral
  * @param This parameter can be a number between 0 and 0x7F.
  * @retval None
  */
void OPA_TrimConfig(u32 OPAx, u32 Value)
{
	/* Check the parameters */
	u32 tmpreg = 0;
	assert_param(IS_OPA_Number(OPAx));
	assert_param(IS_OPA_TrimValue(Value));
	
	tmpreg = OPA->CR1;
	tmpreg &= ~(OPA_CR1_TRIM0<<(OPAx*8));
	tmpreg |= (Value<<(OPAx*8));
	OPA->CR1 = tmpreg;
}
/**
  * @brief Enables or disables trim mode for the specified OPA peripheral.
  * @param OPAx:OPA peripheral
  * @param  NewState: new state of the trim mode.
  *          This parameter can be: ENABLE or DISABLE.
  * @retval None
  */
void OPA_TrimModeCmd(u32 OPAx, FunctionalState NewState)
{
	/* Check the parameters */
	assert_param(IS_OPA_Number(OPAx));
	assert_param(IS_FUNCTIONAL_STATE(NewState));

	if(NewState != DISABLE)
	{
		OPA->CR2 |= OPA_CR2_TMxE<<OPAx;
	}
	else
	{
		OPA->CR2 &= ~(OPA_CR2_TMxE<<OPAx);
	}
}

/**
  * @brief Configures trim key for the specified OPA peripheral.
  * @param OPAx:OPA peripheral
	* @param SEL: the trim key for the specified OPAx peripheral
	*         This parameter can be one of the following values:
	*          @arg OPA_TrimKey: the trim key 
  * @retval None
  */
void OPA_TrimKeyConfig(u32 OPAx, u32 SEL)
{
	u32 tmpreg = 0;
	/* Check the parameters */
	assert_param(IS_OPA_Number(OPAx));
	assert_param(IS_OPA_TrimKey(SEL));
	
	tmpreg = OPA->CR2;
	tmpreg &= (~OPA_CR2_KEY);
	tmpreg |= SEL;
	OPA->CR2 = tmpreg;
}
/**
  * @}
  */
