/********************************************************************************
  * @file    PT32Sx076_tim.c
  * @author  ӦÿŶ
  * @version V1.0.0
  * @date    2023/7/15
  * @brief   This file contains all the functions prototypes for the TIM firmware
  *          library
  * @attention
  *
  * ǰĹָ̼, ĿͻṩйƷıϢ,Խʡǵʱ䡣
  * ̼/ͻʹаıϢκ, * Pai-IC κֱӣӻ̷𺦸
  *
  * (C) Ȩ Pai-IC Microelectronics
  *******************************************************************************/
	
#include "PT32x076_tim.h"

/** @defgroup TIM
  * @brief TIM driver modules
  * @{
  */

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
#define TimeBaseInit_CR1_MASK   		 ((u32)0x604)
#define LPTimeBaseInit_CR1_MASK   	 ((u32)0x70200)
#define Init_CARP1CH_MASK(x)         ((u32)0x0007000F << ((x)*4))
#define Init_CARP2CH_MASK(x)         ((u32)0x00000037 << ((x)*8))

#define Init_OCMRCH_MASK(x)	         ((u32)(0x11110000 << (x)) | (0x00000007 << ((x)*4)))
#define Init_CR3CH_MASK              ((u32)0x00003333)

#define Init_BDTR_MASK           		 ((u32)0x10F0FFF)

#define Init_SlaveMode_MASK          ((u32)0XF7FF)
#define Init_MasterMode_MASK         ((u32)0X1F0000)
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/

/**
  * @brief  Initializes the TIMx Time Base Unit peripheral according to
  *         the specified parameters in the TimeBaseInit.
  * @param  TIMx: ALL Tim periph.
  * @param  TimeBaseInit: pointer to a TIM_TimeBaseInitTypeDef
  *         structure that contains the configuration information for
  *         the specified TIM peripheral.
  * @retval None
  */
void TIM_TimeBaseInit(TIM_TypeDef *TIMx, TIM_TimeBaseInitTypeDef *TimeBaseInit)
{
	u32  tmpreg = 0;
	/* Check the parameters */
	assert_param(IS_TIM_ALL_PERIPH(TIMx));

	if(TIMx == LPTIM)
	{
		assert_param(IS_LPTIM_InternalClockSource(TimeBaseInit->TIM_InternalClockSource));
		/* Set the TIM clcok  */
		while(TIMx->CR1&TIM_CR1_BSY);	
		tmpreg = TIMx->CR1;
		tmpreg &= ~LPTimeBaseInit_CR1_MASK;
		tmpreg |= (TimeBaseInit->TIM_InternalClockSource);
		/*Waiting for synchronization*/
		while(TIMx->CR1&TIM_CR1_BSY);	
	}
	else
	{
		assert_param(IS_TIM_Direction(TimeBaseInit->TIM_Direction));		
		/* Set the TIM clcok  */
		tmpreg = TIMx->CR1;
		tmpreg &= TimeBaseInit_CR1_MASK;
		if(TIMx==TIM2 ||TIMx==TIM3)
		{
		  tmpreg|=TimeBaseInit->TIM_Direction;
		}
		else if(TIMx==TIM4)
		{
		  assert_param(IS_TIM_LIST5_InternalClockSource(TimeBaseInit->TIM_InternalClockSource));		
			tmpreg |=TimeBaseInit->TIM_InternalClockSource;
		}
		else
		{
			assert_param(IS_TIM_CenterAlignedMode(TimeBaseInit->TIM_CenterAlignedMode));
		  assert_param(IS_TIM_LIST4_InternalClockSource(TimeBaseInit->TIM_InternalClockSource));	
		  tmpreg |= (TimeBaseInit->TIM_InternalClockSource | TimeBaseInit->TIM_Direction | TimeBaseInit->TIM_CenterAlignedMode);
		}
	}
	/* Set the counter reload value */
	TIMx->ARR = TimeBaseInit->TIM_AutoReloadValue;
	TIMx->CR1 = tmpreg;
	/* Set the Prescaler value */
	TIMx->PSC = TimeBaseInit->TIM_Prescaler;
}

/**
  * @brief  Fills each TimeBaseInit member with its default value.
  * @param  TimeBaseInit: pointer to a TIM_TimeBaseInitTypeDef structure
  *         which will be initialized.
  * @retval None
  */
void TIM_TimeBaseStructInit(TIM_TimeBaseInitTypeDef *TimeBaseInit)
{
	/* Set the default configuration */
	TimeBaseInit->TIM_AutoReloadValue = 0xFFFF;
	TimeBaseInit->TIM_InternalClockSource = TIM_LIST4_InternalClockSource_PCLK;
	TimeBaseInit->TIM_Prescaler = 0x0000;
	TimeBaseInit->TIM_Direction = TIM_Direction_Up;
	TimeBaseInit->TIM_CenterAlignedMode = TIM_CenterAlignedMode_Disable;
}

/**
  * @brief  Initializes the TIMx peripheral output compare function according to
  *         the specified parameters in the OutInit.
  * @param  TIMx: where x can be TIM1, TIM5 , TIM6 , TIM7, TIM8 or LPTIM to select the TIM peripheral
  * @param  OutInit: pointer to a TIM_OCInitTypeDef
  *         structure that contains the configuration information for
  *         the specified TIM peripheral.
  * @retval None
  */
void TIM_OCInit(TIM_TypeDef *TIMx, TIM_OCInitTypeDef *OutInit)
{
	u8 ch = 0;
	u32 tmpreg1 = 0;
	/* Check the parameters */
	assert_param(IS_TIM_LIST1_PERIPH(TIMx));
	assert_param(IS_TIM_Channel(OutInit->TIM_Channel));
	assert_param(IS_TIM_OCMode(OutInit->TIM_OCMode));
	assert_param(IS_TIM_OCIdleState(OutInit->TIM_OCIdleState));
	assert_param(IS_TIM_OCOutput(OutInit->TIM_OCOutput));

	if((TIMx!=LPTIM)&&(TIMx!=TIM8))
	{
		assert_param(IS_TIM_OCNOutput(OutInit->TIM_OCNOutput));	
		assert_param(IS_TIM_OCNIdleState(OutInit->TIM_OCNIdleState));
	}	
	ch = OutInit->TIM_Channel;
	/* Set the CHx Compare value */
	tmpreg1 = TIMx->OCMR;
	tmpreg1 &= ~Init_OCMRCH_MASK(ch);
	tmpreg1 |=	((OutInit->TIM_OCMode <<= (4 * ch))			 | \
				 (OutInit->TIM_OCIdleState <<= (1 * ch))  | \
				 (OutInit->TIM_OCNIdleState <<= (1 * ch)) | \
				 (OutInit->TIM_OCOutput <<= (1 * ch)) 		 | \
				 (OutInit->TIM_OCNOutput <<= (1 * ch)));

	TIMx->OCR[ch] = OutInit->TIM_OCValue;
	TIMx->OCMR = tmpreg1;
}

/**
  * @brief  Fills each OutInit member with its default value.
  * @param  OutInit: pointer to a TIM_OCInitTypeDef structure
  *         which will be initialized.
  * @retval None
  */
void TIM_OCStructInit(TIM_OCInitTypeDef *OutInit)
{
	/* Set the default configuration */
	OutInit->TIM_OCMode = TIM_OCMode_Timing;
	OutInit->TIM_OCIdleState = TIM_OCIdleState_High;
	OutInit->TIM_OCNIdleState = TIM_OCNIdleState_High;
	OutInit->TIM_OCOutput = TIM_OCOutput_Enable;
	OutInit->TIM_OCNOutput = TIM_OCNOutput_Enable;
}

/**
  * @brief  Initializes the TIMx peripheral input capture function according to
  *         the specified parameters in the CapInit.
  * @param  TIMx: where x can be TIM1, TIM5 , TIM6 , TIM7, TIM8 or LPTIM to select the TIM peripheral
  * @param  CapInit: pointer to a TIM_ICInitTypeDef
  *         structure that contains the configuration information for
  *         the specified TIM peripheral.
  * @retval None
  */
void TIM_ICInit(TIM_TypeDef *TIMx, TIM_ICInitTypeDef *CapInit)
{
	u8 ch = 0;
	u32 tmpreg1 = 0;
	u32 tmpreg2 = 0;

	/* Check the parameters */
	assert_param(IS_TIM_LIST1_PERIPH(TIMx));
	assert_param(IS_TIM_Channel(CapInit->TIM_Channel));
	assert_param(IS_TIM_ICRiseCapture(CapInit->TIM_ICRiseCapture));
	assert_param(IS_TIM_ICFallCapture(CapInit->TIM_ICFallCapture));
	assert_param(IS_TIM_ICResetCounter(CapInit->TIM_ICResetCounter));
	assert_param(IS_TIM_ICSource(CapInit->TIM_ICSource));
	assert_param(IS_TIM_ICFilter(CapInit->TIM_ICFilter));
	assert_param(IS_TIM_ICPrescaler(CapInit->TIM_ICPrescaler));

	ch = CapInit->TIM_Channel;
	tmpreg1 = TIMx->CAPR1;
	tmpreg2 = TIMx->CAPR2;
	tmpreg1 &=	~Init_CARP1CH_MASK(ch);
	tmpreg2 &= ~Init_CARP2CH_MASK(ch);

	tmpreg1 |=	((CapInit->TIM_ICRiseCapture <<= (4 * ch)) | \
				 (CapInit->TIM_ICFallCapture <<= (4 * ch)) | \
				 (CapInit->TIM_ICResetCounter <<= (4 * ch)) | \
				 (CapInit->TIM_ICSource <<= (4 * ch)));

	tmpreg2 |=	((CapInit->TIM_ICFilter <<= (8 * ch)) | \
				 (CapInit->TIM_ICPrescaler <<= (8 * ch)));

	TIMx->CAPR1 = tmpreg1;
	TIMx->CAPR2 = tmpreg2;
}

/**
  * @brief  Fills each CapInit member with its default value.
  * @param  CapInit: pointer to a TIM_ICInitTypeDef structure
  *         which will be initialized.
  * @retval None
  */
void TIM_ICStructInit(TIM_ICInitTypeDef *CapInit)
{
	/* Set the default configuration */
	CapInit->TIM_Channel = TIM_Channel_1;
	CapInit->TIM_ICRiseCapture = TIM_ICRiseCapture_Enable;
	CapInit->TIM_ICFallCapture = TIM_ICFallCapture_Enable;
	CapInit->TIM_ICResetCounter = TIM_ICResetCounter_Enable;
	CapInit->TIM_ICSource = TIM_ICSource_ICS1;
	CapInit->TIM_ICFilter = TIM_ICFilter_64;
	CapInit->TIM_ICPrescaler = TIM_ICPrescaler_8;
}

/**
  * @brief  Set Channel Polarity for TIM peripheral.
  * @param  TIMx: where x can be TIM1, TIM5 , TIM6 , TIM7 or TIM8 to select the TIM peripheral
  * @param  ChannelPolarity:all of IS_TIM_ChannelPolarity member .
  * @retval None
  */
void TIM_ChannelPolarity_Config(TIM_TypeDef *TIMx,u32 ChannelPolarity)
{
	u32 tmpreg = 0;	
	assert_param(IS_TIM_LIST1_PERIPH(TIMx));
	if(TIMx!=LPTIM)
	{
	  assert_param(IS_TIM_LIST4_ChannelPolarity(ChannelPolarity));
	}
	else
	{
	  assert_param(IS_TIM_LIST2_ChannelPolarity(ChannelPolarity));	
	}
	
	tmpreg=TIMx->CR3;
	tmpreg&=(~Init_CR3CH_MASK);
	tmpreg=ChannelPolarity;
  TIMx->CR3=tmpreg;
}

/**
  * @brief  Initializes the TIMx peripheral brake and dead time function according to
  *         the specified parameters in the BDTRInit.
  * @param  TIMx: where x can be TIM1, TIM5 , TIM6 , TIM7  to select the TIM peripheral
  * @param  BDTRInit: pointer to a TIM_BDTRInitTypeDef
  *         structure that contains the configuration information for
  *         the specified TIM peripheral.
  * @retval None
  */
void TIM_BDTRInit(TIM_TypeDef *TIMx, TIM_BDTRInitTypeDef *BDTRInit)
{
	u32 tmpreg = 0;
	/* Check the parameters */
	assert_param(IS_TIM_LIST3_PERIPH(TIMx));
	assert_param(IS_TIM_Break(BDTRInit->TIM_Break));
	assert_param(IS_TIM_BreakPolarity(BDTRInit->TIM_BreakPolarity));
	assert_param(IS_TIM_BreakSoftwareControl(BDTRInit->TIM_BreakSoftwareControl));
	assert_param(IS_TIM_BreakSource(BDTRInit->TIM_BreakSource));
	assert_param(IS_TIM_BreakInputControl(BDTRInit->TIM_BreakInputControl));
	assert_param(IS_TIM_DeadTime(BDTRInit->TIM_DeadTime));	
	
	tmpreg = TIMx->BDTR;
	tmpreg &= ~Init_BDTR_MASK;
	tmpreg |= (BDTRInit->TIM_Break | \
			   BDTRInit->TIM_BreakPolarity | \
			   BDTRInit->TIM_BreakSoftwareControl | \
			   BDTRInit->TIM_BreakSource | \
			   BDTRInit->TIM_BreakInputControl |\
	       BDTRInit->TIM_DeadTime );
	TIMx->BDTR = tmpreg;
}

/**
  * @brief  Fills each BDTRInit member with its default value.
  * @param  BDTRInit: pointer to a TIM_BDTRInitTypeDef structure
  *         which will be initialized.
  * @retval None
  */
void TIM_BDTRStructInit(TIM_BDTRInitTypeDef *BDTRInit)
{
	/* Set the default configuration */
	BDTRInit->TIM_Break = TIM_Break_Enable;
	BDTRInit->TIM_BreakPolarity = TIM_BreakPolarity_Low;
	BDTRInit->TIM_BreakSoftwareControl = TIM_BreakSoftwareControl_Disable;
	BDTRInit->TIM_BreakSource = TIM_BreakSource_TIM1BKIN;
	BDTRInit->TIM_BreakInputControl = TIM_BreakInput_OutputIdle;
}

/**
  * @brief  Enable or Disable Software Break.
  * @param  TIMx: where x can be TIM1, TIM5 , TIM6 , TIM7  to select the TIM peripheral
  * @param  NewState: new state of the TIMx peripheral.
  *          This parameter can be: ENABLE or DISABLE.
  * @retval None
  */
void TIM_SoftwareBreak_CMD(TIM_TypeDef *TIMx, FunctionalState NewState)
{
	/* Check the parameters */
	assert_param(IS_TIM_LIST3_PERIPH(TIMx));
	assert_param(IS_FUNCTIONAL_STATE(NewState));

	if(NewState!=DISABLE)
	{
	  TIMx->BDTR|=TIM_BDTR_BKSC;
	}
	else
	{
	  TIMx->BDTR&=~TIM_BDTR_BKSC;	
	}
}

/**
  * @brief  Set interrupt auto reload value for TIM peripheral.
  * @param  TIMx: where x can be TIM1, TIM5 , TIM6 , TIM7 TIM8 or LPTIM to select the TIM peripheral
  * @param  value: TIM interrupt auto reload value.
  * @retval None
  */
void TIM_SetInterruptAutoreload(TIM_TypeDef *TIMx, u8 value)
{
	/* Check the parameters */
	assert_param(IS_TIM_LIST1_PERIPH(TIMx));
	assert_param(IS_TIM_RepeatTimes(value));
	/* Set the TIM INT_RepeatTimes */
	TIMx->ITARR = value;
}

/**
  * @brief  Set auto reload value for TIM peripheral.
  * @param  TIMx: ALL Tim periph
  * @param  value: Auto reload value.
  * @retval None
  */
void TIM_SetAutoreload(TIM_TypeDef *TIMx, u16 value)
{
	/* Check the parameters */
	assert_param(IS_TIM_ALL_PERIPH(TIMx));
	TIMx->ARR = value;
}

/**
  * @brief  Set value of Prescaler for TIM peripheral.
  * @param  TIMx: ALL Tim periph
  * @param  value: Prescaler value.
  * @retval None
  */
void TIM_SetPrescaler(TIM_TypeDef *TIMx, u16 value)
{
	/* Check the parameters */
	assert_param(IS_TIM_ALL_PERIPH(TIMx));
	TIMx->PSC = value;
}

/**
  * @brief  Set value of Cnt for TIM peripheral.
  * @param  TIMx: ALL Tim periph
  * @param  value: Cnt value.
  * @retval None
  */
void TIM_SetCounter(TIM_TypeDef *TIMx, u16 value)
{
	/* Check the parameters */
	assert_param(IS_TIM_ALL_PERIPH(TIMx));
	TIMx->CNT = value;
}

/**
  * @brief  Set value of output compare for TIM peripheral.
  * @param  TIMx: where x can be TIM1, TIM5 , TIM6 , TIM7 TIM8 or LPTIM to select the TIM peripheral
  * @param  value: output compare value.
  * @retval None
  */
void TIM_SetOCxValue(TIM_TypeDef *TIMx, u8 TIM_Channel, u16 value)
{
	/* Check the parameters */
	u8 ch = 0;
	assert_param(IS_TIM_LIST1_PERIPH(TIMx));
	assert_param(IS_TIM_Channel(TIM_Channel));
	ch = TIM_Channel;
	TIMx->OCR[ch] = value;
}

/**
  * @brief  Set the sampling clock division for TIM peripheral.
  * @param  TIMx: where x can be TIM1, TIM5 , TIM6 , TIM7 TIM8 or LPTIM to select the TIM peripheral
  * @param  TIM_SAMC: sampling clock division.
	*          This parameter can be one of the following values:
  *        @arg TIM_SAMC_DIV1: divide the TIM clock frequency into 1/1 as the sampling clock
	*        @arg TIM_SAMC_DIV2: divide the TIM clock frequency into 1/2 as the sampling clock
	*        @arg TIM_SAMC_DIV4: divide the TIM clock frequency into 1/4 as the sampling clock
	*        @arg TIM_SAMC_DIV8: divide the TIM clock frequency into 1/8 as the sampling clock
	*        @arg TIM_SAMC_DIV16: divide the TIM clock frequency into 1/16 as the sampling clock
	*        @arg TIM_SAMC_DIV32: divide the TIM clock frequency into 1/32 as the sampling clock
  * @retval None
  */
void TIM_SetSAMCClockDivision(TIM_TypeDef *TIMx, u16 TIM_SAMC)
{
	/* Check the parameters */
	assert_param(IS_TIM_LIST1_PERIPH(TIMx));
	assert_param(IS_TIM_SAMCDiv(TIM_SAMC));

	if(TIMx == LPTIM)
	{
		/*Waiting for synchronization*/
		while(TIMx->CR1&TIM_CR1_BSY);	
		TIMx->CR1 &= (~TIM_CR1_SAMPSC);
		TIMx->CR1 |= TIM_SAMC;
		while(TIMx->CR1&TIM_CR1_BSY);	
	}
	else
	{
		TIMx->CR1 &= (~TIM_CR1_SAMPSC);
		TIMx->CR1 |= TIM_SAMC;
	}

}

/**
  * @brief  Get value of input capture channel for TIM peripheral.
  * @param  TIMx: where x can be TIM1, TIM5 , TIM6 , TIM7 TIM8 or LPTIM to select the TIM peripheral
  * @param  TIM_Channel: the input capture channel of TIM peripheral.
	*          This parameter can be one of the following values:
  *        @arg TIM_Channel_1: input capture channel 1 of TIM peripheral
  *        @arg TIM_Channel_2: input capture channel 2 of TIM peripheral
  *        @arg TIM_Channel_3: input capture channel 3 of TIM peripheral
  *        @arg TIM_Channel_4: input capture channel 4 of TIM peripheral
  * @retval the value of input capture channel
  */
u16 TIM_GetICxValue(TIM_TypeDef *TIMx, u8 TIM_Channel)
{
	u16 value = 0;
	u8 ch = 0;
	/* Check the parameters */
	assert_param(IS_TIM_LIST1_PERIPH(TIMx));
	assert_param(IS_TIM_Channel(TIM_Channel));
	ch = TIM_Channel;
	value = TIMx->ICR[ch];
	return value;
}

/**
  * @brief  Get counter value for TIM peripheral.
  * @param  TIMx: ALL Tim periph
  * @retval counter value
  */
u16 TIM_GetCounter(TIM_TypeDef *TIMx)
{
	/* Check the parameters */
	assert_param(IS_TIM_ALL_PERIPH(TIMx));
	return TIMx->CNT;
}

/**
  * @brief  Get auto reload value for TIM peripheral.
  * @param  TIMx: ALL Tim periph
  * @retval auto reload value
  */
u16 TIM_GetAutoreload(TIM_TypeDef *TIMx)
{
	/* Check the parameters */
	assert_param(IS_TIM_ALL_PERIPH(TIMx));
	return TIMx->ARR;
}

/**
  * @brief  Get prescaler value for TIM peripheral.
  * @param  TIMx: ALL Tim periph
  * @retval prescaler value
  */
u16 TIM_GetPrescaler(TIM_TypeDef *TIMx)
{
	/* Check the parameters */
	assert_param(IS_TIM_ALL_PERIPH(TIMx));
	return TIMx->PSC;
}

/**
  * @brief  Configures the TIMx event to be generate by software.
  * @param  TIMx: where x can be TIM1, TIM5 , TIM6 , TIM7 TIM8 or LPTIM to select the TIM peripheral
  * @param  TIM_EventSource: specifies the event source.
  *   This parameter can be one or more of the following values:
  *     @arg TIM_EventSource_Update: Timer update Event source
  *     @arg TIM_EventSource_Break: Timer Break event source
  * @retval None
  */
void TIM_GenerateEvent(TIM_TypeDef *TIMx, u32 TIM_EventSource)
{
	/* Check the parameters */
	assert_param(IS_TIM_LIST1_PERIPH(TIMx));
	assert_param(IS_TIM_EventSource(TIM_EventSource));

	if(TIM_EventSource == TIM_EventSource_Update)
	{
		if(TIMx == LPTIM)
		{
			/*Waiting for synchronization*/
			while(TIMx->CR1&TIM_CR1_BSY);		
		  TIMx->CR1 |= TIM_CR1_UG;
			while(TIMx->CR1&TIM_CR1_BSY);
		}
		else
		{
		  TIMx->CR1 |= TIM_CR1_UG;
		}
	}
	else if(TIM_EventSource == TIM_EventSource_Break)
	{
		if((TIMx!=TIM8)&&(TIMx!=LPTIM))
		{
		 TIMx->BDTR |= TIM_BDTR_BKSC;
		}
	}
}

/**
  * @brief  Enable or Disable TIMx peripheral.
  * @param  TIMx: ALL Tim periph
  * @param  NewState: new state of the TIMx peripheral.
  *          This parameter can be: ENABLE or DISABLE.
  * @retval None
  */
void TIM_Cmd(TIM_TypeDef *TIMx, FunctionalState NewState)
{
	/* Check the parameters */
	assert_param(IS_TIM_ALL_PERIPH(TIMx));
	assert_param(IS_FUNCTIONAL_STATE(NewState));

	if(TIMx == TIM4||TIMx == LPTIM)
	{
		while(TIMx->CR1 & TIM_CR1_BSY);
		if(NewState == ENABLE)
		{
			/* Set the update bit */
			TIMx->CR1 |= TIM_CR1_EN;
		}
		else
		{
			/* Reset the update bit */
			TIMx->CR1 &= (~TIM_CR1_EN);
		}
		while(TIMx->CR1 & TIM_CR1_BSY);
	}	
	else
	{
		if(NewState == ENABLE)
		{
			/* Set the update bit */
			TIMx->CR1 |= TIM_CR1_EN;
		}
		else
		{
			/* Reset the update bit */
			TIMx->CR1 &= (~TIM_CR1_EN);
		}
  }
}

/**
  * @brief  Enables or disables the specified TIM interrupts.
  * @param  TIMx: ALL Tim periph
  * @param  TIM_IT: Specify the TIM interrupts sources to be enabled or disabled.
  *          This parameter can be one of the following values:
  *        @arg IS_TIM_OCIT1(x) The value of x that satisfies the condition
  *        @arg IS_TIM_OCIT(x)  The value of x that satisfies the condition
  * @param  NewState: This parameter can be ENABLE or DISABLE.
  * @retval None
  */
void TIM_OCITConfig(TIM_TypeDef *TIMx, u32 TIM_OCIT, FunctionalState NewState)
{
	/* Check the parameters */
	assert_param(IS_TIM_ALL_PERIPH(TIMx));
	assert_param(IS_FUNCTIONAL_STATE(NewState));	
	if((TIMx==TIM2) || (TIMx== TIM3) || (TIMx== TIM4))
	{
    assert_param(IS_TIM_OCIT1(TIM_OCIT));	
	}
	else
	{
    assert_param(IS_TIM_OCIT(TIM_OCIT));		
	}
  
	if(NewState != DISABLE)
	{
		/* Enable the interrupt sources */
		TIMx->CR2 |= TIM_OCIT;
	}
	else
	{
		/* Disable the interrupt sources */
		TIMx->CR2 &= ~TIM_OCIT;
	}
}

/**
  * @brief  Enables or disables the specified TIM interrupts.
  * @param  TIMx: where x can be TIM1, TIM5 , TIM6 , TIM7 TIM8 or LPTIM to select the TIM peripheral
  * @param  TIM_IT: Specify the TIM interrupts sources to be enabled or disabled.
  *          This parameter can be one of the following values:
  *        @arg IS_TIM_ICIT(x) The value of x that satisfies the condition
  * @param  NewState: This parameter can be ENABLE or DISABLE.
  * @retval None
  */
void TIM_ICITConfig(TIM_TypeDef *TIMx, u32 TIM_ICIT, FunctionalState NewState)
{
	/* Check the parameters */
	assert_param(IS_TIM_LIST1_PERIPH(TIMx));
	assert_param(IS_TIM_ICIT(TIM_ICIT));
	assert_param(IS_FUNCTIONAL_STATE(NewState));

	if(NewState != DISABLE)
	{
		/* Enable the interrupt sources */
		TIMx->CAPR1 |= TIM_ICIT;
	}
	else
	{
		/* Disable the interrupt sources */
		TIMx->CAPR1 &= ~TIM_ICIT;
	}
}

/**
  * @brief  Enables or disables the specified TIM interrupts.
  * @param  TIMx: where x can be TIM1, TIM5 , TIM6 or TIM7 to select the TIM peripheral
  * @param  TIM_IT: Specify the TIM interrupts sources to be enabled or disabled.
  *          This parameter can be one of the following values:
  *        @arg IS_TIM_ICIT(x) The value of x that satisfies the condition
  * @param  NewState: This parameter can be ENABLE or DISABLE.
  * @retval None
  */
void TIM_BKITConfig(TIM_TypeDef *TIMx, u32 TIM_BKIT, FunctionalState NewState)
{
	/* Check the parameters */
	assert_param(IS_TIM_LIST3_PERIPH(TIMx));
	assert_param(IS_TIM_BKIT(TIM_BKIT));
	assert_param(IS_FUNCTIONAL_STATE(NewState));

	if(NewState != DISABLE)
	{
		/* Enable the interrupt sources */
		TIMx->BDTR |= TIM_BKIT;
	}
	else
	{
		/* Disable the interrupt sources */
		TIMx->BDTR &= ~TIM_BKIT;
	}
}

/**
  * @brief  Enables or disables the specified TIM interrupts.
  * @param  TIMx: where x can be TIM1, TIM5 , TIM6 , TIM7 TIM8 or LPTIM to select the TIM peripheral
  * @param  TIM_IT: Specify the TIM interrupts sources to be enabled or disabled.
  *          This parameter can be one of the following values:
  *        @arg IS_TIM_TIIT(x) The value of x that satisfies the condition
  * @param  NewState: This parameter can be ENABLE or DISABLE.
  * @retval None
  */
void TIM_TIITConfig(TIM_TypeDef *TIMx, u32 TIM_TIIT, FunctionalState NewState)
{
	/* Check the parameters */
	assert_param(IS_TIM_LIST1_PERIPH(TIMx));
	assert_param(IS_TIM_TIIT(TIM_TIIT));
	assert_param(IS_FUNCTIONAL_STATE(NewState));

	if(NewState != DISABLE)
	{
		/* Enable the interrupt sources */
		TIMx->MSCR |= TIM_TIIT;
	}
	else
	{
		/* Disable the interrupt sources */
		TIMx->MSCR &= ~TIM_TIIT;
	}
}

/**
  * @brief  Checks whether the specified TIM flag is set or not.
  * @param  TIMx: ALL Tim periph
  * @param  TIM_FLAG: Specify the flag to be checked.
  *         This parameter can be one of the following values:
  *         @arg IS_TIM_FLAG0(x)  The value of x that satisfies the condition
  *         @arg IS_TIM_FLAG1(x)  The value of x that satisfies the condition
  * @return FlagStatus of TIM_FLAG (SET or RESET).
  */
FlagStatus TIM_GetFlagStatus(TIM_TypeDef *TIMx, u32 TIM_FLAG)
{
	/* Check the parameters */
	assert_param(IS_TIM_ALL_PERIPH(TIMx));

	if(TIMx == LPTIM)
	{
	  assert_param(IS_TIM_FLAG1(TIM_FLAG));		
		/*Waiting for synchronization*/
		while(TIMx->SR&LPTIM_SR_BSY);
	}	
	else
	{
	  assert_param(IS_TIM_FLAG0(TIM_FLAG));
	}
	
	if((TIMx->SR & TIM_FLAG) != RESET)
	{
		return SET;
	}
	else
	{
		return RESET;
	}	
}

/**
  * @brief  Clears the TIM's pending flags.
  * @param  TIMx: ALL Tim periph
  * @param  TIM_FLAG: Specify the flag to be checked.
  *         This parameter can be one of the following values:
  *         @arg IS_TIM_FLAG0(x)  The value of x that satisfies the condition
  *         @arg IS_TIM_FLAG1(x)  The value of x that satisfies the condition
  * @retval None
  */
void TIM_ClearFlag(TIM_TypeDef *TIMx, u32 TIM_FLAG)
{
	/* Check the parameters */
	assert_param(IS_TIM_ALL_PERIPH(TIMx));
	if(TIMx == LPTIM)
	{
	  assert_param(IS_TIM_FLAG1(TIM_FLAG));		
		/*Waiting for synchronization*/
		while(TIMx->SR&LPTIM_SR_BSY);
		/* Clear the flags */
		TIMx->SR = TIM_FLAG;
		while(TIMx->SR&LPTIM_SR_BSY);
	}	
	else
	{
	  assert_param(IS_TIM_FLAG0(TIM_FLAG));	
		/* Clear the flags */
		TIMx->SR = TIM_FLAG;
	}
}

/**
  * @brief  Enable the ADC trigger function for TIMx peripheral.
  * @param  TIMx: where x can be TIM1, TIM5 , TIM6 , TIM7 TIM8 or LPTIM to select the TIM peripheral
  * @param  ADCTrigger: the mode of ADC trigger.
  *         This parameter can be one of the following values:
  *         @arg IS_TIM_ADCTrigger(x) The value of x that satisfies the condition
  * @retval None
  */
void TIM_ADCTrigger(TIM_TypeDef *TIMx, u32 ADCTrigger)
{
	assert_param(IS_TIM_LIST1_PERIPH(TIMx));
	assert_param(IS_TIM_ADCTrigger(ADCTrigger));
	TIMx->TACR |= ADCTrigger;
}

/**
  * @brief  Enable the DMA counection function for TIMx peripheral.
  * @param  TIMx: where x can be TIM1, TIM5 , TIM6 , TIM7 TIM8 or LPTIM to select the TIM peripheral
  * @param  DMA_Event: the source of DMA event.
  *         This parameter can be one of the following values:
  *         @arg IS_TIM_DMARequest(x) The value of x that satisfies the condition
  * @param  NewState: This parameter can be ENABLE or DISABLE.
  * @retval None
  */
void TIM_DMAConfig(TIM_TypeDef *TIMx, u32 DMA_Event, FunctionalState NewState)
{
	assert_param(IS_TIM_LIST1_PERIPH(TIMx));
	assert_param(IS_TIM_DMARequest(DMA_Event));
	assert_param(IS_FUNCTIONAL_STATE(NewState));

	if(NewState != DISABLE)
	{
		TIMx->TDCR |= DMA_Event;
	}
	else
	{
		TIMx->TDCR &= ~DMA_Event;
	}
}

/**
  * @brief  Initializes the TIMx peripheral slave mode function
  * @param  TIMx: where x can be TIM1, TIM5 , TIM6 , TIM7 TIM8 or LPTIM to select the TIM peripheral
  * @param  TIM_MasterModeInit: pointer to a TIM_SlaveModeInitTypeDef
  *         structure that contains the configuration information for
  *         the specified TIM peripheral.
  * @retval None
  */
void TIM_SlaveModeInit(TIM_TypeDef *TIMx, TIM_SlaveModeInitTypeDef *TIM_SlaveModeInit)
{
	u32 tmpreg = 0;
	assert_param(IS_TIM_LIST1_PERIPH(TIMx));

	tmpreg = TIMx->MSCR;
	tmpreg &= ~Init_SlaveMode_MASK;


	if((TIMx != TIM1) && (TIMx != TIM8) && (TIMx != LPTIM))
	{
	  assert_param(IS_TIM_TriggerInput1(TIM_SlaveModeInit->TIM_TriggerInput));		
	  assert_param(IS_TIM_SlaveMode1(TIM_SlaveModeInit->TIM_SlaveMode));
		tmpreg |= (TIM_SlaveModeInit->TIM_TriggerInput | TIM_SlaveModeInit->TIM_SlaveMode);
	}
	else
	{
		assert_param(IS_TIM_TriggerFilter(TIM_SlaveModeInit->TIM_TriggerFilter));
		assert_param(IS_TIM_ExternalClock(TIM_SlaveModeInit->TIM_ExternalClock));
		assert_param(IS_TIM_TriggerPolarity(TIM_SlaveModeInit->TIM_TriggerPolarity));
		if(TIMx == LPTIM)
		{
	    assert_param(IS_TIM_TriggerInput2(TIM_SlaveModeInit->TIM_TriggerInput));		
	    assert_param(IS_TIM_SlaveMode2(TIM_SlaveModeInit->TIM_SlaveMode));			
			tmpreg |= (TIM_SlaveModeInit->TIM_TriggerInput | TIM_SlaveModeInit->TIM_SlaveMode | TIM_SlaveModeInit->TIM_TriggerFilter  |
								 TIM_SlaveModeInit->TIM_ExternalClock | TIM_SlaveModeInit->TIM_TriggerPolarity);		
		}
    else
    {
			assert_param(IS_TIM_TriggerPrecaler(TIM_SlaveModeInit->TIM_TriggerPrecaler));		
	    assert_param(IS_TIM_TriggerInput0(TIM_SlaveModeInit->TIM_TriggerInput));
	    assert_param(IS_TIM_SlaveMode0(TIM_SlaveModeInit->TIM_SlaveMode));
			tmpreg |= (TIM_SlaveModeInit->TIM_TriggerInput | TIM_SlaveModeInit->TIM_SlaveMode | TIM_SlaveModeInit->TIM_TriggerFilter  |
			TIM_SlaveModeInit->TIM_TriggerPrecaler | TIM_SlaveModeInit->TIM_ExternalClock | TIM_SlaveModeInit->TIM_TriggerPolarity);		
		
		}			
	}
	TIMx->MSCR = tmpreg;
}

/**
  * @brief  Fills each TIM_SlaveModeInit member with its default value.
  * @param  TIM_SlaveModeInit: pointer to a TIM_SlaveModeInitTypeDef structure
  *         which will be initialized.
  * @retval None
  */
void TIM_SlaveModeStructInit(TIM_SlaveModeInitTypeDef *TIM_SlaveModeInit)
{
	TIM_SlaveModeInit->TIM_TriggerInput = TIM_TriggerInput_ITR0;
	TIM_SlaveModeInit->TIM_SlaveMode = TIM_SlaveMode_Disable;
	TIM_SlaveModeInit->TIM_TriggerFilter = TIM_TriggerFilter_1;
	TIM_SlaveModeInit->TIM_TriggerPrecaler = TIM_TriggerPrecaler_1;
	TIM_SlaveModeInit->TIM_ExternalClock = TIM_ExternalClock_Disable;
	TIM_SlaveModeInit->TIM_TriggerPolarity = TIM_TriggerPolarity_Disable;
}

/**
  * @brief  Initializes the TIMx peripheral slave mode function
  * @param  TIMx: where x can be TIM1, TIM5 , TIM6 , TIM7 or TIM8  to select the TIM peripheral
  * @param  TIM_MasterModeInit: pointer to a TIM_MasterModeInitTypeDef
  *         structure that contains the configuration information for
  *         the specified TIM peripheral.
  * @retval None
  */

void TIM_MasterModeInit(TIM_TypeDef *TIMx, TIM_MasterModeInitTypeDef *TIM_MasterModeInit)
{
	assert_param(IS_TIM_LIST4_PERIPH(TIMx));
	assert_param(IS_TIM_MasterMode(TIM_MasterModeInit->TIM_MasterMode));
	assert_param(IS_TIM_Synchronization(TIM_MasterModeInit->TIM_Synchronization));

	u32 tmpreg = 0;
	tmpreg = TIMx->MSCR;
	tmpreg &= ~Init_MasterMode_MASK;

	tmpreg |= (TIM_MasterModeInit->TIM_MasterMode | TIM_MasterModeInit->TIM_Synchronization);
	TIMx->MSCR = tmpreg;
}

/**
  * @brief  Fills each TIM_MasterModeInit member with its default value.
  * @param  TIM_MasterModeInit: pointer to a TIM_MasterModeInitTypeDef structure
  *         which will be initialized.
  * @retval None
  */

void TIM_MasterModeStructInit(TIM_MasterModeInitTypeDef *TIM_MasterModeInit)
{
	TIM_MasterModeInit->TIM_MasterMode = TIM_MasterMode_0;
	TIM_MasterModeInit->TIM_Synchronization = TIM_Synchronization_Disable;
}

/**
  * @brief Set the Software triggered for TIMx
  * @param  TIMx: where x can be LPTIM  to select the TIM peripheral
  * @param  NewState: This parameter can be ENABLE or DISABLE.
  * @retval None
  */
void LPTIM_SoftTriggerCMD(TIM_TypeDef *TIMx, FunctionalState NewState)
{
	assert_param(IS_TIM_LIST2_PERIPH(TIMx));
	assert_param(IS_FUNCTIONAL_STATE(NewState));	
	if(NewState != DISABLE)
	{
		TIMx->MSCR |= LPTIM_MSCR_SWTC;
	}
	else
	{
		TIMx->MSCR &= ~LPTIM_MSCR_SWTC;
	}
}

/**
  * @brief Set the Single triggered for TIMx
  * @param  TIMx: where x can be LPTIM  to select the TIM peripheral
  * @param  NewState: This parameter can be ENABLE or DISABLE.
  * @retval None
  */
void LPTIM_SingletriggerCMD(TIM_TypeDef *TIMx, FunctionalState NewState)
{
	assert_param(IS_TIM_LIST2_PERIPH(TIMx));	
	assert_param(IS_FUNCTIONAL_STATE(NewState));	
	if(NewState != DISABLE)
	{
		TIMx->MSCR |= LPTIM_MSCR_STE;
	}
	else
	{
		TIMx->MSCR &= ~LPTIM_MSCR_STE;
	}
}

/**
  * @brief Set the Time out for TIMx
  * @param  TIMx: where x can be LPTIM  to select the TIM peripheral
  * @param  NewState: This parameter can be ENABLE or DISABLE.
  * @retval None
  */
void LPTIM_TimeoutCMD(TIM_TypeDef *TIMx, FunctionalState NewState)
{
	assert_param(IS_TIM_LIST2_PERIPH(TIMx));	
	assert_param(IS_FUNCTIONAL_STATE(NewState));	
	if(NewState != DISABLE)
	{
		TIMx->MSCR |= LPTIM_MSCR_TIMOUTE;
	}
	else
	{
		TIMx->MSCR &= ~LPTIM_MSCR_TIMOUTE;
	}
}

/**
  * @brief Set the Trigger Polarity for TIMx
  * @param  TIMx: where x can be LPTIM  to select the TIM peripheral
  * @param  NewState: This parameter can be ENABLE or DISABLE.
  * @retval None
  */
void LPTIM_TriggerPolarityConfig(TIM_TypeDef *TIMx, u32 TriggerPolarity)
{
	u32 tmpreg = 0;	
	assert_param(IS_TIM_LIST2_PERIPH(TIMx));		
	assert_param(IS_LPTIM_TriggerPolarity(TriggerPolarity));
	
	tmpreg = TIMx->MSCR;
	tmpreg &=(~LPTIM_MSCR_TPS);
	tmpreg|=TriggerPolarity;
	TIMx->MSCR=tmpreg;
}

/**
  * @}
  */
