/********************************************************************************
  * @file    PT32Sx076_uart.c
  * @author  ӦÿŶ
  * @version V1.0.0
  * @date    2023/7/15
  * @brief   This file contains all the functions prototypes for the UART firmware
  *          library
  * @attention
  *
  * ǰĹָ̼, ĿͻṩйƷıϢ,Խʡǵʱ䡣
  * ̼/ͻʹаıϢκ, * Pai-IC κֱӣӻ̷𺦸
  *
  * (C) Ȩ Pai-IC Microelectronics
  *******************************************************************************/

/* Includes ------------------------------------------------------------------*/
#include "PT32x076_uart.h"

/** @defgroup UART
  * @brief UART driver modules
  * @{
  */

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
#define Init_UART_CR_MASK                 ((u32)0x0000013F)
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/


/**
  * @brief  Initializes the UARTx peripheral according to the specified
  *         parameters in the USART_InitStruct .
  * @param  UARTx: where x can be from 0 to 3 to select the UART peripheral.
  *                where x can be from 0 to 1 to select the LPUART peripheral.
  * @param  UART_InitStruct: pointer to a UART_InitTypeDef structure that contains
  *         the configuration information for the specified UART peripheral.
  * @retval None
  */
void UART_Init(UART_TypeDef *UARTx, UART_InitTypeDef *UART_InitStruct)
{
	u32  tmpreg = 0, DataLength=0,ParityMode=0;
	/* Check the parameters */
	assert_param(IS_UART_ALL_PERIPH(UARTx));
	assert_param(IS_UART_BaudRate(UART_InitStruct->UART_BaudRate));
	assert_param(UART_DataLength(UART_InitStruct->UART_DataLength));
	assert_param(IS_UART_StopBitLength(UART_InitStruct->UART_StopBitLength));
	assert_param(IS_UART_ParityMode(UART_InitStruct->UART_ParityMode));
	assert_param(IS_UART_Receiver(UART_InitStruct->UART_Receiver));
	assert_param(!IS_UART_ErrorDataLengthAndParity(UART_InitStruct->UART_DataLength, UART_InitStruct->UART_ParityMode));

	UARTx->RXFR = UART_RXFR_RXFR;
	UARTx->TXFR = UART_TXFR_TXFR;
    if(UARTx == LPUART0 | UARTx == LPUART1)
    {
        while((UARTx->RXFR & LPUART_RXFR_BSY) && (UARTx->TXFR & LPUART_TXFR_BSY));
    }
    
	switch(UART_InitStruct ->UART_DataLength )
	{
		case UART_DataLength_7:
			DataLength = UART_WordLengthAndParity_7DP;
			break;

		case UART_DataLength_8:
			if(UART_InitStruct->UART_ParityMode == UART_Parity_None)
			{
				DataLength = UART_WordLengthAndParity_8D;
			}
			else 
			{
				DataLength = UART_WordLengthAndParity_8DP;
			}

			break;

		case UART_DataLength_9:
			DataLength = UART_WordLengthAndParity_9D;
			break;

		default:
			break;
	}

	switch(UART_InitStruct->UART_ParityMode)
	{
		case UART_Parity_Odd:
			ParityMode = UART_ParityMode_Odd;
			break;

		case UART_Parity_Even:
			ParityMode = UART_ParityMode_Even;
			break;

		default:
			break;

	}

    UART_BaudRateConfig(UARTx,UART_InitStruct->UART_BaudRate);
    if(UARTx==LPUART0 || UARTx==LPUART1)
    {
        while(UARTx->CR & LPUART_CR_BSY);
    }
    tmpreg =   UARTx->CR;
	tmpreg &= ~Init_UART_CR_MASK;
	tmpreg |= (DataLength                                  | \
    		   ParityMode                                  | \
			   UART_InitStruct ->UART_StopBitLength        | \
			   UART_InitStruct->UART_Receiver);
    UARTx->CR = tmpreg;
   if(UARTx==LPUART0 || UARTx==LPUART1)
   {
        while(UARTx->CR & LPUART_CR_BSY);
   }
    
}

/**
  * @brief  Fills each UART_InitStruct member with its default value.
  * @param  UART_InitStruct: pointer to a UART_InitTypeDef structure
  *         which will be initialized.
  * @retval None
  */
void UART_StructInit(UART_InitTypeDef *UART_InitStruct)
{
	/* USART_InitStruct members default value */
	UART_InitStruct->UART_BaudRate = 19200;
	UART_InitStruct->UART_DataLength = UART_DataLength_8;
	UART_InitStruct->UART_StopBitLength = UART_StopBitLength_1;
	UART_InitStruct->UART_ParityMode = UART_Parity_Odd;
	UART_InitStruct->UART_Receiver = UART_Receiver_Enable;
}

/**
  * @brief  Enables or disables the specified UART peripheral.
  * @param  UARTx: where x can be from 0 to 3 to select the UART peripheral.
  *                where x can be from 0 to 1 to select the LPUART peripheral.
  * @param  NewState: new state of the USARTx peripheral.
  *          This parameter can be: ENABLE or DISABLE.
  * @retval None
  */
void UART_Cmd(UART_TypeDef *UARTx, FunctionalState NewState)
{
	/* Check the parameters */
	assert_param(IS_UART_ALL_PERIPH(UARTx));
	assert_param(IS_FUNCTIONAL_STATE(NewState));
    if(UARTx==LPUART0 || UARTx==LPUART1)
    {
        while(UARTx->CR & LPUART_CR_BSY);
    }
	if(NewState != DISABLE)
	{
		/* Enable the selected USART by setting the UE bit in the CR1 register */
		UARTx->CR |= UART_CR_EN;
	}
	else
	{
		/* Disable the selected USART by clearing the UE bit in the CR1 register */
		UARTx->CR &= (u32)~((u32)UART_CR_EN);
	}
    if(UARTx==LPUART0 || UARTx==LPUART1)
    {
        while(UARTx->CR & LPUART_CR_BSY);
    }
}

/**
  * @brief  Sets the receiver Time Out value.
  * @param  UARTx: where x can be from 0 to 3 to select the UART peripheral.
  *                where x can be from 0 to 1 to select the LPUART peripheral.
  * @param  UART_ReceiverTimeOut: specifies the Receiver Time Out value(0x00~0xFF).
  * @retval None
  */
void UART_SetTimeOut(UART_TypeDef *UARTx, u32 TimeOut)
{
	/* Check the parameters */
	assert_param(IS_UART_ALL_PERIPH(UARTx));
	assert_param(IS_UART_TimeOut(TimeOut));
    if(UARTx==LPUART0 || UARTx==LPUART1)
    {
        while(UARTx->TO & LPUART_TO_BSY);
    }
	/* Clear the receiver Time Out value by clearing the RTO[23:0] bits in the RTOR
	   register  */
	UARTx->TO &= (u32)~((u32)UART_TO_TO);
	/* Set the receiver Time Out value by setting the RTO[23:0] bits in the RTOR
	   register  */
	UARTx->TO |= TimeOut;
    if(UARTx==LPUART0 || UARTx==LPUART1)
    {
        while(UARTx->TO & LPUART_TO_BSY);
    }
}

/**
  * @brief  Transmits single data through the UARTx peripheral.
  * @param  UARTx: where x can be from 0 to 3 to select the UART peripheral.
  *                where x can be from 0 to 1 to select the LPUART peripheral.
  * @param  Data: the data to transmit.
  * @retval None
  */
void UART_SendData(UART_TypeDef *UARTx, u16 Data)
{
	/* Check the parameters */
	assert_param(IS_UART_ALL_PERIPH(UARTx));
	assert_param(IS_UART_Data(Data));

	/* While the TxFIFO contain 8 characters. */
	while((UARTx->SR & UART_SR_TXF));

	/* Transmit Data */
	UARTx->DR = (Data & (u16)0x01FF);
}

/**
  * @brief  Returns the most recent received data by the UARTx peripheral.
  * @param  UARTx: where x can be from 0 to 3 to select the UART peripheral.
  *                where x can be from 0 to 1 to select the LPUART peripheral.
  * @retval The received data.
  */
u16 UART_ReceiveData(UART_TypeDef *UARTx)
{
	/* Check the parameters */
	assert_param(IS_UART_ALL_PERIPH(UARTx));
	/* Receive Data */
	return (u16)(UARTx->DR & (u16)0x01FF);
}

/**
  * @brief  This function reset the Rx and the Tx FIFOs
  * @param  UARTx: where x can be from 0 to 3 to select the UART peripheral.
  *                where x can be from 0 to 1 to select the LPUART peripheral.
  * @param  FIFO: Transmit FIFO or receive FIFO for the UART .
  *          This parameter can be:
  *            @arg FIFO_RX: Receive FIFO .
  *            @arg FIFO_TX: Transmit FIFO .
  * @retval None.
  */
void UART_FifoReset(UART_TypeDef *UARTx,  u8 UART_FIFO)
{
	assert_param(IS_UART_ALL_PERIPH(UARTx));
	assert_param(IS_UART_FIFO(UART_FIFO));

	switch(UART_FIFO)
	{
		case FIFO_RX :
       if(UARTx==LPUART0 || UARTx==LPUART1)
       {
        while(UARTx->RXFR & LPUART_RXFR_BSY);
       }
			UARTx->RXFR = UART_RXFR_RXFR;
       if(UARTx==LPUART0 || UARTx==LPUART1)
       {
        while(UARTx->RXFR & LPUART_RXFR_BSY);
       }
			break;

		case FIFO_TX :
        if(UARTx==LPUART0 || UARTx==LPUART1)
       {
        while(UARTx->TXFR & LPUART_TXFR_BSY);
       }
			UARTx->TXFR = UART_TXFR_TXFR;
        if(UARTx==LPUART0 || UARTx==LPUART1)
       {
        while(UARTx->RXFR & LPUART_RXFR_BSY);
       }
			break;
	}
}

/**
  * @brief  Enables or disables the UART's IrDA interface.
  * @param  UARTx: where x can be from 0 to 3 to select the UART peripheral.
  *                where x can be from 0 to 1 to select the LPUART peripheral.
  * @param  NewState: new state of the IrDA mode.
  *          This parameter can be: ENABLE or DISABLE.
  * @retval None
  */
void UART_IrDACmd(UART_TypeDef *UARTx, FunctionalState NewState)
{
	/* Check the parameters */
	assert_param(IS_UART_IRDA_PERIPH(UARTx));
	assert_param(IS_FUNCTIONAL_STATE(NewState));
	/*Check the UARTx is vaild or not*/

	if(NewState != DISABLE)
	{
		/* Enable the IrDA mode by setting the EN bit in the IRR register */
		UARTx->IMCR |= UART_IMCR_IRE;
	}
	else
	{
		/* Disable the IrDA mode by clearing the EN bit in the IRR register */
		UARTx->IMCR &= (u32)~((u32)UART_IMCR_IRE);
	}

}

/**
  * @brief  Configures the IrDA's Pin polarity
  * @param  UARTx: where x can be 0 to select the UART peripheral.
  * @param  NewState: new defined levels for the USART data.
  *          This parameter can be one of the following values:
  *           @arg ENABLE: pin(s) signal values are inverted (Vdd =0, Gnd =1).
	*           @arg DIABLE: pin(s) signal works using the standard logic levels (Vdd =1, Gnd =0).
  * @note   This function has to be called before calling UART_Cmd() function.
  * @retval None
  */
void UART_IrDAPolarityConfig(UART_TypeDef *UARTx, FunctionalState NewState)
{
	/* Check the parameters */
	assert_param(IS_UART_IRDA_PERIPH(UARTx));
	assert_param(IS_FUNCTIONAL_STATE(NewState));

	/*Check the UARTx is vaild or not*/
	if(NewState != DISABLE)
	{
		/* Enable the binary data inversion feature by setting the DATAINV bit in
			 the CR2 register */
		UARTx->IMCR |= UART_IMCR_IRPN;
	}
	else
	{
		/* Disable the binary data inversion feature by clearing the DATAINV bit in
			 the CR2 register */
		UARTx->IMCR &= (u32)~((u32)UART_IMCR_IRPN);
	}
}

/**
  * @brief  Set the Infrared Baud Rate for UART peripheral.
  * @param  UARTx: where x can be 0 to select the UART peripheral.
  * @param  IrDABaudRate: set infrared baud rate for UART peripheral.
  *          This parameter can be one of the following values:
  *           @arg UART_InfraredBaudRate_600bps: set 600 bits per second as the infrared baud rate
	*           @arg UART_InfraredBaudRate_1200bps: set 1200 bits per second as the infrared baud rate
	*           @arg UART_InfraredBaudRate_2400bps: set 1400 bits per second as the infrared baud rate
  * @note   This function has to be called before calling UART_Cmd() function.
  * @retval None
  */
void UART_IrDABaudRateConfig(UART_TypeDef *UARTx, u8 IrDABaudRate)
{
	/* Check the parameters */
	assert_param(IS_UART_IRDA_PERIPH(UARTx));
	assert_param(IS_UART_InfraredBaudRate(IrDABaudRate));
	/*Check the UARTx is vaild or not*/
	/* Write to IMCR */
	UARTx->IMCR &= ~UART_IMCR_IRBD;
	UARTx->IMCR |= ((u32)IrDABaudRate);
}

/**
  * @brief  Sets the infrared duty cycle for UART peripheral.
  * @param  UARTx: where x can be 0 to select the UART peripheral.
  * @param  IrDADutyCycle: specifies the infrared duty cycle.
  * @note   This function has to be called before calling UART_Cmd() function.
  * @retval None
  */
void UART_IrDADutyCycleConfig(UART_TypeDef *UARTx, u16 IrDADutyCycle)
{
	/* Check the parameters */
	assert_param(IS_UART_IRDA_PERIPH(UARTx));
	assert_param(IS_UART_InfraredDutyCycle(IrDADutyCycle));
	/*Check the UARTx is vaild or not*/
	/* Clear the IrDA's modulation PWM duty cycle */
	UARTx->IMDCR &= ~UART_IMDCR_DUTY;
	/* Set the IrDA's modulation PWM duty cycle*/
	UARTx->IMDCR |= IrDADutyCycle;
}

/**
  * @brief  Enables or disables the UART's Half Duplex communication.
  * @param  UARTx: where x can be from 0 to 3 to select the UART peripheral.
  *                where x can be from 0 to 1 to select the LPUART peripheral.
  * @param  NewState: new state of the UART Communication.
  *          This parameter can be: ENABLE or DISABLE.
  * @retval None
  */
void UART_HalfDuplexCmd(UART_TypeDef *UARTx, FunctionalState NewState)
{
	/* Check the parameters */
	assert_param(IS_UART_ALL_PERIPH(UARTx));
	assert_param(IS_FUNCTIONAL_STATE(NewState));
    if(UARTx==LPUART0 || UARTx==LPUART1)
    {
    while(UARTx->RXFR & LPUART_RXFR_BSY);
    }
	if(NewState != DISABLE)
	{
		/* Enable the Half-Duplex mode by setting the OWE bit in the CR register */
		UARTx->CR |= UART_CR_SLME;
	}
	else
	{
		/* Disable the Half-Duplex mode by clearing the OWE bit in the CR register */
		UARTx->CR  &= (u32)~((u32)UART_CR_SLME);
	}
    if(UARTx==LPUART0 || UARTx==LPUART1)
    {
        while(UARTx->CR & LPUART_CR_BSY);
    }
}

/**
  * @brief  Enables or disables the UART's transmitter or receiver.
  * @param  UARTx: where x can be from 0 to 3 to select the UART peripheral.
  *                where x can be from 0 to 1 to select the LPUART peripheral.
  * @param  UART_Direction: specifies the UART direction.
  *          This parameter can be any combination of the following values:
  *            @arg UART_SingleLineDirection_Tx: UART Single Line Direction Transmitter
  *            @arg UART_SingleLineDirection_Rx: UART Single Line Direction Receiver
  * @param  NewState: new state of the USART transfer direction.
  *          This parameter can be: ENABLE or DISABLE.
  * @retval None
  */

void UART_HalfDuplexDirectionConfig(UART_TypeDef *UARTx, u32 Direction)
{
	/* Check the parameters */
	assert_param(IS_UART_ALL_PERIPH(UARTx));
	assert_param(IS_UART_SingleLineDirection(Direction));
    if(UARTx==LPUART0 || UARTx==LPUART1)
    {
    while(UARTx->RXFR & LPUART_RXFR_BSY);
    }
	if(Direction != UART_SingleLineDirection_Rx)
	{
		/* Set NSS pin internally by software */
		UARTx->CR |= UART_SingleLineDirection_Tx;
	}
	else
	{
		/* Reset NSS pin internally by software */
		UARTx->CR &= UART_SingleLineDirection_Rx;
	}
    if(UARTx==LPUART0 || UARTx==LPUART1)
    {
        while(UARTx->CR & LPUART_CR_BSY);
    }
}

/**
  * @brief  Enables or disables the specified UART interrupts.
  * @param  UARTx: where x can be from 0 to 3 to select the UART peripheral.
  *                where x can be from 0 to 1 to select the LPUART peripheral.
  * @param  UART_IT: specifies the UART interrupt sources to be enabled or disabled.
  *        @arg IS_UART_IT(x)  The value of x that satisfies the condition
  * @param  NewState: new state of the specified UARTx interrupts.
  *          This parameter can be: ENABLE or DISABLE.
  * @retval None
  */
void UART_ITConfig(UART_TypeDef *UARTx, u32 UART_IT, FunctionalState NewState)
{
	/* Check the parameters */
	assert_param(IS_UART_ALL_PERIPH(UARTx));
	assert_param(IS_UART_IT(UART_IT));
	assert_param(IS_FUNCTIONAL_STATE(NewState));

	if(NewState != DISABLE)
	{
		UARTx->IE |= UART_IT;
	}
	else
	{
		UARTx->IE &= ~UART_IT;
	}
}

/**
  * @brief  Checks whether the specified UART flag is set or not.
  * @param  UARTx: where x can be from 0 to 3 to select the UART peripheral.
  *                where x can be from 0 to 1 to select the LPUART peripheral.
  * @param  UART_FLAG: specifies the flag to check.
  *        @arg IS_UART_FLAG(x)  The value of x that satisfies the condition
  * @retval The new state of UART_FLAG (SET or RESET).
  */
FlagStatus UART_GetFlagStatus(UART_TypeDef *UARTx, u32 UART_FLAG)
{
	FlagStatus bitstatus = RESET;
	/* Check the parameters */
	assert_param(IS_UART_ALL_PERIPH(UARTx));
	assert_param(IS_UART_FLAG(UART_FLAG));

	if((UARTx->SR & UART_FLAG) != (u16)RESET)
	{
		bitstatus = SET;
	}
	else
	{
		bitstatus = RESET;
	}

	return bitstatus;
}

/**
  * @brief  Clears the UARTx's pending flags.
  * @param  UARTx: where x can be from 0 to 3 to select the UART peripheral.
  *                where x can be from 0 to 1 to select the LPUART peripheral.
  * @param  UART_CLEAR_FLAG: specifies the flag to clear.
  *          This parameter can be any combination of the following values:
  *            @arg UART_FLAG_PE:  Parity error.
  *            @arg UART_FLAG_FE:  Frame error.
  *            @arg UART_FLAG_OVR: Receiver FIFO buffer overflow.
  * @retval None
  */
void UART_ClearFlag(UART_TypeDef *UARTx, u32 UART_CLEAR_FLAG)
{
	/* Check the parameters */
	assert_param(IS_UART_ALL_PERIPH(UARTx));
	assert_param(IS_UART_FLAG(UART_CLEAR_FLAG));
	UARTx->SR = UART_CLEAR_FLAG;
}

/**
  * @brief  Checks whether the specified UART intterrupt status is set or not.
  * @param  UARTx: where x can be from 0 to 3 to select the UART peripheral.
  *                where x can be from 0 to 1 to select the LPUART peripheral.
  * @param  UART_IT: specifies the UART interrupt sources to be enabled or disabled.
  *        @arg IS_UART_IT(x)  The value of x that satisfies the condition
  * @return ITStatus of UART_IT (SET or RESET).
  */
ITStatus UART_GetITStatus(UART_TypeDef *UARTx, u32 UART_IT)
{
	ITStatus bitstatus = RESET;
	u32 enablestatus = 0;
	/* Check the parameters */
	assert_param(IS_UART_ALL_PERIPH(UARTx));
	assert_param(IS_UART_IT(UART_IT));
	/**/
	enablestatus = (u32)(UARTx->IE & UART_IT);

	/*  */
	if(((u32)(UARTx->SR & UART_IT) != (u32)RESET) && (enablestatus != (u32)RESET))
	{
		/* */
		bitstatus = SET;
	}
	else
	{
		/* */
		bitstatus = RESET;
	}

	/**/
	return  bitstatus;
}

/**
  * @brief  Sets the address value for UART peripheral.
  * @param  UARTx: where x can be from 0 to 3 to select the UART peripheral.
  *                where x can be from 0 to 1 to select the LPUART peripheral.
  * @param  UART_Address: specifies the Address value(0x00~0xFF).
  * @retval None
  */
void UART_SetAddress(UART_TypeDef *UARTx, u32 Address)
{
    u32 tmpreg ;
    	/* Check the parameters */
	assert_param(IS_UART_ALL_PERIPH(UARTx));
    assert_param(IS_UART_Address(Address));
   if(UARTx==LPUART0 || UARTx==LPUART1)
   {
        while(UARTx->CR & LPUART_CR_BSY);
   }
    tmpreg = UARTx->CR;
    UARTx->CR &= ~UART_CR_RE ; 
	/* Clear the receiver Time Out value by clearing the RTO[23:0] bits in the RTOR
	   register  */
	UARTx->AR &= (u32)~((u32)UART_AR_AR);
	/* Set the receiver Time Out value by setting the RTO[23:0] bits in the RTOR
	   register  */
	UARTx->AR = Address;
    UARTx->CR = tmpreg ; 
    
}


/**
  * @brief  Enables or disables the UART's DMA Mode.
  * @param  UARTx: where x can be from 0 to 3 to select the UART peripheral.
  *                where x can be from 0 to 1 to select the LPUART peripheral.
  * @param  NewState: new state of the USARTx peripheral.
  *          This parameter can be: ENABLE or DISABLE.
  * @retval None
  */
void UART_DMACmd(UART_TypeDef *UARTx,FunctionalState NewState)
{
    assert_param(IS_UART_ALL_PERIPH(UARTx));
    assert_param(IS_FUNCTIONAL_STATE(NewState));
    if(UARTx==LPUART0 || UARTx==LPUART1)
    {
       while(UARTx->CR & LPUART_CR_BSY);
     }
    	if(NewState == ENABLE)
	{
		/* Set the update bit */
		UARTx->CR |= UART_CR_DMAE;
	}
    else
    {
            		/* Reset the update bit */
		UARTx->CR &= (~UART_CR_DMAE);
    }
    if(UARTx==LPUART0 || UARTx==LPUART1)
    {
        while(UARTx->CR & LPUART_CR_BSY);
    }
    
}

/**
  * @brief  Sets the DMA trigger control for UART peripheral.
  * @param  UARTx: where x can be from 0 to 3 to select the UART peripheral.
  *                where x can be from 0 to 1 to select the LPUART peripheral.
  * @param  UART_DMATriggerControl: specifies the DMATriggerControl for UART peripheral.
  *          This parameter can be one of the following values:
  *           @arg UART_DMA_TriggerControl_1: DMA data is transmitted consecutively for 1 byte
	*         	@arg UART_DMA_TriggerControl_4: DMA data is transmitted consecutively for 4 byte
	*         	@arg UART_DMA_TriggerControl_8: DMA data is transmitted consecutively for 8 byte
  * @retval None
  */
void UART_SetDMATC(UART_TypeDef *UARTx,u32 DMA_TriggerControl)
{
    u32 tmpreg = 0;
    assert_param(IS_UART_ALL_PERIPH(UARTx));
    assert_param(IS_UART_DMATriggerControl(DMA_TriggerControl));
    tmpreg = UARTx->CR;
    tmpreg &= ~UART_CR_DMATC;
    tmpreg |= DMA_TriggerControl;
    if(UARTx==LPUART0 || UARTx==LPUART1)
    {
        while(UARTx->CR & LPUART_CR_BSY);
    }
    UARTx->CR = tmpreg;
   if(UARTx==LPUART0 || UARTx==LPUART1)
    {
        while(UARTx->CR & LPUART_CR_BSY);
    }

}
  

/**
  * @brief  Sets mute mode wakeup method for UART peripheral.
  * @param  UARTx: where x can be from 0 to 3 to select the UART peripheral.
  *                where x can be from 0 to 1 to select the LPUART peripheral.
  * @param  UART_MuteModeWakeup: specifies the MuteModeWakeup for UART peripheral.
  *          This parameter can be one of the following values:
  *           @arg UART_MuteModeWakeup_LineIdle: Line idle
	*         	@arg UART_MuteModeWakeup_AddressMatch: AddressMatch
  * @retval None
  */
void UART_MuteModeWakeupConfig(UART_TypeDef *UARTx,u32 Mode)
{
     u32 tmpreg = 0;
     assert_param(IS_UART_ALL_PERIPH(UARTx));
     assert_param(IS_UART_MuteModeWakeup(Mode));
     tmpreg = UARTx->CR;
     tmpreg &= ~UART_CR_MMWU;
     tmpreg |= Mode;
     if(UARTx==LPUART0 || UARTx==LPUART1)
     {
        while(UARTx->CR & LPUART_CR_BSY);
     }
     UARTx->CR = tmpreg;
    if(UARTx==LPUART0 || UARTx==LPUART1)
    {
        while(UARTx->CR & LPUART_CR_BSY);
    }

}

/**
  * @brief  Enables or disables the UART's mute mode.
  * @param  UARTx: where x can be from 0 to 3 to select the UART peripheral.
  *                where x can be from 0 to 1 to select the LPUART peripheral.
  * @param  NewState: new state of the USARTx peripheral.
  *          This parameter can be: ENABLE or DISABLE.
  * @retval None
  */
void UART_MuteModeEnable(UART_TypeDef *UARTx)
{
    u32 tmpreg = 0;
    assert_param(IS_UART_ALL_PERIPH(UARTx));
		/* Set the update bit */
      tmpreg = UARTx->CR;
      tmpreg &= ~UART_CR_WP;
      tmpreg |= UART_CR_MME|UART_WordLengthAndParity_8DW;
    if(UARTx==LPUART0 || UARTx==LPUART1)
    {
        while(UARTx->CR & LPUART_CR_BSY);
    }
      UARTx->CR = tmpreg;
    if(UARTx==LPUART0 || UARTx==LPUART1)
    {
        while(UARTx->CR & LPUART_CR_BSY);
    }
}


/**
  * @brief  Sets low power mode wakeup method for UART peripheral.
  * @param  UARTx: where x can be from 0 to 3 to select the UART peripheral.
  *                where x can be from 0 to 1 to select the LPUART peripheral.
  * @param  UART_WakeupMode: specifies the wakeupmode for UART peripheral.
  *          This parameter can be one of the following values:
  *           @arg UART_WakeupMethod_RXNE: Detects that a data frame has been received
	*        	  @arg UART_WakeupMethod_StartBit: Start bit detected
  * @retval None
  */
void UART_LowPowerConfig(UART_TypeDef *UARTx,u32 Method)
{
     u32 tmpreg = 0;
     assert_param(IS_UART_ALL_PERIPH(UARTx));
     assert_param(IS_UART_WakeupMode(Method));
     tmpreg = UARTx->CR;
     tmpreg &= ~(UART_CR_LPWU);
     tmpreg |= Method;
     if(UARTx==LPUART0 || UARTx==LPUART1)
     {
        while(UARTx->CR & LPUART_CR_BSY);
     }
     UARTx->CR = tmpreg;
     if(UARTx==LPUART0 || UARTx==LPUART1)
     {
        while(UARTx->CR & LPUART_CR_BSY);
     }
}

/**
  * @brief  Enables or disables the UART's loopback mode.
  * @param  UARTx: where x can be from 0 to 3 to select the UART peripheral.
  *                where x can be from 0 to 1 to select the LPUART peripheral.
  * @param  NewState: new state of the USARTx peripheral.
  *          This parameter can be: ENABLE or DISABLE.
  * @retval None
  */
void UART_LoopBackModeCmd(UART_TypeDef *UARTx,FunctionalState NewState)
{
    assert_param(IS_UART_ALL_PERIPH(UARTx));
	assert_param(IS_FUNCTIONAL_STATE(NewState));
    if(UARTx==LPUART0 || UARTx==LPUART1)
    {
        while(UARTx->CR & LPUART_CR_BSY);
    }
    if(NewState == ENABLE)
	{
		/* Set the update bit */
		UARTx->CR |= UART_CR_LPB;
	}
    else
    {
         /* Reset the update bit */
		UARTx->CR &= (~UART_CR_LPB);
    }
    if(UARTx==LPUART0 || UARTx==LPUART1)
    {
        while(UARTx->CR & LPUART_CR_BSY);
    }
}

/**
  * @brief  Sets clock source for UART peripheral.
  * @param  UARTx: where x can be from 0 to 1 to select the LPUART peripheral.
  * @param  clk: specifies the clock source for UART peripheral.
  *        	@arg IS_LPUART_Clocksource(x)  The value of x that satisfies the condition
  * @retval None
  */
void LPUART_ClockSel(UART_TypeDef *UARTx,u32 clk)
{
    u32 tmpreg = 0;
    assert_param(IS_UART_ALL_PERIPH(UARTx));
    assert_param(IS_LPUART_Clocksource(clk));
    
     while(UARTx->CR & LPUART_CR_BSY);
     tmpreg = UARTx->CR;
     tmpreg &= ~LPUART_CR_CLKS;
     tmpreg |= clk;
     UARTx->CR = tmpreg;
     while(UARTx->CR & LPUART_CR_BSY);
}

/**
  * @brief  Sets baudrate for UART peripheral.
  * @param  UARTx: where x can be from 0 to 3 to select the UART peripheral.
  *                where x can be from 0 to 1 to select the LPUART peripheral.
  * @param  BaudRate: baudrate for UART peripheral.
  * @retval None
  */
void UART_BaudRateConfig(UART_TypeDef *UARTx,u32 BaudRate)
{
    u32  remainder = 0, quotient = 0, i = 0,clk_source = 0,tmpvalue = 0;
    u32 SampleRate[3] = {16,8,4};
    
     clk_source = RCC_GetClockFreq(RCC_PCLK);
    
      if(UARTx== LPUART0 || UARTx==LPUART1)
    {
        switch(UARTx->CR&LPUART_CR_CLKS)
        {
            case LPUART_Clocksource_LSI:
                    clk_source = RCC_GetClockFreq(RCC_LSI);
                break;
            case LPUART_Clocksource_LSE:
                clk_source = RCC_GetClockFreq(RCC_LSE);
                break;
            case LPUART_Clocksource_HSI:
                clk_source = RCC_GetClockFreq(RCC_HSI);
                 break;
            case LPUART_Clocksource_HCLK:
                clk_source = RCC_GetClockFreq(RCC_HCLK);;
                 break; 
            default:
                 break;                  
        }
    } 
   for(i = 0 ;i<3;i++)
    {
        tmpvalue = SampleRate[i] * BaudRate;
        if ((clk_source/tmpvalue) > 0)
        {
            break;
        }
    }
	if(i >= 3)
	{
		UARTx->BRR = 0x01 | 0x20000;
	}
	else
	{
		quotient =  clk_source / tmpvalue;
		remainder = clk_source % tmpvalue;  
		   
		 if(remainder > (tmpvalue/2))
		{
			UARTx->BRR = (quotient + 1)|(i<<16);
		}
		 else
		{
			UARTx->BRR = quotient | (i<<16);
		}
    }

}

/**
  * @}
  */
