/********************************************************************************
  * @file    PT32S038x_spi_flash.c
  * @author  ӦÿŶ
  * @version V1.1.0
  * @date    2023/6/15
  * @brief   This file contains all the functions prototypes for the SPI FLASH firmware
  *          library
  * @attention
  *
  * ǰĹָ̼, ĿͻṩйƷıϢ,Խʡǵʱ䡣
  * ̼/ͻʹаıϢκ, * Pai-IC κֱӣӻ̷𺦸
  *
  * (C) Ȩ Pai-IC Microelectronics
  *******************************************************************************/
  
/* Includes ------------------------------------------------------------------*/
#include "PT32x076_spi.h"
#include "spi_flash.h"

static __IO u32  SPITimeout = SPIT_LONG_TIMEOUT; 
static uint16_t SPI_TIMEOUT_UserCallback(uint8_t errorCode);
uint8_t SPI_FLASH_SendByte(SPI_TypeDef* SPIx,uint8_t byte);

/**
  * @brief  ȡFLASH ID
  * @param 	
  * @retval FLASH ID
  */
u32 SPI_FLASH_ReadID(SPI_TypeDef* SPIx)
{
  u32 Temp = 0, Temp0 = 0, Temp1 = 0, Temp2 = 0;

  /* ʼͨѶCS͵ƽ */   
  SPI_SoftwareControlCSSConfig(SPIx,SPI_SoftwareControlCSS_Low);

  /* JEDECָȡID */
  SPI_FLASH_SendByte(SPIx,W25X_JedecDeviceID);

  /* ȡһֽ */
  Temp0 = SPI_FLASH_SendByte(SPIx,Dummy_Byte);

  /* ȡһֽ */
  Temp1 = SPI_FLASH_SendByte(SPIx,Dummy_Byte);

  /* ȡһֽ */
  Temp2 = SPI_FLASH_SendByte(SPIx,Dummy_Byte);

 /* ֹͣͨѶCSߵƽ */
  SPI_SoftwareControlCSSConfig(SPIx,SPI_SoftwareControlCSS_High);

  /*Ϊķֵ*/
	Temp = (Temp0 << 16) | (Temp1 << 8) | Temp2;

  return Temp;
}


 /**
  * @brief  FLASH дʹ 
  * @param  none
  * @retval none
  */
void SPI_FLASH_WriteEnable(SPI_TypeDef* SPIx)
{
  /* ͨѶʼCS */
  SPI_SoftwareControlCSSConfig(SPIx,SPI_SoftwareControlCSS_Low);

  /* дʹ*/
  SPI_FLASH_SendByte(SPIx ,W25X_WriteEnable);

  /*ͨѶCS */
  SPI_SoftwareControlCSSConfig(SPIx,SPI_SoftwareControlCSS_High);
}

/* WIP(busy)־FLASHڲд */
#define WIP_Flag                  0x01

 /**
  * @brief  ȴWIP(BUSY)־0ȴFLASHڲд
  * @param  none
  * @retval none
  */
void SPI_FLASH_WaitForWriteEnd(SPI_TypeDef* SPIx)
{
  uint8_t FLASH_Status = 0;

  /* ѡ FLASH: CS  */
  SPI_SoftwareControlCSSConfig(SPIx,SPI_SoftwareControlCSS_Low);

  /*  ״̬Ĵ  */
  SPI_FLASH_SendByte(SPIx ,W25X_ReadStatusReg);

  /* FLASHæµȴ */
  do
  {
		/* ȡFLASHоƬ״̬Ĵ */
    FLASH_Status = SPI_FLASH_SendByte(SPIx ,Dummy_Byte);	 
  }
  while ((FLASH_Status & WIP_Flag) == SET);  /* д־ */

  /* ֹͣź  FLASH: CS  */
  SPI_SoftwareControlCSSConfig(SPIx,SPI_SoftwareControlCSS_High);
}

 /**
  * @brief  ʹSPIһֽڵ
  * @param  byteҪ͵
  * @retval ؽյ
  */
uint8_t SPI_FLASH_SendByte(SPI_TypeDef* SPIx,uint8_t byte)
{
	 SPITimeout = SPIT_FLAG_TIMEOUT;
  /* ȴͻΪգTXE¼ */
  while (SPI_GetFlagStatus(SPIx , SPI_FLAG_TNF) == RESET)
	{
    if((SPITimeout--) == 0) return SPI_TIMEOUT_UserCallback(0);
   }

  /* дݼĴҪдд뷢ͻ */
  SPI_SendData(SPIx , byte);

	SPITimeout = SPIT_FLAG_TIMEOUT;
  /* ȴջǿգRXNE¼ */
  while (SPI_GetFlagStatus(SPIx , SPI_FLAG_RXNE) == RESET)
  {
    if((SPITimeout--) == 0) return SPI_TIMEOUT_UserCallback(1);
   }

  /* ȡݼĴȡջ */
  return SPI_ReceiveData(SPIx );
}

/**
  * @brief  ȴʱص
  * @param  None.
  * @retval None.
  */
static  uint16_t SPI_TIMEOUT_UserCallback(uint8_t errorCode)
{
  /* ȴʱĴ,Ϣ */
  FLASH_ERROR("SPI ȴʱ!errorCode = %d",errorCode);
  return 0;
}
