/********************************************************************************
  * @file    PT32S038x_spi_flash.h
  * @author  ӦÿŶ
  * @version V1.1.0
  * @date    2023/6/15
  * @brief   This file contains all the functions prototypes for the SPI FLASH firmware
  *          library
  * @attention
  *
  * ǰĹָ̼, ĿͻṩйƷıϢ,Խʡǵʱ䡣
  * ̼/ͻʹаıϢκ, * Pai-IC κֱӣӻ̷𺦸
  *
  * (C) Ȩ Pai-IC Microelectronics
  *******************************************************************************/

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef SPI_FLASH_H
#define SPI_FLASH_H

#ifdef __cplusplus
 extern "C" {
#endif

#include "PT32x076.h"

/* WIP(busy)־FLASHڲд */
#define WIP_Flag                  0x01
#define Dummy_Byte                0xFF

/*ȴʱʱ*/
#define SPIT_FLAG_TIMEOUT         ((u32)0x1000)
#define SPIT_LONG_TIMEOUT         ((u32)(10 * SPIT_FLAG_TIMEOUT))

/*Ϣ*/
#define FLASH_DEBUG_ON         1

#define FLASH_INFO(fmt,arg...)           printf("<<-FLASH-INFO->> "fmt"\n",##arg)
#define FLASH_ERROR(fmt,arg...)          printf("<<-FLASH-ERROR->> "fmt"\n",##arg)
#define FLASH_DEBUG(fmt,arg...)          do{\
                                          if(FLASH_DEBUG_ON)\
                                          printf("<<-FLASH-DEBUG->> [%d]"fmt"\n",__LINE__, ##arg);\
                                          }while(0)


/* SPI read/write flash define*/
#define  sFLASH_ID              0XEF4017    //W25Q64
#define SPI_FLASH_PageSize              256
#define SPI_FLASH_PerWritePageSize      256

/*-ͷ*******************************/
#define W25X_WriteEnable		      0x06 
#define W25X_WriteDisable		      0x04 
#define W25X_ReadStatusReg		    0x05 
#define W25X_WriteStatusReg		    0x01 
#define W25X_ReadData			        0x03 
#define W25X_FastReadData		      0x0B 
#define W25X_FastReadDual		      0x3B 
#define W25X_PageProgram		      0x02 
#define W25X_BlockErase			      0xD8 
#define W25X_SectorErase		      0x20 
#define W25X_ChipErase			      0xC7 
#define W25X_PowerDown			      0xB9 
#define W25X_ReleasePowerDown	    0xAB 
#define W25X_DeviceID			        0xAB 
#define W25X_ManufactDeviceID   	0x90 
#define W25X_JedecDeviceID		    0x9F

u32 SPI_FLASH_ReadID(SPI_TypeDef* SPIx);
void SPI_FLASH_WriteEnable(SPI_TypeDef* SPIx);
void SPI_FLASH_WaitForWriteEnd(SPI_TypeDef* SPIx);
uint8_t SPI_FLASH_SendByte(SPI_TypeDef* SPIx,uint8_t byte);
static  uint16_t SPI_TIMEOUT_UserCallback(uint8_t errorCode);
#ifdef __cplusplus
}
#endif

#endif 
